(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)



(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Interfaces to SPICE / PSpice", "Subtitle"],

Cell[TextData[{
  "To execute this notebook you need the add-on package ",
  StyleBox["Analog Insydes 2",
    FontWeight->"Bold"],
  " by ITWM (see copyright message at end of document)"
}], "Box"],

Cell[CellGroupData[{

Cell["Schematics Import", "ExampleSection"],

Cell[TextData[{
  "Analog Insydes provides functions for importing circuit schematics into \
your ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " notebooks for better documentation of your circuit analysis tasks. The \
Analog Insydes function ",
  StyleBox["DXFGraphics", "MR"],
  " displays a DXF file as a native ",
  StyleBox["Mathematica", "TI"],
  " graphics object. Consider the following example where the file ",
  StyleBox["\"Buffer.dxf\"", "TI"],
  " was produced by the DXF export function of MicroSim's Schematics editor."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000810001Ka000`40O003
h00Oo`00o`000`00003oHaSoHaP2HaP10000009S6003@Q1S66<H02YS6003
@Q1S66<H00QS60800?mS65mS6003@Q1S66<H05aS6005@Q1S648@HaQ24002
HaP10000009S6003@Q1S66<H00mS6003001S66<H01QS6003@Q1S66<H00YS
6003001S66<H0?mS65aS6003@Q1S66<H05aS60I2405S604000000V<H00=2
46<HHaP016<H100000=S60000000100000=S6000HaP00V<H00H006<HHaQS
6000HaP80008HaP00d8@HaP00003HaP<0002HaP00`00HaP0000200000f<H
0000000500001F<H00000000HaP00`0000=S6000HaP0of<H@6<H00=246<H
HaP00`0000ES6000HaP006<H00H004mS60A2409S604000000V<H00=246<H
HaP016<H00<006<HHaP00V<H00<006<HHaP00V<H00<006<HHaP00f<H00<0
06<H00000P001F<H0P0000=S6000HaP01f<H00=246<H00000f<H00<006<H
HaP00P000V<H1@000V<H00h006<H001S6000HaP006<H001S6000HaP006<H
0`0000AS6000HaP00?mS64=S6003@Q1S600000=S60800003HaP006<H0080
009S6003001S66<H04mS60A2405S604000000V<H00=246<HHaP01F<H00<0
06<HHaP00V<H00<006<H00000P001F<H00<006<H00000P000f<H1P0026<H
00=246<H0000200000AS60000000009S6009001S66<H001S6000HaP006<H
00<0000<HaP006<H001S6000HaP006<H001S6000of<H@f<H00=246<H0000
16<H00@006<H001S60800003HaP00000059S6092409S604000000V<H00=2
46<HHaP016<H00<006<H00000V<H00@006<H000000MS6003001S66<H0080
00ES60800003HaP006<H00MS6003@Q1S6000009S6004001S60000002HaP3
00000f<H00000003HaP00`00HaP0000200001F<H00000000HaP00`0000ES
6000000006<H00<00?mS64=S6003@Q1S600000=S60<00004HaP006<HHaP4
001BHaP2@Q01HaP10000009S6003@Q1S66<H00AS60<0009S60H000AS6080
00=S6003001S66<H00L000QS6003@Q1S600000<000iS6003001S66<H00US
6003001S66<H00ES6003001S66<H0?mS645S6003@Q1S66<H00<000US6003
001S66<H05AS604000000V<H00=246<HHaP0:V<H00=246<HHaP0of<HJF<H
00=246<HHaP0Hf<H0@000002HaP/@Q000f<H@Q12403o@Q1Y@Q000f<H@Q12
401J@Q0:HaP100000?mS6?mS609S604000000V<H448@of<Hkf<H0@00000A
HaP9000YHaP9003oHaRSHaP8000:HaP10000015S6003001S66<H00ES6003
001S66<H02QS6003OomS66<H00AS6003001S66<H0?mS6:QS6003001S66<H
00QS604000004F<H00<006<HHaP00V<H00@006<HHaP002YS6003OomS66<H
00AS6003001S66<H0?mS6:AS6005001S66<HHaP0000:HaP10000015S6004
001S66<HHaP20002HaP00`00HaQS600XHaP00gooHaQS6004HaP00`00HaQS
603oHaRTHaP20002HaP00`00HaQS6008HaP10000015S6003001S66<H00<0
009S6003001S66<H02QS6003OomS66<H00AS6003001S66<H0?mS6:AS6080
009S6003001S66<H00QS604000004F<H00@006<HHaQS6080009S6003001S
66<H02QS6003OomS66<H00AS6003001S66<H0?mS6:AS6005001S66<HHaP0
000:HaP10000015S6003001S66<H00ES6003001S66<H02QS6003OomS66<H
00AS6003001S66<H0?mS6:QS6003001S66<H00QS604000004F<H00<006<H
HaP01F<H00<006<HHaP0;f<H00<006<HHaP0of<HZ6<H00<006<HHaP026<H
0@00000AHaP00`00Oomoo`3oOooSOol80002HaP10000015S6003001oogoo
0?moon=oo`MS6003001S66<H004000004F<H00<007ooOol0ogoohgoo1f<H
00<006<HHaP00@00000AHaP00`00Oomoo`3oOooSOol3HaP20002HaP00`00
HaQS60010000015S6003001oogoo0?moon=oo`9S60@00004HaP006<HHaP1
0000015S6003001oogoo0?moon=oo`MS6003001S66<H004000004F<H00<0
07ooOol0=Goo100OogooZWoo1f<H00<006<HHaP00@00000AHaP00`00Oomo
o`0eOol0100OOomoo`0OogooZWoo1f<H00<006<HHaP00@00000AHaP00`00
Oomoo`0eOol0100OOomoo`0OogooZWoo20000V<H0@00000AHaP00`00Oomo
o`0aOol01@0OOomoogoo01l00Woo00<07gooOol0ogooZ7oo1f<H00<006<H
HaP00@00000AHaP00`00Oomoo`0`Ool301l2Ool0100OOomoo`0OogooZWoo
1f<H00<006<HHaP00@00000AHaP00`00Oomoo`0_Ool01@0OOomoogoo01l0
0Woo0P0OogooZgoo1f<H00<006<HHaP00@00000AHaP00`00Oomoo`0^Ool2
01l3Ool201ooOon^Ool7HaP00`00HaQS60010000015S6003001oogoo02eo
o`807`Eoo`807omoojeoo`MS6003001S66<H004000004F<H00<007ooOol0
;Goo2@0Oogoo[Goo1f<H00<006<HHaP00@00000AHaP00`00Oomoo`0bOol0
0`0OOomoo`3oOon^Ool7HaP00`00HaQS60010000015S6003001oogoo039o
o`0301moogoo0?moojioo`MS6003001S66<H004000004F<H00<007ooOol0
<Woo00<07gooOol0ogoo[Woo2V<H0@00000AHaP00`00Oomoo`0bOol00`0O
Oomoo`3oOon^Ool:HaP10000015S6003001oogoo039oo`0301moogoo0?mo
ojioo`YS604000004F<H00<007ooOol0<Goo0P0OPWoo0P0OK7oo00<07goo
Ool0_7oo2V<H0@00000AHaP00`00Oomoo`0`Ool301l00`000P02001n0P00
100001l07`00JP800`0OO080@Goo2V<H0@00000AHaP00`00Oomoo`0`Ool4
01n0Ool401mZOol301mkOol00`80Oomoo`0oOol:HaP10000015S6003001o
ogoo035oo`0301l007oo085oo`0301l007oo06]oo`03001oogoo07Yoo`03
0P1oogoo03moo`YS604000004F<H00<007ooOol0<Woo00<207ooOol0PGoo
00<207ooOol0JWoo00<207ooOol0NWoo00<207ooOol0?goo2V<H0@00000A
HaP00`00Oomoo`0bOol00`80Oomoo`21Ool00`80Oomoo`1ZOol00`80Oomo
o`1jOol00`80Oomoo`0oOol:HaP10000015S6003001oogoo039oo`030P1o
ogoo085oo`030P1oogoo06Yoo`030P1oogoo07Yoo`030P1oogoo03moo`YS
604000004F<H00<007ooOol0<Woo00<207ooOol0PGoo00<207ooOol0JWoo
00<207ooOol0NWoo00<207ooOol0?goo2V<H0@00000AHaP00`00Oomoo`0b
Ool00`80Oomoo`21Ool00`80Oomoo`1ZOol00`80Oomoo`1jOol00`80Oomo
o`0oOol:HaP10000015S6003001oogoo039oo`030P1oogoo085oo`030P1o
ogoo06Yoo`030P1oogoo07Yoo`030P1oogoo03moo`YS604000004F<H00<0
07ooOol0<Woo00<207ooOol0PGoo00<207ooOol0JWoo00<207ooOol0NWoo
00<207ooOol0?goo2V<H0@00000AHaP00`00Oomoo`0bOol00`80Oomoo`21
Ool00`80Oomoo`1ZOol00`80Oomoo`1jOol00`80Oomoo`0oOol:HaP10000
015S6003001oogoo039oo`030P1oogoo085oo`030P1oogoo06Yoo`030P1o
ogoo07Yoo`030P1oogoo03moo`YS604000004F<H00<007ooOol0<Woo00<2
07ooOol0PGoo00<207ooOol0JWoo00<207ooOol0NWoo00<207ooOol0?goo
2V<H0@00000AHaP00`00Oomoo`0bOol00`80Oomoo`21Ool00`80Oomoo`1Z
Ool00`80Oomoo`1jOol00`80Oomoo`0oOol:HaP10000015S6003001oogoo
039oo`030P1oogoo085oo`030P1oogoo06Yoo`030P1oogoo07Yoo`030P1o
ogoo03moo`YS604000004F<H00<007ooOol0<Woo00<207ooOol0PGoo00<2
07ooOol0JWoo00<207ooOol0NWoo00<207ooOol0?goo2V<H0@00000AHaP0
0`00Oomoo`0bOol00`80Oomoo`21Ool00`0OOomoo`1ZOol00`0OOomoo`1j
Ool00`80Oomoo`0oOol:HaP10000015S6003001oogoo039oo`030P1oogoo
085oo`0301moogoo06Yoo`0301moogoo07Yoo`030P1oogoo03moo`YS6040
00004F<H00<007ooOol0<Woo00<207ooOol0PGoo00<07gooOol0JWoo00<0
7gooOol0NWoo00<207ooOol0?goo2V<H0@00000AHaP00`00Oomoo`0bOol0
0`80Oomoo`21Ool00`0OOomoo`1ZOol00`0OOomoo`1jOol00`80Oomoo`0o
Ool:HaP10000015S6003001oogoo039oo`030P1oogoo085oo`0301moogoo
06Yoo`0301moogoo07Yoo`030P1oogoo03moo`YS604000004F<H00<007oo
Ool0<Woo00<207ooOol0PGoo00<07gooOol0JWoo00<07gooOol0NWoo00<2
07ooOol0?goo2V<H0@00000AHaP00`00Oomoo`0aOol00`0O001oo`22Ool0
0`0OOomoo`1ZOol00`0OOomoo`1jOol00`80Oomoo`0oOol:HaP10000015S
6003001oogoo031oo`@07h9oo`0301moogoo06Yoo`0301moogoo07Yoo`03
0P1oogoo03moo`YS604000004F<H00<007ooOol0<7oo100OP7oo100OJWoo
0`0ONgoo00<207ooOol0?goo2V<H0@00000AHaP00`00Oomoo`0aOol201mo
Ool301l20P0401mTOol301l20P0017oo01l07`0ON7oo00<207ooOol0?goo
2V<H0@00000AHaP00`00Oomoo`0bOol00`80Oomoo`1lOol00`0OOomoo`06
Ool201mROol00`0OOomoo`06Ool201mgOol00`80Oomoo`0oOol:HaP10000
015S6003001oogoo039oo`030P1oogoo07]oo`0301moogoo00Qoo`807f1o
o`0301moogoo00Qoo`807gIoo`030P1oogoo03moo`YS604000004F<H00<0
07ooOol0<Woo00<207ooOol0NWoo00<07gooOol00goo0P0O1Goo00<07goo
Ool0GGoo00<07gooOol017oo0P0O17oo00<07gooOol0M7oo00<207ooOol0
?goo2V<H0@00000AHaP00`00Oomoo`0bOol00`80Oomoo`1jOol00`0OOomo
o`02Ool0100OOol07`0O1Goo00<07gooOol0G7oo00<07gooOol00goo100O
17oo00<07gooOol0Lgoo00<207ooOol0?goo2V<H0@00000AHaP00`00Oomo
o`0bOol00`80Oomoo`1iOol201l3Ool201l017oo01l07`0O17oo00<07goo
Ool0Fgoo0P0O17oo00D07goo01moo`0O00Aoo`0301moogoo07=oo`030P1o
ogoo03moo`YS604000004F<H00<007ooOol0<Woo00<207ooOol0NGoo00@0
7gooOomoo`807`9oo`0401moo`0O01l3Ool00`0OOomoo`1KOol0100OOomo
ogoo0P0O0Woo00@07gooOol07`=oo`0301moogoo07=oo`030P1oogoo03mo
o`YS604000004F<H00<007ooOol0<7oo100ONWoo00<07gooOol01Goo00<0
7gooOol017oo00<07gooOol0Fgoo00<07gooOol01Goo00<07gooOol017oo
00<07gooOol0Lgoo00<207ooOol0?goo2V<H0@00000AHaP00`00Oomoo`0]
Ool301l3Ool301mhOol201l6Ool00`0OOomoo`04Ool00`0OOomoo`1KOol2
01l6Ool00`0OOomoo`04Ool00`0OOomoo`1cOol00`80Oomoo`0oOol:HaP1
0000015S6003001oogoo02aoo`807`Qoo`0301moogoo07Ioo`0301moogoo
00Aoo`0301moogoo00Aoo`0301moogoo05aoo`0301moogoo00Aoo`0301mo
ogoo00Aoo`0301moogoo07=oo`030P1oogoo03moo`YS604000004F<H00<0
07ooOol0:goo0P0O17oo0P8017oo00<07gooOol0MGoo00<07gooOol017oo
00<07gooOol00goo00<07gooOol0GGoo00<07gooOol017oo00<07gooOol0
0goo00<07gooOol0M7oo00<207ooOol0?goo2V<H0@00000AHaP00`00Oomo
o`0[Ool00`0OOomoo`0:Ool00`0OOomoo`1eOol00`0OOomoo`08Ool201mP
Ool00`0OOomoo`08Ool201mfOol00`80Oomoo`0oOol:HaP10000015S6003
001oogoo02Yoo`0301moogoo00]oo`0301moogoo07Ioo`0501moogooOol2
0004Ool201mROol00`0OOomoo`02Ool01080Oomoogoo0P0OMgoo00<207oo
Ool0?goo2V<H0@00000AHaP00`00Oomoo`0ZOol00`0OOomoo`0;Ool00`0O
Oomoo`1gOol201l00`000P02000401mTOol301l30P0301mhOol00`80Oomo
o`0oOol:HaP10000015S6003001oogoo02Yoo`0301moogoo00aoo`0301mo
ogoo07Qoo`0401l0000O01mZOol00`0O00007`1kOol00`80Oomoo`0oOol:
HaP10000015S6003001oogoo02Yoo`0301moogoo00aoo`0301moogoo071o
o`0401moogoo01l6Ool00`0OOomoo`1POol00`0OOol07`0201l5Ool00`0O
Oomoo`1jOol00`80Oomoo`0oOol:HaP10000015S6003001oogoo02Yoo`03
01moogoo00]oo`0301moogoo075oo`0401moogoo01l6Ool00`0OOomoo`1P
Ool0100OOomoo`0O1Woo00<07gooOol0NWoo00<207ooOol0?goo2V<H0@00
000AHaP00`00Oomoo`0ZOol00`0OOomoo`0;Ool00`0OOomoo`1aOol0100O
Oomoo`0O1Woo00<07gooOol0H7oo00D07gooOomoo`0O00Eoo`0301moogoo
07Yoo`030P1oogoo03moo`YS604000004F<H00<007ooOol0:goo00<07goo
Ool00goo00<207ooOol017oo00<07gooOol0LGoo00@07gooOol07`Ioo`03
01moogoo061oo`0501moogooOol07`05Ool00`0OOomoo`1jOol00`80Oomo
o`0oOol:HaP10000015S6003001oogoo02]oo`807`=oo`<200Aoo`0301mo
ogoo079oo`0401moo`0O01l6Ool00`0OOomoo`1POol01@0OOol07goo01l0
1Goo00<07gooOol0NWoo00<207ooOol0?goo2V<H0@00000AHaP00`00Oomo
o`0/Ool201l3Ool00`80Oomoo`02Ool00`0OOomoo`1cOol0100OOomoo`0O
1Woo00<07gooOol0H7oo00<07goo01l00P0O1Goo00<07gooOol0NWoo00<2
07ooOol0?goo2V<H0@00000AHaP00`00Oomoo`0]Ool301l3Ool301n0Ool0
0`0OOomoo`1ZOol00`0OOomoo`1jOol00`80Oomoo`0oOol:HaP10000015S
6003001oogoo031oo`@07`9oo`0301moogoo00807`=oo`0301moogoo07Eo
o`030P1oogoo06Yoo`03001oogoo07Yoo`030P1oogoo03moo`YS60400000
4F<H00<007ooOol0<Woo00<07gooOol00P0O0Woo0P0O0Woo0P0OMgoo00<2
07ooOol0JWoo00<207ooOol0NWoo00<207ooOol0?goo2V<H0@00000AHaP0
0`00Oomoo`0bOol00`0OOomoo`0301l017oo01l07goo0`0OMgoo00<207oo
Ool0JWoo00<207ooOol0NWoo00<207ooOol0?goo2V<H0@00000AHaP00`00
Oomoo`0bOol01`0OOomoo`0OOol07goo00807`04Ool07goo01mgOol00`80
Oomoo`1ZOol00`80Oomoo`1jOol00`80Oomoo`0oOol:HaP10000015S6003
001oogoo039oo`0301moo`0O009oo`0301moo`0O00807`9oo`0301moogoo
07Eoo`030P1oogoo06Yoo`030P1oogoo07Yoo`030P1oogoo03moo`YS6040
00004F<H00<007ooOol0<Woo00<07goo01l00goo100O0Woo00<07gooOol0
MGoo00<207ooOol0JWoo00<207ooOol0NWoo00<207ooOol0?goo2V<H0@00
000AHaP00`00Oomoo`0bOol00`0OOomoo`21Ool00`80Oomoo`1ZOol00`80
Oomoo`1jOol00`80Oomoo`0oOol:HaP10000015S6003001oogoo039oo`03
01moogoo085oo`030P1oogoo06Yoo`030P1oogoo07Yoo`030P1oogoo03mo
o`YS604000004F<H00<007ooOol0<Woo00<007ooOol0PGoo00<207ooOol0
JWoo00<207ooOol0NWoo00<207ooOol0?goo2V<H0@00000AHaP00`00Oomo
o`0bOol00`80Oomoo`21Ool00`80Oomoo`1ZOol00`80Oomoo`1jOol00`80
Oomoo`0oOol:HaP10000015S6003001oogoo039oo`030P1oogoo085oo`03
0P1oogoo06Yoo`030P1oogoo07Yoo`030P1oogoo03moo`YS604000004F<H
00<007ooOol0<Woo00<207ooOol0PGoo00<207ooOol0JWoo00<207ooOol0
NWoo00<207ooOol0?goo2V<H0@00000AHaP00`00Oomoo`0bOol00`80Oomo
o`21Ool00`80Oomoo`1ZOol00`80Oomoo`1jOol00`80Oomoo`0oOol:HaP1
0000015S6003001oogoo039oo`030P1oogoo085oo`030P1oogoo06Yoo`03
0P1oogoo07Yoo`030P1oogoo03moo`YS604000004F<H00<007ooOol0<Woo
00<207ooOol0PGoo00<207ooOol0JWoo00<207ooOol0NWoo00<207ooOol0
?goo2V<H0@00000AHaP00`00Oomoo`0bOol00`80Oomoo`21Ool00`80Oomo
o`1ZOol00`80Oomoo`1jOol00`80Oomoo`0oOol:HaP10000015S6003001o
ogoo039oo`030P1oogoo085oo`030P1oogoo06Yoo`030P1oogoo07Yoo`03
0P1oogoo03moo`YS604000004F<H00<007ooOol0<Woo00<207ooOol0PGoo
00<207ooOol0JWoo00<207ooOol0NWoo00<207ooOol0?goo2V<H0@00000A
HaP00`00Oomoo`0bOol00`80Oomoo`21Ool00`80Oomoo`1ZOol00`80Oomo
o`1jOol00`80Oomoo`0oOol:HaP10000015S6003001oogoo039oo`030P1o
ogoo085oo`030P1oogoo06Yoo`030P1oogoo07Yoo`030P1oogoo03moo`YS
604000004F<H00<007ooOol0<Woo00<207ooOol0PGoo00<207ooOol0JWoo
00<207ooOol0NWoo00<207ooOol0?goo2V<H0@00000AHaP00`00Oomoo`0b
Ool00`80Oomoo`21Ool00`80Oomoo`1ZOol00`80Oomoo`1jOol00`80Oomo
o`0oOol:HaP10000015S6003001oogoo039oo`030P1oogoo085oo`030P1o
ogoo06Yoo`030P1oogoo07Yoo`030P1oogoo03moo`YS604000004F<H00<0
07ooOol0<Woo00<207ooOol0PGoo00<207ooOol0JWoo00<207ooOol0NWoo
00<207ooOol0?goo2V<H0@00000AHaP00`00Oomoo`0bOol00`80Oomoo`21
Ool00`80Oomoo`1ZOol00`80Oomoo`1jOol00`80Oomoo`0oOol:HaP10000
015S6003001oogoo039oo`030P1oogoo085oo`030P1oogoo06Yoo`030P1o
ogoo07Yoo`030P1oogoo03moo`YS604000004F<H00<007ooOol0<Woo00<2
07ooOol0PGoo00<207ooOol0JWoo00<207ooOol0NWoo00<207ooOol0?goo
2V<H0@00000AHaP00`00Oomoo`0bOol00`80Oomoo`21Ool00`80Oomoo`1Z
Ool00`80Oomoo`1jOol00`80Oomoo`0oOol:HaP10000015S6003001oogoo
039oo`030P1oogoo085oo`030P1oogoo06Yoo`030P1oogoo07Yoo`030P1o
ogoo03moo`YS604000004F<H00<007ooOol0<Woo00<207ooOol0PGoo00<2
07ooOol0JWoo00<207ooOol0NWoo00<207ooOol0?goo2V<H0@00000AHaP0
0`00Oomoo`0bOol00`80Oomoo`21Ool00`80Oomoo`1ZOol00`80Oomoo`1j
Ool00`80Oomoo`0oOol:HaP10000015S6003001oogoo039oo`030P1oogoo
085oo`030P1oogoo06Yoo`030P1oogoo07Yoo`030P1oogoo03moo`YS6040
00004F<H00<007ooOol0<Woo00<207ooOol0PGoo00<207ooOol0JWoo00<2
07ooOol0NWoo00<07gooOol0?goo2V<H0@00000AHaP00`00Oomoo`0bOol0
0`80Oomoo`21Ool00`80Oomoo`1ZOol00`80Oomoo`1jOol00`0OOomoo`0o
Ool:HaP10000015S6003001oogoo039oo`030P1oogoo085oo`030P1oogoo
06Yoo`030P1oogoo07Yoo`0301moogoo03moo`YS604000004F<H00<007oo
Ool0<Woo00<207ooOol0PGoo00<207ooOol0JWoo00<207ooOol0NWoo00<0
7gooOol0?goo2V<H0@00000AHaP00`00Oomoo`0bOol00`80Oomoo`21Ool0
0`80Oomoo`1ZOol00`80Oomoo`1jOol00`0OOomoo`0oOol:HaP10000015S
6003001oogoo039oo`030P1oogoo085oo`030P1oogoo06Yoo`030P1oogoo
07Yoo`0301moogoo03moo`YS604000004F<H00<007ooOol0<Woo00<207oo
Ool0P7oo0P0OK7oo00<207ooOol0NWoo00<07gooOol0?goo2V<H0@00000A
HaP00`00Oomoo`0bOol00`80Oomoo`1ZOol00`000P02000B0P00100001l0
7`005@8000<007ooOol0Dgoo00<207ooOol0_7oo2V<H0@00000AHaP00`00
Oomoo`0bOol00`80Oomoo`1ZOol00`0OOomoo`0COol201lFOol00`0OOomo
o`1COol00`80Oomoo`1gOol601loOol:HaP10000015S6003001oogoo039o
o`030P1oogoo06Yoo`0301moogoo00Uoo`<07amoo`0301moogoo05=oo`03
0P1oogoo07Eoo`807`Ioo`807ceoo`YS604000004F<H00<007ooOol0<Woo
00<207ooOol0JWoo00<07gooOol02Woo00<07gooOol07Woo00<07gooOol0
Dgoo00<207ooOol0M7oo0P0O0goo0P800goo0P0O?7oo2V<H0@00000AHaP0
0`00Oomoo`0bOol00`80Oomoo`1ZOol00`0OOomoo`0;Ool00`0OOomoo`0M
Ool00`0OOomoo`1COol00`80Oomoo`1dOol00`0OOomoo`08Ool00`0OOomo
o`0jOol:HaP10000015S6003001oogoo039oo`030P1oogoo06Yoo`0301mo
ogoo00]oo`0301moogoo01eoo`0301moogoo00ioo`X07`9ooa807bMoo`03
0P1oogoo07=oo`0301moogoo00Yoo`0301moogoo03Uoo`YS604000004F<H
00<007ooOol0<Woo00<207ooOol0JWoo00<07gooOol02Goo00<07goo01l0
7goo00<07gooOol03Goo0P0O00Eoo`0O01l07goo00807`04Ool07gooOol2
01l00goo01l07`02Ool201l2Ool201l2Ool201lXOol00`80Oomoo`1cOol0
0`0OOomoo`0:Ool00`0OOomoo`0iOol:HaP10000015S6003001oogoo039o
o`030P1oogoo06Yoo`0301moogoo00Uoo`<07amoo`0301moogoo00eoo`03
01moogoo009oo`0:01moogoo01moo`0OOol07goo01l2Ool01@0OOomoogoo
01l00goo00D07gooOomoo`0O02Qoo`030P1oogoo079oo`807`aoo`0301mo
ogoo03Uoo`YS604000004F<H00<007ooOol0<Woo00<207ooOol0JGoo00<2
000OOol0;7oo00<00080Ool03Goo00<07gooOol00Woo00@07gooOomoo`@0
7`03Ool07goo009oo`0501moogooOol07`03Ool01@0OOomoogoo01l09goo
00<207ooOol0LWoo00<07gooOol037oo00<07gooOol0>7oo2V<H0@00000A
HaP00`00Oomoo`0bOol00`80Oomoo`1QOol00`80Oomoo`050P0`Ool50P02
Ool00`80Oomoo`06Ool01P0OOomoo`0OOol07`9oo`<07`9oo`807`9oo`80
7`9oo`807`9oo`807`9oo`0301moogoo02Eoo`030P1oogoo079oo`0301mo
ogoo00aoo`0301moogoo03Qoo`YS604000004F<H00<007ooOol0<Woo00<2
07ooOol0HGoo0`8000Aoo`800P0203=oo`H200Uoo`807`=oo`807`03Ool0
7goo009oo`0401moo`0O01l2Ool201l2Ool201l2Ool201lXOol00`80Oomo
o`1bOol201l<Ool00`0OOomoo`0iOol:HaP10000015S6003001oogoo039o
o`030P1oogoo065oo`060P1oo`800P1oo`80=7oo1P80CGoo00<207ooOol0
Lgoo00<07gooOol02Woo00<07gooOol0>Goo2V<H0@00000AHaP00`00Oomo
o`0bOol00`80Oomoo`1QOol20P02Ool00`80Oomoo`0VOol00`0OOomoo`03
01l8Ool20P000goo0P02001=Ool00`80Oomoo`1cOol00`0OOomoo`03Ool0
0`80Oomoo`04Ool00`0OOomoo`0iOol:HaP10000015S6003001oogoo039o
o`030P1oogoo065oo`030P1oogoo02Yoo`0301moogoo00807`eoo`030P1o
ogoo04]oo`030P1oogoo07Aoo`0401moogooOol30P04Ool00`0OOomoo`0j
Ool:HaP10000015S6003001oogoo039oo`030P1oogoo065oo`030P1oogoo
00aoo`0501moogooOol07`0IOol0100OOomoogoo0P0O37oo00<207ooOol0
Bgoo00<207ooOol0MGoo00D07gooOomoo`8000Aoo`0301moogoo03]oo`YS
604000004F<H00<007ooOol0<Woo00<207ooOol0HGoo00<207ooOol037oo
00D07gooOomoo`0O01Uoo`0301moogoo009oo`0301moogoo00Yoo`030P1o
ogoo02=oo`807bEoo`<07gMoo`<07`9oo`<07cioo`YS604000004F<H00<0
07ooOol0<WooG@8000<0000O01l0100O00<007ooOol037oo00D07gooOomo
o`0O01Uoo`0601moogoo01moo`0O37oo00<2000O01l01@0O00<000800P00
6P8000@0000O01l002@200@07gQoo`D07`9oo`@07`9oo`@07c=oo`YS6040
00004F<H00<007ooOol0UWoo00<207ooOol037oo00D07gooOomoo`0O01Mo
o`P07`aoo`030P1oogoo02=oo`807bEoo`H07gQoo`0601moo`0O01moo`0O
0goo0`0O0goo00<07gooOol0<7oo2V<H0@00000AHaP00`00Oomoo`2FOol0
0`80Oomoo`0<Ool00`0OOomoo`0201l[Ool00`80Oomoo`0TOol00`80Oomo
o`0UOol00`0OOomoo`0301mfOol401l00goo01moo`03Ool201l3Ool00`0O
Oomoo`0`Ool:HaP10000015S6003001oogoo069oo`0301moogoo035oo`03
0P1oogoo00Yoo`D07`03Ool07goo02Yoo`030P1oogoo02Aoo`030P1oogoo
02Ioo`0501moogooOol07`1fOol201l017oo01moo`0O17oo0P0O0goo00<0
7gooOol0<7oo2V<H0@00000AHaP00`00Oomoo`1ROol00`0OOomoo`0aOol3
0P0jOol30P0VOol00`80Oomoo`0VOol0100OOomoo`0OMgoo0P0O0Woo0P0O
17oo0P0O0goo00<07gooOol0<7oo2V<H0@00000AHaP00`00Oomoo`1ROol0
0`0OOomoo`0aOol00`80Oomoo`020P0fOol30P000goo0P1oo`0UOol00`80
Oomoo`0WOol401mfOol0100OOomoogoo1P0O00=oo`0O01l00`0O<Woo2V<H
0@00000AHaP00`00Oomoo`1ROol00`0OOomoo`0aOol00`80Oomoo`02Ool2
0P0bOol30P03Ool00`80Oomoo`0TOol00`80Oomoo`0WOol00`0OOomoo`02
01meOol00`0OOomoo`0oOol:HaP10000015S6003001oogoo065oo`807c=o
o`030P1oogoo00Aoo`8202ioo`<200Eoo`030P1oogoo02Aoo`030P1oogoo
02]oo`807gAoo`03001oogoo03moo`YS604000004F<H00<007ooOol0HWoo
00<07gooOol0>Woo00<07gooOol0:goo00<07gooOol0;7oo00<207ooOol0
;7oo0P0OLgoo00<207ooOol0?goo2V<H0@00000AHaP00`00Oomoo`2OOol0
0`0OOomoo`0[Ool00`0OOomoo`0/Ool00`80Oomoo`0@Ool0100OOomoogoo
0`0O0goo0P0O0goo00<07gooOol02goo0P0OLWoo00<207ooOol0?goo2V<H
0@00000AHaP00`00Oomoo`2OOol00`0OOomoo`0[Ool00`0OOomoo`0/Ool0
0`80Oomoo`0?Ool201l2Ool201l01Goo01l07goo01l00Woo00@07gooOol0
7`ioo`807g5oo`030P1oogoo03moo`YS604000004F<H00<007ooOol0Wgoo
00<07gooOol0:goo00<07gooOol0;7oo00<207ooOol03goo0`0O00=oo`0O
Ool00Woo00<07goo01l00Woo00@07gooOol07`moo`807g1oo`030P1oogoo
03moo`YS604000004F<H00<007ooOol0Wgoo00<07gooOol0:goo00<07goo
Ool0;7oo00<207ooOol03goo00D07goo01moo`0O00=oo`0301moo`0O009o
o`0401moogoo01l@Ool601m[Ool00`80Oomoo`0oOol:HaP10000015S6003
001oogoo07Qoo`@07`06Ool07`0O01moo`0O0Woo00<07goo01l00P0O00Eo
o`0O01l07goo00<07`04Ool07`0O01l:Ool00`0OOomoo`0[Ool00`0OOomo
o`0/Ool00`80Oomoo`0>Ool01P0OOomoo`0OOol07`=oo`0301moo`0O009o
o`0401moogoo01lAOol00`0OOomoo`02Ool00`0OOomoo`1XOol00`80Oomo
o`0oOol:HaP10000015S6003001oogoo07Moo`D07`03Ool07`0O009oo`05
01moo`0O01moo`0201l2Ool201l2Ool201l2Ool201l;Ool00`0OOomoo`0[
Ool00`0OOomoo`0/Ool00`80Oomoo`0>Ool0100OOomoogoo1P0O00Aoo`0O
Oomoo`L07`eoo`0601moo`0OOol07goo0P0OJGoo00<207ooOol0?goo2V<H
0@00000AHaP00`00Oomoo`1gOol01@0OOomoogoo01l00Woo0P0O00=oo`0O
Ool00P0O0Woo0P0O0Woo0P0O0Woo0P0O0Woo0P0O2Woo00<07gooOol0:goo
00<07gooOol0;7oo00<207ooOol0<7oo0`0O00=oo`0O01l00P0OJGoo00<2
07ooOol0?goo2V<H0@00000AHaP00`00Oomoo`1gOol01@0OOomoogoo01l0
0goo00H07goo01l07goo01l3Ool01@0OOomoogoo01l00goo00D07gooOomo
o`0O00Yoo`030P1oogoo02]oo`030P1oogoo02aoo`030P1oogoo031oo`P0
7fUoo`030P1oogoo03moo`YS604000004F<H00<007ooOol0Mgoo00X07goo
Oomoo`0OOol07goo01moo`807`0BOol07goo01moo`0OOol07goo01moo`0O
Ool07goo01moo`0O2Woo00<207ooOol0:goo00<207ooOol0;7oo00<207oo
Ool0<7oo00<07gooOol017oo00<07gooOol0Igoo00<207ooOol0?goo2V<H
0@00000AHaP00`00Oomoo`1gOol501l01Woo01l07`0OOol07`9oo`0301mo
o`0O00807`05Ool07`0O01moo`0301l017oo01l07`0O2Woo00<207ooOol0
:goo00<207ooOol0;7oo00<207ooOol0<Goo00<07gooOol00Woo00<07goo
Ool0J7oo00<207ooOol0?goo2V<H0@00000AHaP00`00Oomoo`2OOol00`80
Oomoo`0[Ool00`80Oomoo`0/Ool00`80Oomoo`0bOol401m[Ool00`80Oomo
o`0oOol:HaP10000015S6003001oogoo09moo`030P1oogoo02]oo`030P1o
ogoo02aoo`030P1oogoo0:5oo`030P1oogoo03moo`YS604000004F<H00<0
07ooOol0Wgoo00<207ooOol0:goo00<207ooOol0;7oo00<207ooOol0XGoo
00<207ooOol0?goo2V<H0@00000AHaP00`00Oomoo`2OOol00`80Oomoo`0[
Ool00`80Oomoo`0/Ool00`80Oomoo`2QOol00`80Oomoo`0oOol:HaP10000
015S6003001oogoo09moo`030P1oogoo02]oo`030P1oogoo02aoo`030P1o
ogoo0:5oo`030P1oogoo03moo`YS604000004F<H00<007ooOol0Wgoo00<2
07ooOol0:goo00<207ooOol0;7oo00<207ooOol0XGoo00<207ooOol0?goo
2V<H0@00000AHaP00`00Oomoo`2OOol00`80Oomoo`0[Ool00`80Oomoo`0/
Ool00`80Oomoo`2QOol00`80Oomoo`0oOol:HaP10000015S6003001oogoo
09moo`030P1oogoo02]oo`030P1oogoo02aoo`030P1oogoo0:5oo`030P1o
ogoo03moo`YS604000004F<H00<007ooOol0Wgoo00<207ooOol0:goo00<2
07ooOol0;7oo00<207ooOol0XGoo00<207ooOol0?goo2V<H0@00000AHaP0
0`00Oomoo`2OOol00`80Oomoo`0[Ool00`80Oomoo`0/Ool00`80Oomoo`2Q
Ool00`80Oomoo`0oOol:HaP10000015S6003001oogoo09moo`030P1oogoo
02]oo`030P1oogoo02aoo`030P1oogoo0:5oo`030P1oogoo03moo`YS6040
00004F<H00<007ooOol0Wgoo00<207ooOol0:goo00<207ooOol0;7oo00<2
07ooOol0XGoo00<207ooOol0?goo2V<H0@00000AHaP00`00Oomoo`2OOol0
0`80Oomoo`0[Ool00`80Oomoo`0/Ool00`80Oomoo`2QOol00`80Oomoo`0o
Ool:HaP10000015S6003001oogoo09moo`030P1oogoo02]oo`030P1oogoo
02aoo`030P1oogoo0:5oo`030P1oogoo03moo`YS604000004F<H00<007oo
Ool0Wgoo00<207ooOol0:goo00<207ooOol0;7oo00<207ooOol0XGoo00<2
07ooOol0?goo2V<H0@00000AHaP00`00Oomoo`2OOol00`80Oomoo`0[Ool0
0`80Oomoo`0/Ool00`80Oomoo`2QOol00`80Oomoo`0oOol:HaP10000015S
6003001oogoo09moo`030P1oogoo02]oo`030P1oogoo02aoo`030P1oogoo
0:5oo`030P1oogoo03moo`YS604000004F<H00<007ooOol0Wgoo00<207oo
Ool0:goo00<207ooOol0;7oo00<207ooOol0XGoo00<207ooOol0?goo2V<H
0@00000AHaP00`00Oomoo`2OOol00`80Oomoo`0[Ool00`80Oomoo`0/Ool0
0`80Oomoo`2QOol00`80Oomoo`0oOol:HaP10000015S6003001oogoo09mo
o`030P1oogoo02]oo`030P1oogoo02aoo`030P1oogoo0:5oo`030P1oogoo
03moo`YS604000004F<H00<007ooOol0Wgoo00<207ooOol0:goo00<207oo
Ool0;7oo00<207ooOol0XGoo00<207ooOol0?goo2V<H0@00000AHaP00`00
Oomoo`2OOol00`80Oomoo`0[Ool00`80Oomoo`0/Ool00`80Oomoo`2QOol0
0`80Oomoo`0oOol:HaP10000015S6003001oogoo09moo`030P1oogoo02]o
o`030P1oogoo02aoo`030P1oogoo0:5oo`030P1oogoo03moo`YS60400000
4F<H00<007ooOol0Wgoo00<207ooOol0:goo00<207ooOol0;7oo00<207oo
Ool0XGoo00<207ooOol0?goo2V<H0@00000AHaP00`00Oomoo`2OOol00`80
Oomoo`0[Ool00`80Oomoo`0/Ool00`80Oomoo`2QOol00`80Oomoo`0oOol:
HaP10000015S6003001oogoo09moo`030P1oogoo02]oo`030P1oogoo02ao
o`030P1oogoo0:5oo`030P1oogoo03moo`YS604000004F<H00<007ooOol0
Wgoo00<207ooOol0:goo00<207ooOol0;7oo00<207ooOol0XGoo00<207oo
Ool0?goo2V<H0@00000AHaP00`00Oomoo`2OOol00`80Oomoo`0[Ool00`80
Oomoo`0/Ool00`80Oomoo`2QOol00`80Oomoo`0oOol:HaP10000015S6003
001oogoo09moo`030P1oogoo02]oo`030P1oogoo02aoo`030P1oogoo0:5o
o`030P1oogoo03moo`YS604000004F<H00<007ooOol0Wgoo00<207ooOol0
:goo00<207ooOol0;7oo00<207ooOol0XGoo00<207ooOol0?goo2V<H0@00
000AHaP00`00Oomoo`2OOol00`80Oomoo`0[Ool00`80Oomoo`0/Ool00`80
Oomoo`2QOol00`80Oomoo`0oOol:HaP10000015S6003001oogoo09moo`03
0P1oogoo02]oo`030P1oogoo02aoo`030P1oogoo0:5oo`030P1oogoo03mo
o`YS604000004F<H00<007ooOol0Wgoo00<207ooOol0:goo00<207ooOol0
;7oo00<207ooOol0XGoo00<207ooOol0?goo2V<H0@00000AHaP00`00Oomo
o`2OOol00`80Oomoo`0[Ool00`80Oomoo`0/Ool00`80Oomoo`2QOol00`80
Oomoo`0oOol:HaP10000015S6003001oogoo09moo`030P1oogoo02]oo`03
0P1oogoo02aoo`030P1oogoo0:5oo`030P1oogoo03moo`YS604000004F<H
00<007ooOol0Wgoo00<207ooOol0:goo00<207ooOol0;7oo00<207ooOol0
XGoo00<207ooOol0?goo2V<H0@00000AHaP00`00Oomoo`2OOol00`80Oomo
o`0[Ool00`80Oomoo`0/Ool00`80Oomoo`2QOol00`80Oomoo`0oOol:HaP1
0000015S6003001oogoo09moo`030P1oogoo02]oo`030P1oogoo02aoo`03
0P1oogoo0:5oo`030P1oogoo03moo`YS604000004F<H00<007ooOol0Wgoo
00<207ooOol0:goo00<207ooOol0;7oo00<207ooOol0XGoo00<207ooOol0
?goo2V<H0@00000AHaP00`00Oomoo`2OOol00`80Oomoo`0[Ool00`80Oomo
o`0/Ool00`80Oomoo`2QOol00`80Oomoo`0oOol:HaP10000015S6003001o
ogoo09moo`030P1oo`0O00807bUoo`030P1oogoo02aoo`030P1oogoo0:5o
o`030P1oogoo03moo`YS604000004F<H00<007ooOol0Wgoo00D207oo01mo
o`0O02Uoo`030P1oogoo02aoo`030P1oogoo0:5oo`030P1oogoo03moo`YS
604000004F<H00<007ooOol0Wgoo00<207ooOol00P0O:Goo00<207ooOol0
;7oo00<207ooOol0XGoo00<207ooOol0?goo2V<H0@00000AHaP00`00Oomo
o`2OOol01@80Oomoogoo01l0:Goo00<207ooOol0;7oo00<207ooOol0XGoo
00<207ooOol0?goo2V<H0@00000AHaP00`00Oomoo`2OOol01@80Ool07goo
01l0:Goo00<207ooOol0;7oo00<207ooOol0XGoo00<207ooOol0?goo2V<H
0@00000AHaP00`00Oomoo`2OOol00`80Ool07`0201lYOol00`80Oomoo`0/
Ool00`80Oomoo`2QOol00`80Oomoo`0oOol:HaP10000015S6003001oogoo
09moo`030P1oogoo02]oo`030P1oogoo02aoo`030P1oogoo0:5oo`030P1o
ogoo03moo`YS604000004F<H00<007ooOol0Wgoo00<207ooOol0:goo00<2
07ooOol0;7oo00<207ooOol0XGoo00<207ooOol0?goo2V<H0@00000AHaP0
0`00Oomoo`2OOol00`80Oomoo`0[Ool01@80Oomoogoo01l0:Woo00<207oo
Ool0XGoo00<207ooOol0?goo2V<H0@00000AHaP00`00Oomoo`2OOol00`80
Oomoo`0[Ool00`80Ool07`0301lYOol00`80Oomoo`2QOol00`80Oomoo`0o
Ool:HaP10000015S6003001oogoo09moo`030P1oogoo02]oo`050P1oo`0O
Ool07`0ZOol00`80Oomoo`2QOol00`80Oomoo`0oOol:HaP10000015S6003
001oogoo09moo`030P1oogoo02]oo`030P1oogoo00807bYoo`030P1oogoo
0:5oo`030P1oogoo03moo`YS604000004F<H00<007ooOol0Wgoo00<207oo
Ool0:goo00<207ooOol00P0O:Woo00<207ooOol0XGoo00<207ooOol0?goo
2V<H0@00000AHaP00`00Oomoo`2OOol00`80Oomoo`0[Ool01@80Oomoogoo
01l0:Woo00<207ooOol0XGoo00<207ooOol0?goo2V<H0@00000AHaP00`00
Oomoo`2OOol00`80Oomoo`0[Ool00`80Oomoo`0/Ool00`80Oomoo`2QOol0
0`80Oomoo`0oOol:HaP10000015S6003001oogoo09moo`030P1oogoo02]o
o`030P1oogoo02aoo`030P1oogoo0:5oo`030P1oogoo03moo`YS60400000
4F<H00<007ooOol0Wgoo00<207ooOol0:goo00<207ooOol0;7oo00<207oo
Ool0XGoo00<207ooOol0?goo2V<H0@00000AHaP00`00Oomoo`2OOol00`80
Oomoo`0[Ool00`80Oomoo`0/Ool00`80Oomoo`2QOol00`80Oomoo`0oOol:
HaP10000015S6003001oogoo09moo`030P1oogoo02]oo`030P1oogoo02ao
o`030P1oogoo0:5oo`030P1oogoo03moo`YS604000004F<H00<007ooOol0
Wgoo00<207ooOol0:goo00<207ooOol0;7oo00<207ooOol0XGoo00<207oo
Ool0?goo2V<H0@00000AHaP00`00Oomoo`2OOol00`80Oomoo`0[Ool00`80
Oomoo`0/Ool00`80Oomoo`2QOol00`80Oomoo`0oOol:HaP10000015S6003
001oogoo09moo`030P1oogoo02]oo`030P1oogoo02aoo`030P1oogoo0:5o
o`030P1oogoo03moo`YS604000004F<H00<007ooOol0Wgoo00<207ooOol0
:goo00<207ooOol0;7oo00<207ooOol0XGoo00<207ooOol0?goo2V<H0@00
000AHaP00`00Oomoo`2OOol00`80Oomoo`0[Ool00`80Oomoo`0/Ool00`80
Oomoo`2QOol00`80Oomoo`0oOol:HaP10000015S6003001oogoo09moo`03
0P1oogoo02]oo`030P1oogoo02aoo`030P1oogoo0:5oo`030P1oogoo03mo
o`YS604000004F<H00<007ooOol0Wgoo00<207ooOol0:goo00<207ooOol0
;7oo00<207ooOol0XGoo00<207ooOol0?goo2V<H0@00000AHaP00`00Oomo
o`2OOol00`80Oomoo`0[Ool00`80Oomoo`0/Ool00`80Oomoo`2QOol00`80
Oomoo`0oOol:HaP10000015S6003001oogoo09moo`030P1oogoo02]oo`03
0P1oogoo02aoo`0301moogoo0:5oo`030P1oogoo03moo`YS604000004F<H
00<007ooOol0Wgoo00<207ooOol0:goo00<207ooOol0;7oo00<07gooOol0
XGoo00<207ooOol0?goo2V<H0@00000AHaP00`00Oomoo`2OOol00`80Oomo
o`0[Ool00`80Oomoo`0/Ool00`0OOomoo`2QOol00`80Oomoo`0oOol:HaP1
0000015S6003001oogoo09moo`030P1oogoo02]oo`030P1oogoo02aoo`03
01moogoo0:5oo`030P1oogoo03moo`YS604000004F<H00<007ooOol0Wgoo
00<207ooOol0:goo00<207ooOol0;7oo00<07gooOol0XGoo00<207ooOol0
?goo2V<H0@00000AHaP00`00Oomoo`2OOol00`80Oomoo`0[Ool00`80Oomo
o`0/Ool00`0OOomoo`2QOol00`80Oomoo`0oOol:HaP10000015S6003001o
ogoo09moo`030P1oogoo02]oo`030P1oogoo02aoo`0301moogoo0:5oo`03
0P1oogoo03moo`YS604000004F<H00<007ooOol0Wgoo00<207ooOol0:goo
00<207ooOol0;7oo00<07gooOol0XGoo00<207ooOol0?goo2V<H0@00000A
HaP00`00Oomoo`2OOol00`80Oomoo`0[Ool00`80Oomoo`0TOol00`80Oomo
o`03Ool30P2SOol00`80Oomoo`0oOol:HaP10000015S6003001oogoo09mo
o`030P1oogoo02]oo`030P1oogoo02Aoo`040P1oogooOol30P2UOol00`80
Oomoo`0oOol:HaP10000009S60m24003001oogoo09moo`030P1oogoo02]o
o`030P1oogoo02Aoo`040P1oo`800P2XOol00`80Oomoo`0oOol:HaP10000
015S6003001oogoo09moo`030P1oogoo02]oo`030P1oogoo02Aoo`820:Yo
o`030P1oogoo03moo`YS604000004F<H00<007ooOol0Wgoo00<207ooOol0
:goo00<207ooOol097oo00<207ooOol04Goo00<07gooOol00`0OTWoo00<2
07ooOol0?goo2V<H0@00000AHaP00`00Oomoo`2OOol00`80Oomoo`0[Ool0
0`80Oomoo`0TOol00`80Oomoo`0AOol01P0OOomoo`0OOol07i9oo`030P1o
ogoo03moo`YS6040000016<H300000=S6000Ool0Wgoo00<07`00Ool0;7oo
00<207ooOol097oo00<207ooOol04Goo00H07gooOol07goo01nBOol00`80
Oomoo`0oOol:HaP1000000iS6004@Q0006<H002OOol301l00`000P02001:
0P000`0001l07`0401l00`00Oomoo`0AOol00`0OOomoo`0301nBOol00`80
Oomoo`0oOol:HaP1000000ES6004@P0000000005@P00148@001S6000Wgoo
100O;7oo00<207ooOol097oo00<207ooOol04Goo00@07gooOol07iAoo`03
0P1oogoo03moo`YS604000001F<H00=20000000010000T8000A24000HaP0
0:1oo`0301l007oo02aoo`030P1oogoo02Aoo`030P1oogoo00moo`P07i9o
o`030P1oogoo03moo`YS604000001F<H0T800P80100000E2048@001S6000
0:5oo`030P1oogoo02]oo`030P1oogoo02Aoo`030P1oogoo0:Uoo`030P1o
ogoo03moo`YS604000001F<H0`000P80100000A24000HaP00:5oo`030P1o
ogoo02]oo`030P1oogoo02Aoo`030P1oogoo0:Uoo`030P1oogoo03moo`YS
604000001F<H00<060000P000P8000P0000O01l0648@001S6000XGoo00<2
07ooOol0:goo00<207ooOol097oo1P80YWoo00<207ooOol0?goo2V<H0@00
0005HaP0100H000200800P0000Moh00001Q24000HaP0002QOol00`80Oomo
o`0[Ool00`80Oomoo`0TOol00`80Oomoo`050P2TOol00`80Oomoo`0oOol:
HaP1000000ES600=01P07`000P007`00On00000H@Q0006<H0000XGoo00<2
07ooOol0:goo00<207ooOol097oo00<207ooOol01@80Y7oo00<207ooOol0
?goo2V<H0@000005HaP00`0H01l07`0501l01@0H@Q0006<H0000XGoo00<2
07ooOol0:goo00<207ooOol0:7oo0P8000=oo`8001l0Xgoo00<207ooOol0
?goo2V<H0@00000>HaP0148@001S6000XGoo00<207ooOol0:goo00<207oo
Ool0;7oo00<07gooOol0XGoo00<207ooOol0?goo2V<H0@000004HaP<0000
0f<H001oo`2POol00`80Oomoo`0[Ool00`80Oomoo`0/Ool00`0OOomoo`2Q
Ool00`80Oomoo`0oOol:HaP1000000AS60]24003001S60000:5oo`030P1o
ogoo02]oo`030P1oogoo02aoo`0301moogoo0:5oo`030P1oogoo03moo`YS
604000003V<H00A24000HaP00:5oo`030P1oogoo02]oo`030P1oogoo02ao
o`0301moogoo0:5oo`030P1oogoo03moo`YS604000001F<H2@0000A24000
HaP00:5oo`030P1oogoo02]oo`030P1oogoo02aoo`0301moogoo0:5oo`03
0P1oogoo03moo`YS604000001F<H2@0000A24000HaP00:5oo`030P1oogoo
02]oo`030P1oogoo02aoo`0301moogoo0:5oo`030P1oogoo03moo`YS6040
00001F<H2@0000A24000HaP00:5oo`030P1oogoo02Yoo`<07beoo`0301mo
ogoo0:5oo`030P1oogoo03moo`YS604000001F<H2@0000A24000HaP00:5o
o`030P1oogoo01AooaH200<07beoo`030P1oogoo00eoo`807`03Ool07`0O
00@07`=oo`D07`03Ool07`0O009oo`<07`9oo`0301moogoo00<07g=oo`03
0P1oogoo03moo`YS604000001F<H2@0000A24000HaP00:5oo`030P1oogoo
01Aoo`030P1oogoo01=oo`<07beoo`030P1oogoo00aoo`0401moo`0O01l2
Ool0100OOomoo`0O0Woo0P0O00Eoo`0OOomoo`0O009oo`0501moo`0OOol0
7`02Ool01P0OOomoo`0OOol07g=oo`030P1oogoo03moo`YS604000001F<H
00<006<H00001P0000A24000HaP00:5oo`030P1oogoo01Aoo`030P1oogoo
01Aoo`030P1oogoo02aoo`030P1oogoo00]oo`0301moogoo009oo`0701mo
ogoo01moo`0OOol00`0O0Woo00<07gooOol00`0O00Aoo`0OOol07`9oo`03
01moogoo00<07g=oo`030P1oogoo03moo`YS604000001F<H00@006<H001S
60D00004@Q0006<H002QOol00`80Oomoo`0DOol00`80Oomoo`0DOol00`80
Oomoo`0/Ool00`80Oomoo`0;Ool00`0OOomoo`02Ool00`0OOomoo`0301l0
17oo01moo`0O0Woo0`0O00Moo`0O01moo`0OOol07`02Ool01P0OOomoo`0O
Ool07g=oo`030P1oogoo03moo`YS604000001F<H2@0000A24000HaP00:5o
o`030P1oogoo01Aoo`030P1oogoo01Aoo`030P1oogoo02aoo`030P1oogoo
00]oo`807`9oo`<07`9oo`<07`9oo`807`9oo`807`9oo`0501moo`0OOol0
7`03Ool00`0OOol07`0201mcOol00`80Oomoo`0oOol:HaP1000000iS6004
@Q0006<H002QOol00`80Oomoo`0DOol00`80Oomoo`0DOol00`80Oomoo`0/
Ool00`80Oomoo`0<Ool01P0OOomoo`0OOol07`9oo`<07`9oo`807`9oo`80
7`9oo`0501moo`0OOol07`03Ool00`0OOomoo`1eOol00`80Oomoo`0oOol:
HaP1000000AS60`00003HaP007oo0:1oo`030P1oogoo01Aoo`030P1oogoo
01Aoo`030P1oogoo02aoo`030P1oogoo00eoo`807`=oo`807`03Ool07goo
009oo`0401moo`0O01l2Ool201l2Ool301l017oo01l07`0OMgoo00<207oo
Ool0?goo2V<H0@000004HaP;@Q000`00HaP0002QOol00`80Oomoo`0DOol0
0`80Oomoo`0DOol00`80Oomoo`0/Ool00`80Oomoo`2QOol00`80Oomoo`0o
Ool:HaP1000000iS6004@Q0006<H002QOol00`00Oomoo`0DOol00`80Oomo
o`0DOol00`00Oomoo`0/Ool00`80Oomoo`2QOol00`80Oomoo`0oOol:HaP1
000000QS60<060=S6004@Q0006<H002QOol00`0OOomoo`0DOol00`80Oomo
o`0DOol00`0OOomoo`0/Ool00`80Oomoo`2QOol00`80Oomoo`0oOol:HaP1
000000MS600301P07f<H0080609S6004@Q0006<H002QOol00`0OOomoo`0D
Ool00`80Oomoo`0DOol00`0OOomoo`0/Ool00`80Oomoo`2QOol00`80Oomo
o`0oOol:HaP1000000ES609P000;01P07f<H01l00080HaQ24000HaP0002Q
Ool00`0OOomoo`0DOol00`80Oomoo`0DOol00`0OOomoo`0/Ool00`80Oomo
o`2QOol00`80Oomoo`0oOol:HaP1000000ES6006H01l06<H00007`000`80
00A24000HaP00:5oo`0301moogoo01Aoo`030P1oogoo01Aoo`0301moogoo
02aoo`030P1oogoo0:5oo`030P1oogoo03moo`YS604000001V<H0g`000=2
40800P000P8000A24000HaP00:5oo`0301moogoo01Aoo`030P1oogoo01Ao
o`0301moogoo02aoo`030P1oogoo0:5oo`030P1oogoo03moo`YS60400000
1V<H00Al06<HO01240@20004@Q0006<H002QOol00`0OOomoo`0DOol00`80
Oomoo`0DOol00`0OOomoo`0/Ool00`80Oomoo`2QOol00`80Oomoo`0oOol:
HaP1000000IS6004H01l0600HaP40P00148@001S6000XGoo00<07gooOol0
17oo00<207ooOol03Goo00<207ooOol03Goo00<207ooOol017oo00<07goo
Ool0;7oo00<207ooOol0XGoo00<207ooOol0?goo2V<H0@00000>HaP0148@
001S6000X7oo0`801Goo00<207ooOol03Goo00<207ooOol03Goo00<207oo
Ool00goo0P80;Woo00<207ooOol0XGoo00<207ooOol0?goo2V<H0@00000>
HaP0148@001S6000XWoo0`800goo00<207ooOol03Goo00<207ooOol03Goo
00<207ooOol00`80<7oo00<207ooOol0XGoo00<207ooOol0?goo2V<H0@00
0004HaP<00000f<H001oo`2TOol20P000goo0P1oo`0>Ool00`80Oomoo`0=
Ool40P0bOol00`80Oomoo`2QOol00`80Oomoo`0oOol:HaP1000000iS6004
@Q0006<H002WOol20P0?Ool00`80Oomoo`0=Ool20P0dOol00`80Oomoo`2Q
Ool00`80Oomoo`0oOol:HaP1000000iS6004@Q0006<H002XOol00`80Oomo
o`0=Ool00`80Oomoo`0=Ool00`80Oomoo`0cOol00`80Oomoo`2QOol00`80
Oomoo`0oOol:HaP1000000IS60H0009S6004@Q0006<H002DOol00`0OOomo
o`0301l>Ool00`80Oomoo`0=Ool00`80Oomoo`0=Ool00`80Oomoo`0cOol0
0`80Oomoo`2QOol00`80Oomoo`0oOol:HaP1000000IS6003001S66<H00ES
6004@Q0006<H002DOol0100OOomoo`0O0Woo00<07gooOol02goo00<207oo
Ool037oo00<07`00Ool03Woo00<207ooOol0<goo00<207ooOol0XGoo00<2
07ooOol0?goo2V<H0@000006HaP00`00HaQS6002HaP2@Q001F<H@Q0006<H
0000U7oo00<07gooOol00goo00<07gooOol02goo00<2000O01l01P0O1@80
00@0000O01l000H2000300007`0O00D07`030P1oogoo00]oo`0301moogoo
009oo`0301moogoo021oo`030P1oogoo0:5oo`030P1oogoo03moo`YS6040
00001V<H00@006<HHaQS60<00005HaQ24000HaP0002DOol0100OOomoogoo
0`0O3Goo00<207ooOol02goo100O3Woo00<207ooOol02goo00<07goo01l0
0`0O8Woo00<207ooOol0XGoo00<207ooOol0?goo2V<H0@000006HaP20002
HaP02000HaQS66<H@Q0006<H002DOol0100OOomoo`0O0Woo00<07gooOol0
2goo00<207ooOol037oo0P0O3goo00<207ooOol02goo00H07goo01l07goo
01lROol00`80Oomoo`2QOol00`80Oomoo`0oOol:HaP1000000MS60D0009S
6004@Q0006<H002BOol901l=Ool00`80Oomoo`0MOol00`80Oomoo`0;Ool0
1P0OOomoo`0OOol07b9oo`030P1oogoo0:5oo`030P1oogoo03moo`YS6040
00003V<H00A24000HaP00:Qoo`030P1oogoo01aoo`8200eoo`0401moogoo
Ool201lROol00`80Oomoo`2QOol00`80Oomoo`0oOol:HaP1000000iS6004
@Q0006<H002SOol60P0OOol60P06Ool501l2Ool00`0OOomoo`0POol00`80
Oomoo`2QOol00`80Oomoo`0oOol:HaP1000000AS60`00003HaP007oo0:1o
o`H20003Ool207oo01ioo`030P1oo`8000@202moo`030P1oogoo0:5oo`03
0P1oogoo03moo`YS6040000016<H2d8@00<006<H0000XGoo1@800Woo00<2
07ooOol07Goo00D207ooOol207oo008202moo`030P1oogoo0:5oo`030P1o
ogoo03moo`YS604000003V<H00A24000HaP00:5oo`04001oo`800P0WOol0
1080Oomoo`00;Woo00<207ooOol0XGoo00<207ooOol0?goo2V<H0@000008
HaP300001d8@HaQS648@001S60000:5oo`0301moogoo02]oo`0301moogoo
02aoo`030P1oogoo0:5oo`030P1oogoo03moo`YS604000001V<H0P000V<H
0P0000I246<H@Q0006<H002QOol00`0OOomoo`0[Ool00`0OOomoo`0/Ool0
0`80Oomoo`2QOol00`80Oomoo`0oOol:HaP1000000IS6003001S66<H00=S
6006001S648@001S6000XGoo00<07gooOol0:goo00<07gooOol01goo0P0O
00=oo`0OOol00`0O00Ioo`0OOomoo`0OOol301l01Goo01l07`0OOol00`0O
0Woo00<07gooOol00`0O17oo00<207ooOol0XGoo00<207ooOol0?goo2V<H
0@000005HaP00`00@Q1S6004HaP01P00HaQ24000HaP00:5oo`0301moogoo
02]oo`0301moogoo00Ioo`0401moo`0O01l2Ool201l2Ool01@0OOol07`0O
Ool00P0O0Woo00L07goo01moo`0OOol07`02Ool01P0OOomoo`0OOol07`Ao
o`030P1oogoo0:5oo`030P1oogoo03moo`YS604000001F<H00<0048@HaP0
16<H00H006<H@Q0006<H002QOol00`0OOomoo`0[Ool00`0OOomoo`05Ool0
0`0OOomoo`02Ool00`0OOomoo`0201l00goo01moo`0201l2Ool201l027oo
01l07`0OOol07goo01l2Ool00`0OOomoo`0301l4Ool00`80Oomoo`2QOol0
0`80Oomoo`0oOol:HaP1000000IS6003001S66<H00=S6006001S648@001S
6000XGoo00<07gooOol0:goo00<07gooOol01Goo00<07gooOol00Woo00H0
7gooOomoo`0OOol201l00goo01moo`02Ool02@0OOol07goo01moo`0OOol0
7`02Ool01P0OOomoo`0OOol07`Aoo`030P1oogoo0:5oo`030P1oogoo03mo
o`YS604000001V<H00<0048@HaP00V<H00L006<HHaQ24000HaP0002QOol0
0`0OOomoo`0[Ool00`0OOomoo`05Ool00`0OOomoo`02Ool01P0OOomoogoo
01moo`807`03Ool07goo009oo`0901moo`0OOol07goo01moo`0O00=oo`03
01moo`0O00807`Aoo`030P1oogoo0:5oo`030P1oogoo03moo`YS60400000
1f<H1@000V<H00A24000HaP00:5oo`03001oogoo02]oo`0301moogoo00Io
o`0401moogoo01l2Ool0100OOol07goo0P0O00ioo`0OOol07goo01moo`0O
Ool07goo01moo`0O0goo00<07gooOol01Woo00<207ooOol0XGoo00<207oo
Ool0?goo2V<H0@00000>HaP0148@001S6000XGoo00<207ooOol0:goo00<2
07ooOol01goo0P0O0goo0`0O00Ioo`0OOomoo`0OOol301l01Goo01l07`0O
Ool00`0O00Aoo`0O01l07`Qoo`030P1oogoo0:5oo`030P1oogoo03moo`YS
6040000016<H300000=S6000Ool0X7oo00<207ooOol0:goo00<207ooOol0
;7oo00<207ooOol0XGoo00<207ooOol0?goo2V<H0@000004HaP;@Q000`00
HaP0002QOol00`80Oomoo`0[Ool00`80Oomoo`0/Ool00`80Oomoo`2QOol0
0`80Oomoo`0oOol:HaP1000000iS6004@Q0006<H001bOol501l01Woo01l0
7`0OOol07`9oo`0301moo`0O00807`05Ool07`0O01moo`0301l2Ool00`0O
Oomoo`0301l=Ool00`80Oomoo`0[Ool00`80Oomoo`0/Ool00`80Oomoo`2Q
Ool00`80Oomoo`0oOol:HaP1000000ES60L00006@Q1S648@001S6000LGoo
0P0O00Aoo`0O01l07`9oo`0501moogoo01moo`0201l2Ool02P0OOomoo`0O
Ool07goo01moo`0O0Woo00H07gooOol07goo01l=Ool00`80Oomoo`0[Ool0
0`80Oomoo`0/Ool00`80Oomoo`2QOol00`80Oomoo`0oOol:HaP1000000ES
6003001246<H00=S6007001246<H@Q0006<H0000LGoo00<07gooOol00Woo
00H07gooOomoo`0OOol401l3Ool00`0OOol07`0201l017oo01moo`0O0Woo
00@07gooOomoo`807`eoo`030P1oogoo02]oo`030P1oogoo02aoo`030P1o
ogoo0:5oo`030P1oogoo03moo`YS604000001F<H00<0048@HaP00f<H00L0
048@HaQ24000HaP0001aOol00`0OOomoo`02Ool01P0OOomoogoo01moo`80
7`03Ool07goo009oo`0901moo`0OOol07goo01moo`0O009oo`807`04Ool0
7`0O01l=Ool00`80Oomoo`0[Ool00`80Oomoo`0/Ool00`80Oomoo`2QOol0
0`80Oomoo`0oOol:HaP1000000ES6003001246<H00=S6007001246<H@Q00
06<H0000LWoo00@07gooOol07`9oo`0401moo`0OOol201l03Woo01moo`0O
Ool07goo01moo`0OOol07goo01l3Ool00`0OOomoo`0?Ool00`80Oomoo`0[
Ool00`80Oomoo`0/Ool00`80Oomoo`2QOol00`80Oomoo`0oOol:HaP10000
00ES6003001246<H00=S6007001246<H@Q0006<H0000Lgoo0P0O0goo0`0O
00Ioo`0OOomoo`0OOol301l01Goo01l07`0OOol00`0O00Aoo`0O01l07a5o
o`030P1oogoo02]oo`030P1oogoo02aoo`030P1oogoo0:5oo`030P1oogoo
03moo`YS604000001F<H00<0048@HaP00f<H00L0048@HaQ24000HaP0002Q
Ool00`80Oomoo`0[Ool00`80Oomoo`0/Ool00`80Oomoo`2QOol00`80Oomo
o`0oOol:HaP1000000ES60L00006@Q1S648@001S6000XGoo00<207ooOol0
:goo00<207ooOol0;7oo00<207ooOol0XGoo00<207ooOol0?goo2V<H0@00
000>HaP0148@001S6000XGoo00<207ooOol0:goo00<207ooOol0;7oo00<2
07ooOol0XGoo00<207ooOol0?goo2V<H0@00000>HaP0148@001S6000XGoo
00<207ooOol0:goo00<207ooOol0;7oo00<207ooOol0XGoo00<207ooOol0
?goo2V<H0@000004HaP<00000f<H001oo`2POol00`80Oomoo`0[Ool00`00
Oomoo`0[Ool00`0O001oo`2ROol00`80Oomoo`0oOol:HaP1000000iS6004
@Q0006<H002QOol]0P0301l[0P00100001l07`00X`80@Goo2V<H0@00000>
HaP0148@001S6000cWoo0`0O:goo100Oi7oo2V<H0@00000;HaP01d8@0000
048@001S60000<moo`0301moogoo02]oo`807e9oo`<07i1oo`YS60400000
2f<H0P0000ES648@001S60000?mooe9oo`0301moo`0O091oo`YS60400000
2V<H00Q24000HaQS648@001S6000ogooE7oo00<07gooOol0SWoo2V<H0@00
000:HaP20002HaP0148@001S6000ogooDWoo0`0OT7oo20000V<H0@000008
HaP00d8@00000003HaP0148@001S6000ogooDWoo00<07gooOol0T7oo1d8@
00<006<HHaP00@000006HaP0148@0000000016<H00A24000HaP00?mooe9o
o`<07i1oo`MS6003001S66<H004000001V<H0P001V<H00A24000HaP00?mo
onEoo`9S60@00004HaP006<HHaP1000000iS6004@Q0006<H003oOooUOol2
HaP30002HaP00`00HaQS6001000000mS6003001S60000?moonEoo`=S6005
001S66<HHaP00002HaP10000015S6003001oogoo0?moon=oo`MS6003001S
66<H004000004F<H00<007ooOol0ogoohgoo1f<H00<006<HHaP00@00000A
HaSo003^0002HaP10000009S6?m24?i2405S60400000_6<H00=246<HHaP0
WV<H0T8@UV<H00=246<HHaP026<H0@000005HaPT0003HaP<0004HaPS0004
HaPH0003HaPk0003HaP0148@HaQS66<H;`0016<H00<007ooOol0@7oo1f<H
00<006<HHaP00f<H60000V<H0T8@0f<H600016<H00<007ooOol06Woo1f<H
00<006<HHaP00f<H60000f<H;`000f<H00=246<HHaP026<H0@00000@HaP0
0`00HaQS6008HaP00d8@001S6009HaP00d8@001S600=HaP00`00HaQS600=
HaP00`00HaQS6008HaP00d8@001S6009HaP00`00HaQS600=HaP00`00HaQS
6008HaP00d8@001S600=HaP00d8@001S6009HaP00`00HaQS6008HaP00d8@
001S6009HaP00d8@001S6009HaP01@00HaQS66<H@Q003F<H00=24000HaP0
2F<H00=24000HaP02F<H00<006<HHaP026<H00=24000HaP00f<H00<007oo
Ool0@7oo1f<H00<006<HHaP03F<H00=24000HaP02F<H00A24000HaQS6092
40iS6003001S66<H00US6003001S66<H009S6003001oogoo01Yoo`MS6003
001S66<H00eS6003@Q0006<H00US6003@Q0006<H00eS6003001S66<H00QS
6003@Q0006<H00US6003@Q0006<H00US6005001S66<HHaQ2400:HaP10000
011S6003001S66<H00QS6003@Q0006<H00US6003@Q0006<H00eS6003001S
66<H00eS6003001S66<H00QS6003@Q0006<H00US6003001S66<H00eS6003
001S66<H00QS6003@Q0006<H00eS6003@Q0006<H00IS6004001S66<H000:
HaP00d8@001S6009HaP00d8@001S6009HaP01@00HaQS66<H@Q002F<H0P00
0V<H00=24000HaP01F<H00H006<HHaQS648@0002HaP7@Q000f<H001S6003
HaP20002HaP200000d8@001S6003HaP00`00Oomoo`10Ool7HaP00`00HaQS
600=HaP00d8@001S6009HaP0148@001S66<H0T8@1F<H200000=S6000HaP0
2@0000=S6000HaP00f<H00<007ooOol06Woo1f<H00<006<HHaP016<H00<0
048@HaP01V<H00A24000HaP000=S6003001S66<H009S6003@Q0006<H00eS
6003001S66<H00QS6003@Q0006<H00US6003@Q0006<H00US6005001S66<H
HaQ2400:HaP10000011S6003001S66<H00QS6004@Q0006<HHaP700000f<H
@Q000006HaP60002HaP00`00HaQS6006HaP00d8@HaQS6004HaP00`00HaQS
6008HaP00d8@001S6003HaP5@Q000f<H001S600>HaP00`00HaQS6008HaP0
0d8@001S6004HaP301P00`0O01P0600201P00f<H@Q000006HaP300000f<H
001S6006HaP200000f<H@Q000006HaP20002HaP00d8@001S6005HaP20002
HaP01@00HaQS66<H@Q0026<H100000=S648@00001F<H100000=S648@0000
0V<H1P0000=246<H000016<H0P0000IS648@0000048@0004HaP00`00Oomo
o`10Ool7HaP00`00HaQS6007HaP7@Q000`00HaQS60040004HaP0148@001S
66<H0T8@1F<H00<006<HHaP016<H00D006<H001S600000Eoh005@01oh000
HaP00004HaP00`00Oomoo`0JOol7HaP00`00HaQS6004HaP00d8@00000006
HaP00d8@001S6003000026<H00000000@Q1S648@0009HaP00`00HaQS6002
HaP00`00HaQS6002HaP00d8@HaQS6003HaP00d8@001S6002HaP50002HaP0
0d8@001S6003HaP2@Q001F<H@Q1S66<H00000f<H00=246<HHaP026<H0@00
0008HaP60002HaP00`00HaQS60060002HaP01D8@001S6000O0001P0000=S
648@00001F<H200000=S6000HaP01V<H00=246<H@Q000T8@00Aoof<HHaP0
00ES60I24003001S648@00M24003HaP006<H00iS6003001S66<H00QS6003
@Q0006<H00MS600301P07`0H00=S6003@Q0006<H009S60H00003HaP006<H
00ES600600120000HaQ240000V<H1`0000=S648@00001F<H100000=S6000
HaP00V<H00=246<HHaP01F<H1@0000=S648@000016<H10000V<H00I24000
HaP06000HaP3Ool01000@Q1S600016<H1P0000=24000HaP00f<H00<007oo
Ool0@7oo0f<H0P000V<H00<006<HHaP01V<H248@00@006<HHaP000=oo`80
009S6004@Q0006<HHaP2@Q05HaP00`00@Q1S6004@Q001000HaP006<H1000
00Moh7`0@01l0000HaP00004HaP00`00Oomoo`0JOol3HaP20002HaP00`00
HaQS6005HaP30005HaP0148@001S648@0`0000MS6000000006<H@Q000008
HaP20004HaP00`00HaQS6002HaP7@Q000`00HaQS6003HaP20003HaP00d8@
001S6003HaP4@Q02HaP01@00HaQS66<H@Q002V<H0@000008HaP00`00Oomo
o`02Ool01000HaQS60000V<H0P00148000L006<H@Q0006<H001l00060000
0f<H@Q000005HaP00`000ol3o`030ol200000f<H001S6006HaP5@Q03HaP0
0`00HaQS6009@Q000`00HaQ24007@Q000f<H001S6005HaP4@Q02HaP0148@
HaQS60000f<H00=246<HHaP00d8@00=S648@00001f<H0P000P0O0f<H00=2
4000HaP00P000P0H0`000V<H00<006<HHaP0100000I20000HaQS648@0002
HaP60002HaP0148@001S66<H1P000V<H00D006<HHaQS648@00IS60D0009S
6003@Q0006<H009S60@000=S6005@Q0006<HHaP00003Ool01F<H000046<H
000016<H1P0000=24000HaP00f<H00<007ooOol0@7oo0V<H100000=S6000
HaP01V<H2D8@00<006<HHaP00`000goo00@006<H@Q00009S609240ES6003
0012448@00AS6004001S6000HaP200002GoP001oh000@01oh000HaP00004
HaP01`00Oomoo`00Ool007oo00@00003Ool00000008000eoo`9S60@00003
HaP006<H00MS60H00003HaQ24000009S60H0009S6003@Q0006<H00MS60<0
00=S6003001S66<H009S609240AS6003@Q0006<H00AS608000=S6003@Q00
06<H00Q24003HaP006<H009S6003@Q1S66<H00QS6040000026<H00<007oo
Ool00Woo00@006<HHaP0009S6003001oh00000D00005@Q0006<H001l0006
00000f<H@Q000005HaP800000f<H001S6008HaP3@Q03HaP00`00HaQS6009
@Q000`00HaQ24003@Q02HaP2@Q000f<H001S6005HaP3@Q03HaP0148@HaQS
60000V<H00A246<HHaQS60=24003HaQ2400000IS60@0000901QS66<HHaQ2
4000HaP006<H00806003HaP006<H009S6004001S66<H0003HaP02000HaQS
66<H@Q0006<H000301l30002HaP0148@001S60000d8@0P000f<H00D006<H
HaQS648@00IS60@000=S6004@Q0006<HHaP40004HaP01T8@001S600H001S
60=oo`04001246<H0002HaP800000d8@001S6003HaP00`00Oomoo`10Ool7
HaP00`00HaQS6004HaP:@Q000`00HaQS6002000016<H000007oo0P0000A2
4000HaQS609240ES6003001246<H00A24005001S6000HaP00002On030000
1D00O00006<H000016<H00<007ooOol00`0000=oo`00Ool00P0000=oo`00
00000P003Goo1f<H00<006<HHaP01f<H00D007oo001oo`0000924004001S
66<HHaP400001Goo001S648@00001f<H10000f<H00<006<HHaP00V<H00A2
46<HHaQ2409S6003@Q0006<H00AS608000=S6003@Q0006<H00924005HaQ2
448@HaQ24002HaP01@00HaQS66<H@Q002V<H0@000008HaP00`00Oomoo`02
Ool01000HaQS60000V<H00<007oPOn000WoP00H006<HHaQ24000HaP20004
Ool200000f<H@Q000005HaP60000108@001S60002F<H0T8@16<H00<006<H
HaP02D8@00<006<H@Q001d8@00=S6000HaP01F<H148@0V<H00A246<HHaP0
009S60924003HaQ2448@00924003HaQ2400000ES608000920003001S66<H
009S6004@Q0006<H000401l02000HaQS66<H001S6000HaP201P00f<H001S
6002HaP0248@001S600001moo`0OOol20002HaP01D8@001S6000@Q000Woo
00=24000HaP00V<H00D006<HHaQS648@00ES6004001S60000004HaP0148@
001S66<H0`001F<H00E24000HaQS600000=oo`06HaP0000@HaP006<H0P00
0Woo100000=S648@000016<H00<007ooOol0@7oo1f<H00<006<HHaP016<H
2T8@00D006<H000007oo00D00003HaQ24000009S609240ES60030012448@
00=S6006@Q0006<H001S6000108000H00400On0006<H0004HaP00`00Oomo
o`0300000goo00000007000=Ool7HaP00`00HaQS6007HaP02000Ool00000
Ool0048@0003HaP02@00Oomoo`00Ool006<H@Q000007HaP200000f<H001S
6002HaP00`00HaQS6002HaP0148@HaQ2448@0V<H00=24000HaP016<H0P00
0f<H00M24000HaQS648@HaQ24002HaP0148@HaQS60000f<H00=246<HHaP0
26<H0@000008HaP01000Oomoogoo0P000V<H00<006<HHaP0200000=24000
HaP00P0017oo0P0000=S648@00001V<H1`0000=S6000HaP01f<H0d8@16<H
00<006<HHaP01d8@00AS648@001S60Q24003HaP006<H00US609240=S6004
001S66<HHaP3@Q04HaP00d8@001S6004HaP00`00@P1200020004HaP01D8@
001S6000HaP00P0H00=S6000HaP00V<H00@006<H000000=S6008001S66<H
HaQ24000HaP000<07`<0009S6005@Q0006<H00124002Ool20003HaP01@00
HaQS66<H@Q001F<H0P001d8@00<006<H0000200000I24000HaP06000HaP3
Ool01000@Q1S60000V<H00@007ooOomoo`80009S6003@Q0006<H00=S6003
001oogoo041oo`MS6003001S66<H00ES60U24003001S66<H00D00005@000
06<H@Q000002HaP2@Q05HaP800001V<H001S60000P1oh0820006On1007`0
001S600016<H00H007ooOol007oo000GOol7HaP00`00HaQS6007HaP20000
1Woo00124000@Q0000=S600900124000001oo`00HaQ2400000IS60<0009S
6005001S66<H001S6004@Q001f<H@Q12448@HaQ2400000ES608000=S6005
@Q0006<HHaQ24007HaP01@00HaQS66<H@Q002V<H0@000008HaP01000Oomo
ogoo0P000V<H00<006<HHaP016<H00L006<H0000048@001S60020004Ool2
00000f<H@Q000007HaP50002HaP00`00HaQS6006HaP00d8@HaQ24004HaP0
1@00HaQS648@HaP00T8@16<H00=24000HaP0248@00=S6000HaP03V<H00<0
06<HHaP026<H00=24000HaP016<H0T800P001F<H00=24000HaP00P000P0H
0P000f<H00<006<HHaP00P0000=S600000000f<H00=24000HaP00P0000=o
o`00000016<H00=24000HaP00P0000=24000000016<H00D006<HHaQS648@
00AS60T00003@Q0006<H00T00005@Q0006<HHaP00004Ool01@00@Q1S6000
HaP00P000goo00H006<HHaQS648@0004HaP00`00Oomoo`10Ool7HaP00`00
HaQS6006HaP6@Q000f<H@Q000005HaP50000148@001S66<H0T8@1F<H00<0
000O01l0100O00L006<H001S60000P1oh0020P001WoP@01oh000HaP000AS
6006001oogoo001oo`005goo1f<H00<006<HHaP01f<H0P0000Iood8@001S
648@0004HaP00`00@Q1oo`0200000f<H@Q000005HaP400001V<H00000000
HaP000ES60A24003HaQ2400000=S60D0009S6003@Q0006<H009240MS6005
001S66<HHaQ2400:HaP1000000QS60D000=S6003001S66<H00AS6080009S
6003@Q0006<H00P00003HaQ2400000MS60D0009S6003001S66<H00IS6003
@Q1S648@00AS6003001S66<H00=240ES6003@Q0006<H00=S609240AS6003
001S66<H00eS6003001S66<H00QS6003@Q0006<H00AS6003H`12000000IS
6003@Q0006<H009S608000ES6004001S66<HHaP20005HaP00d8@001S6002
HaP20005HaP00d8@001S6002HaP20005HaP01@00HaQS66<H@Q003F<H00=2
4000HaP02F<H00A24000HaQS60H0009S6003001S66<H00@000AS6003@Q00
06<H00=S6003001oogoo041oo`MS6003001S66<H00eS6003@Q0006<H00ES
6006001P06<HHaQ240000V<H0T8@1F<H200000=S6000HaP02@0000=S6000
HaP00f<H00<007ooOol06Woo1f<H00<006<HHaP026<H00=2400000000V<H
00=24000HaP016<H0P0000E246<HHaQ2400000iS6003001S66<H00QS6003
@Q0006<H00US6003@Q0006<H00US6005001S66<HHaQ2400:HaP10000011S
6003001S66<H00QS6003@Q0006<H00US6003@Q0006<H00eS6003001S66<H
00eS6003001S66<H00QS6003@Q0006<H00US6003001S66<H00eS6003001S
66<H00QS6003@Q0006<H00eS6003@Q0006<H00US6003001S66<H00QS6003
@Q0006<H00US6003@Q0006<H00US6005001S66<HHaQ2400=HaP00d8@001S
6009HaP00d8@001S6009HaP00`00HaQS6008HaP00d8@001S6003HaQ;0000
0d8@HaQS600<HaP00d8@001S6009HaP0148@001S66<H0T8@3V<H00<006<H
HaP02F<H00<006<HHaP00V<H9@0000=246<HHaP036<H00=24000HaP02F<H
00=24000HaP03F<H00<006<HHaP026<H00=24000HaP02F<H00=24000HaP0
2F<H00D006<HHaQS648@00YS60400000_6<H00=246<HHaP0WV<H0T8@UV<H
00=246<HHaP026<H0@00002lHaP00d8@HaQS602NHaP2@Q2FHaP00d8@HaQS
6008HaP10000009S6?m24?i2405S604000001F<H1`00of<HmF<H0@000005
HaP01480On1200000WoP00<006<HHaP00V<H1@003f<H1@003V<H1P004V<H
1P002F<H0`004V<H1@004V<H1`0066<H1P0026<H0P004V<H1P0056<H1P00
6f<H1`006V<H1@001V<H00<006<HHaP0/6<H400000=S600000001P000V<H
0@000005HaP00d80On00000200000goP001S6004HaP01000HaQS66<H0P00
00AS6000000000US60@00008HaP00000001S6000HaP000QS60<0009S6003
001S600000@0009S6003001S66<H00MS6005001S66<H001S600400001F<H
001S6000HaP00`0000=S600000000`0000AS6000000000YS6005001S66<H
001S6003000016<H001S60002f<H0P000V<H0`0000AS6000001S60<00005
HaP006<H001S60020008HaP00`00HaQS6002HaP200000f<H001S60040002
HaP00`00HaQS600200000f<H001S6002000;HaP00`00HaQS600300001f<H
00000000HaP006<H008000US6006001S6000HaP006<H0`0000MS6000HaP0
06<H001S6002000016<H001S66<H0P002V<H00/006<HHaP006<H001S6000
HaP006<H00<00008HaP00000001S6000HaP000US6006001S66<HHaP006<H
0P0000=S6000HaP00`00/V<H0`000V<H00<006<H00000`000V<H00<006<H
HaP01V<H00<006<HHaP00@000005HaP00d80On1200040005HaP01000HaQS
66<H0P0000AS6000HaP000US6003001S66<H009S6004001S6000HaP20009
HaP02`00HaQS6000HaP006<H001S6000HaP010002F<H00T006<H000006<H
001S6000HaP00P00011S6000HaP006<H001S6000HaP006<H001S6000HaP0
00YS60800007HaP006<H001S6000HaP010002F<H00T006<HHaP006<H001S
6000HaP00P0000MS6000HaP006<H001S600200000f<H001S6007HaP20002
HaP300000f<H00000002HaP2000026<H000006<H001S6000HaP200000f<H
001S600:HaP02`00HaQS6000HaP006<H001S6000HaP00P0000=S6000HaP0
26<H0`0000=S600000000V<H00@006<H001S60@0009S60800004HaP006<H
0009HaP200004V<H000006<H001S6000HaP006<H001S6000HaP006<H001S
60@000QS6004001S66<HHaP20002HaP200001F<H001S66<H0000/F<H0`00
0V<H00<006<H00000V<H00@006<HHaP000=S60@00004HaP006<HHaP10000
00ES6004@P1oh0000002On000`00HaQS6003HaP01000HaQS66<H0P0000AS
6000000000US6003001S66<H009S6004001S6000HaP20009HaP01`00HaQS
6000HaP006<H00<00003HaP00000008000US6005001S6000001S60030000
0f<H001S600200001F<H001S6000HaP00`0000=S6000HaP00`002F<H0`00
00=S6000HaP00`0000=S600000000P002F<H00T006<HHaP006<H001S6000
HaP00P0000MS6000HaP006<H001S60040009HaP400000f<H001S60060000
0f<H001S600400000f<H00000002000;HaP02`00HaQS6000HaP006<H001S
6000HaP010002F<H2@0000=S6000HaP00P0000=S600000000`0000AS6000
000000US6080000BHaP00000HaP006<H001S6000HaP006<H001S6000HaP0
06<H100026<H00@006<HHaQS60H00005HaP006<HHaP0002fHaP00`00HaP0
000400000f<H001S6003HaP20002HaP00`00HaQS6001000000ES6003@P1o
h00000800003On0006<H00AS60<00004HaP00000HaP30009HaP400001F<H
00000000HaP00`0026<H00D006<HHaP006<H00H0009S6003001S600000QS
60800003HaP006<H00@0009S60800005HaP00000001S6005000016<H0000
00002F<H00<006<H00000P0000=S600000000P0000AS6000HaP000US6005
001S66<H001S600600001F<H00000000HaP01P002F<H100000=S60000000
1`000V<H100000=S600000000P002f<H00<006<HHaP00`0000ES60000000
06<H00@000US60800003HaP0000000@00003HaP0000000`000US6005001S
6000001S600200001F<H00000000HaP00`0000=S600000000P0000AS6000
HaP000QS60X00003HaP0000000800;IS6003001S600000@00003HaP006<H
009S60@00004HaP006<HHaP1000000ES6003@P1oh00000@000ES6003001S
66<H009S6003001S66<H00]S6003001S66<H00AS6004001S66<H0009HaP0
1000HaQS600056<H0P0000=S6000HaP04F<H00<006<HHaP02V<H0P000V<H
00<006<HHaP04F<H00@006<HHaP000ES6003001S66<H01AS608000US6003
001S66<H01ES6003001S66<H00QS6003001S66<H00YS6003001S66<H0080
00MS6003001S66<H015S6004001S66<H0002HaP00`00HaQS6006HaP00`00
HaQS600?HaP01@00HaQS66<H000016<H00<006<HHaP0^F<H00<006<HHaP0
100000=S6000HaP00V<H00H006<HHaP006<H0002HaP1000000ES6003@P1o
h7oP0080009200ES60H000eS60@000=S6003001S600000YS60<001ES6004
001S66<H0008HaP00`00HaQS600DHaP01000HaQS66<H0P004f<H0P001f<H
00<006<HHaP056<H00<006<HHaP01f<H00<006<HHaP01V<H00<006<HHaP0
2F<H1P0026<H00<006<HHaP02V<H00D006<HHaQS600000MS6003001S66<H
015S6004001S66<H0002HaP20007HaP00`00HaQS600?HaP01@00HaQS66<H
000016<H00<006<HHaP0^F<H00<006<HHaP01F<H00<006<HHaP01V<H00<0
06<HHaP00@000005HaP6@P3oHaSfHaP10000009S6?l04?h0405S60400000
0V<H00<0400000001@0000=2000@0100KP0@00=oo`0@0100:`0@00=oo`0@
0100o`0@>P0@400000<0400000001P000@0@0F<H0@000002HaP00`0@0000
0002000017oP00000480L00@00=oo`0@0100:`0@00=oo`0@0100o`0@>P0@
1d8@00<0048@@Q001D8@00<0000@@Q001T8@00<0000@HaP00@000002HaP0
100@001oh0000goP0P000P0@00Uoo`0@Ool047oo011oo`0@Ool00`0@00=o
o`0@01000P0@00=oo`0@Ool0800@00=oo`0@Ool01P0@00Moo`0@Ool047oo
011oo`0501000goo0100400:01000goo0100400201002Goo011oo`0@Ool0
47oo011oo`0:01000goo0100400G01000goo0100400401001Goo011oo`0@
Ool0200@00=oo`0@0100o`0@>P0@0V<H0`000V<H00<006<H0000100000=S
600001000V<H00P006<HHaP006<H000046<H0@000002HaP00`0@001oh003
00000d80On00000201002Goo0100400@Ool047oo011oo`0301000goo0100
400201000goo0100400N01001Goo011oo`0@Ool01P0@00Moo`0@Ool047oo
011oo`0B01000goo0100400201002Goo011oo`0@Ool047oo011oo`0:0100
0goo0100400G01000goo0100400201001goo011oo`0@Ool047oo00P04003
Ool0400@0?l043X040MS6003001S600000=S6004001S60000102HaP40000
16<H000046<H0@000002HaP01@0@00000000H`0010000P0@00Moo`0@0100
47oo011oo`0501000goo0100400<01000goo0100400>01000goo01004005
010017oo010047oo1`0@00=oo`0@Ool0500@00=oo`0@01000P0@00Moo`0@
Ool047oo011oo`0601000goo0100400301000goo0100400E01000goo011o
o`0601001Goo0100400@Ool0200@00=oo`0@0100o`0@>P0@1f<H00<006<H
00000f<H00@006<H000040=S6080009S6003000046<H004000000V<H00<0
400000001P000P0@00Eoo`0@010047oo00h04003Ool0400@02T04003Ool0
400@01@04003Ool0400@00H04003Ool047oo01T04003Ool0400@01D04003
Ool047oo00H04003Ool0400@0?l043X040MS6003001S600000@00003HaP0
000@009S60@00004HaP0000@HaP10000009S60030100000000800003On00
000000800?l04=X040MS6003001S600000@00003HaP0000@00MS60030000
46<H004000000V<H00<0400000001`00o`0@h@0@00<0000@01001@0@00<0
000@01001P0@00<0000@HaP00@000002HaSo013n0101HaP100000?mS6?mS
609S60400000of<Hof<H0V<H0@000000\
\>"], "Picture",
  CellMargins->{{20, 0}, {0, 0}},
  Evaluatable->False,
  ImageSize->{513.063, 367},
  ImageMargins->{{11, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DXFGraphics[\[IndentingNewLine]"\<Buffer.dxf\>", \ 
      TextStyle\  \[Rule] 
        \ {FontColor\  \[Rule] \ RGBColor[1, 0, 0], 
          FontWeight\  \[Rule] \ Bold}, 
      ColorList\  \[Rule] \ {RGBColor[0, 0, 0]}\[IndentingNewLine]]; \)\)], 
  "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .75144 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 1 r
MFill
% Scaling calculations
-0.206935 0.192287 -2.73723 0.192287 [
[.94933 .29536 -5 -2.6 ]
[.94933 .29536 5 10.4 ]
[.94933 .27229 -5 -2.6 ]
[.94933 .27229 5 10.4 ]
[.97619 .30632 -13.8125 -3.325 ]
[.97619 .30632 13.8125 13.3 ]
[.21225 .33901 0 -3.325 ]
[.21225 .33901 58.6875 13.3 ]
[.32185 .30055 0 -3.325 ]
[.32185 .30055 19.625 13.3 ]
[.36738 .14538 -5 -2.6 ]
[.36738 .14538 5 10.4 ]
[.36738 .11461 -5 -2.6 ]
[.36738 .11461 5 10.4 ]
[.34391 .15249 -9.8125 -3.325 ]
[.34391 .15249 9.8125 13.3 ]
[.04558 .16076 -5 -2.6 ]
[.04558 .16076 5 10.4 ]
[.04558 .13769 -5 -2.6 ]
[.04558 .13769 5 10.4 ]
[.07244 .17172 -13.8125 -3.325 ]
[.07244 .17172 13.8125 13.3 ]
[.63658 .14538 -5 -2.6 ]
[.63658 .14538 5 10.4 ]
[.63658 .11461 -5 -2.6 ]
[.63658 .11461 5 10.4 ]
[.61311 .15249 -9.8125 -3.325 ]
[.61311 .15249 9.8125 13.3 ]
[.19494 .69474 0 -3.325 ]
[.19494 .69474 66.5 13.3 ]
[.27571 .64282 0 -3.325 ]
[.27571 .64282 19.625 13.3 ]
[.4791 .67551 -66.5 -3.325 ]
[.4791 .67551 0 13.3 ]
[.44673 .64667 -19.625 -3.325 ]
[.44673 .64667 0 13.3 ]
[.60985 .59091 -66.5 -3.325 ]
[.60985 .59091 0 13.3 ]
[.57364 .54283 -19.625 -3.325 ]
[.57364 .54283 0 13.3 ]
[.4955 .27748 -58.6875 -3.325 ]
[.4955 .27748 0 13.3 ]
[.40443 .29671 -19.625 -3.325 ]
[.40443 .29671 0 13.3 ]
[.05073 .01789 0 -3.325 ]
[.05073 .01789 11.8125 13.3 ]
[.66989 .34207 0 -1.925 ]
[.66989 .34207 16.75 7.7 ]
[.74488 .7332 0 -3.325 ]
[.74488 .7332 11.8125 13.3 ]
[.34108 .27171 0 -3.325 ]
[.34108 .27171 11.8125 13.3 ]
[.15841 .31401 0 -3.325 ]
[.15841 .31401 11.8125 13.3 ]
[.43146 .46977 0 -3.325 ]
[.43146 .46977 11.8125 13.3 ]
[.31609 .45054 0 -3.325 ]
[.31609 .45054 11.8125 13.3 ]
[.58336 .3294 0 -3.325 ]
[.58336 .3294 35.4375 13.3 ]
[ 0 0 0 0 ]
[ 1 .75144 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
%
% $ID: DXFGraphics.m,v 2.13 2000/06/06 16:00:52 thole Exp $
% $ID: DXFGraphics (C) 1998-1999 by M. Thole, ITWM e. V. $
%
% $ID: Created with: $
% $ID:   DXFGraphics[\"Buffer.dxf\", TextStyle -> {FontColor -> RGBColor[1, \
0, 0], FontWeight -> Bold}, ColorList -> {RGBColor[0, 0, 0]}] $
% $ID: User: halfmann@TENFORWARD.None $
% $ID: Date: 2000/11/3 17:14:21 $
%
% End of user PostScript
0 0 0 r
0 Mabswid
newpath
.94679 .28936 .01923 0 365.73 arc
s
.94679 .32782 m
.94679 .30859 L
s
gsave
.94933 .29536 -66 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 9.812500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Math1Mono-Bold
%%IncludeFont: Math1Mono-Bold
/Math1Mono-Bold findfont 9.812500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(+) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 9.812500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono-Bold
%%+ font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono-Bold
%%+ Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono-Bold
%%+ font Courier-Bold
grestore
.94679 .2509 m
.94679 .27013 L
s
gsave
.94933 .27229 -66 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 9.812500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Math1Mono-Bold
%%IncludeFont: Math1Mono-Bold
/Math1Mono-Bold findfont 9.812500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(-) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 9.812500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono-Bold
%%+ font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono-Bold
%%+ Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono-Bold
%%+ font Courier-Bold
grestore
gsave
.97619 .30632 -74.8125 -7.325 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 20.625000 moveto
 460.000000 20.625000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 20.625000 lineto
closepath
clip newpath
63.000000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.187500 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(VDD) show
86.625000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.31224 .32782 m
.29301 .3182 L
s
.31224 .28936 m
.29301 .29898 L
s
.29493 .29321 m
.30839 .29128 L
s
.30839 .29128 m
.29878 .3009 L
s
.29301 .32782 m
.29301 .28936 L
s
.27378 .30859 m
.29301 .30859 L
s
.31224 .34705 m
.31224 .32782 L
s
.31224 .27013 m
.31224 .28936 L
s
gsave
.21225 .33901 -61 -7.325 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 20.625000 moveto
 460.000000 20.625000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 20.625000 lineto
closepath
clip newpath
63.000000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(Q2N2222) show
117.687500 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.32185 .30055 -61 -7.325 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 20.625000 moveto
 460.000000 20.625000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 20.625000 lineto
closepath
clip newpath
63.000000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(T1) show
78.625000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
newpath
.36993 .13553 .01923 0 365.73 arc
s
.36993 .12592 m
.37954 .13553 L
s
.36993 .12592 m
.36031 .13553 L
s
.36993 .14515 m
.36993 .12592 L
s
.36993 .17399 m
.36993 .15476 L
s
gsave
.36738 .14538 -66 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 9.812500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Math1Mono-Bold
%%IncludeFont: Math1Mono-Bold
/Math1Mono-Bold findfont 9.812500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(+) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 9.812500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono-Bold
%%+ font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono-Bold
%%+ Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono-Bold
%%+ font Courier-Bold
grestore
.36993 .09708 m
.36993 .1163 L
s
gsave
.36738 .11461 -66 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 9.812500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Math1Mono-Bold
%%IncludeFont: Math1Mono-Bold
/Math1Mono-Bold findfont 9.812500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(-) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 9.812500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono-Bold
%%+ font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono-Bold
%%+ Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono-Bold
%%+ font Courier-Bold
grestore
gsave
.34391 .15249 -70.8125 -7.325 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 20.625000 moveto
 460.000000 20.625000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 20.625000 lineto
closepath
clip newpath
63.000000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(I1) show
78.625000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
newpath
.04304 .15476 .01923 0 365.73 arc
s
.04304 .19322 m
.04304 .17399 L
s
gsave
.04558 .16076 -66 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 9.812500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Math1Mono-Bold
%%IncludeFont: Math1Mono-Bold
/Math1Mono-Bold findfont 9.812500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(+) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 9.812500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono-Bold
%%+ font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono-Bold
%%+ Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono-Bold
%%+ font Courier-Bold
grestore
.04304 .1163 m
.04304 .13553 L
s
gsave
.04558 .13769 -66 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 9.812500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Math1Mono-Bold
%%IncludeFont: Math1Mono-Bold
/Math1Mono-Bold findfont 9.812500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(-) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 9.812500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono-Bold
%%+ font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono-Bold
%%+ Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono-Bold
%%+ font Courier-Bold
grestore
gsave
.07244 .17172 -74.8125 -7.325 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 20.625000 moveto
 460.000000 20.625000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 20.625000 lineto
closepath
clip newpath
63.000000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.187500 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(VIN) show
86.625000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
newpath
.63913 .13553 .01923 0 365.73 arc
s
.63913 .12592 m
.64874 .13553 L
s
.63913 .12592 m
.62951 .13553 L
s
.63913 .14515 m
.63913 .12592 L
s
.63913 .17399 m
.63913 .15476 L
s
gsave
.63658 .14538 -66 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 9.812500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Math1Mono-Bold
%%IncludeFont: Math1Mono-Bold
/Math1Mono-Bold findfont 9.812500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(+) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 9.812500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono-Bold
%%+ font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono-Bold
%%+ Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono-Bold
%%+ font Courier-Bold
grestore
.63913 .09708 m
.63913 .1163 L
s
gsave
.63658 .11461 -66 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 9.812500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Math1Mono-Bold
%%IncludeFont: Math1Mono-Bold
/Math1Mono-Bold findfont 9.812500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(-) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 9.812500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono-Bold
%%+ font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono-Bold
%%+ Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono-Bold
%%+ font Courier-Bold
grestore
gsave
.61311 .15249 -70.8125 -7.325 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 20.625000 moveto
 460.000000 20.625000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 20.625000 lineto
closepath
clip newpath
63.000000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(I2) show
78.625000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.31224 .63548 m
.33147 .64509 L
s
.33147 .66432 m
.31224 .67394 L
s
.31416 .66817 m
.32762 .66624 L
s
.32762 .66624 m
.31801 .67586 L
s
.33147 .63548 m
.33147 .67394 L
s
.3507 .65471 m
.33147 .65471 L
s
.31224 .61625 m
.31224 .63548 L
s
.31224 .69316 m
.31224 .67394 L
s
gsave
.19494 .69474 -61 -7.325 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 20.625000 moveto
 460.000000 20.625000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 20.625000 lineto
closepath
clip newpath
63.000000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(Q2N2907a) show
125.500000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.27571 .64282 -61 -7.325 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 20.625000 moveto
 460.000000 20.625000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 20.625000 lineto
closepath
clip newpath
63.000000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(T3) show
78.625000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.42761 .63548 m
.40838 .64509 L
s
.40838 .66432 m
.42761 .67394 L
s
.42569 .66817 m
.41223 .66624 L
s
.41223 .66624 m
.42184 .67586 L
s
.40838 .63548 m
.40838 .67394 L
s
.38915 .65471 m
.40838 .65471 L
s
.42761 .61625 m
.42761 .63548 L
s
.42761 .69316 m
.42761 .67394 L
s
gsave
.4791 .67551 -127.5 -7.325 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 20.625000 moveto
 460.000000 20.625000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 20.625000 lineto
closepath
clip newpath
63.000000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(Q2N2907a) show
125.500000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.44673 .64667 -80.625 -7.325 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 20.625000 moveto
 460.000000 20.625000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 20.625000 lineto
closepath
clip newpath
63.000000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(T4) show
78.625000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.54298 .53933 m
.52376 .54895 L
s
.52376 .56818 m
.54298 .57779 L
s
.54106 .57202 m
.5276 .5701 L
s
.5276 .5701 m
.53722 .57971 L
s
.52376 .53933 m
.52376 .57779 L
s
.50453 .55856 m
.52376 .55856 L
s
.54298 .52011 m
.54298 .53933 L
s
.54298 .59702 m
.54298 .57779 L
s
gsave
.60985 .59091 -127.5 -7.325 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 20.625000 moveto
 460.000000 20.625000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 20.625000 lineto
closepath
clip newpath
63.000000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(Q2N2907a) show
125.500000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.57364 .54283 -80.625 -7.325 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 20.625000 moveto
 460.000000 20.625000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 20.625000 lineto
closepath
clip newpath
63.000000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(T5) show
78.625000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.42761 .32782 m
.44684 .3182 L
s
.42761 .28936 m
.44684 .29898 L
s
.44492 .29321 m
.43146 .29128 L
s
.43146 .29128 m
.44107 .3009 L
s
.44684 .32782 m
.44684 .28936 L
s
.46607 .30859 m
.44684 .30859 L
s
.42761 .34705 m
.42761 .32782 L
s
.42761 .27013 m
.42761 .28936 L
s
gsave
.4955 .27748 -119.688 -7.325 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 20.625000 moveto
 460.000000 20.625000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 20.625000 lineto
closepath
clip newpath
63.000000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(Q2N2222) show
117.687500 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.40443 .29671 -80.625 -7.325 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 20.625000 moveto
 460.000000 20.625000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 20.625000 lineto
closepath
clip newpath
63.000000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(T2) show
78.625000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.05073 .01789 -61 -7.325 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 20.625000 moveto
 460.000000 20.625000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 20.625000 lineto
closepath
clip newpath
63.000000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(0) show
70.812500 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.03342 .03939 m
.04304 .02977 L
s
.04304 .02977 m
.05265 .03939 L
s
.03342 .03939 m
.05265 .03939 L
s
.04304 .05862 m
.04304 .03939 L
s
.65066 .32013 m
.67182 .34128 L
s
newpath
.67758 .34705 .00961 0 365.73 arc
s
.65451 .31628 m
.63913 .30859 L
s
.63913 .30859 m
.64682 .32397 L
s
.64682 .32397 m
.65451 .31628 L
s
gsave
.66989 .34207 -61 -5.925 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 13.625000 moveto
 460.000000 13.625000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 13.625000 lineto
closepath
clip newpath
63.000000 10.625000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 6.500000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.187500 10.625000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 6.500000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(VDB) show
75.750000 10.625000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 6.500000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.54298 .73162 m
.42761 .73162 L
s
gsave
.74488 .7332 -61 -7.325 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 20.625000 moveto
 460.000000 20.625000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 20.625000 lineto
closepath
clip newpath
63.000000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(5) show
70.812500 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.31224 .69316 m
.31224 .73162 L
s
.31224 .73162 m
.42761 .73162 L
s
.42761 .73162 m
.42761 .69316 L
s
.94679 .32782 m
.94679 .73162 L
s
.94679 .73162 m
.54298 .73162 L
s
.54298 .59702 m
.54298 .73162 L
s
.36993 .27013 m
.31224 .27013 L
s
gsave
.34108 .27171 -61 -7.325 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 20.625000 moveto
 460.000000 20.625000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 20.625000 lineto
closepath
clip newpath
63.000000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(2) show
70.812500 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.42761 .27013 m
.36993 .27013 L
s
.36993 .17399 m
.36993 .27013 L
s
.27378 .30859 m
.04304 .30859 L
s
gsave
.15841 .31401 -61 -7.325 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 20.625000 moveto
 460.000000 20.625000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 20.625000 lineto
closepath
clip newpath
63.000000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(1) show
70.812500 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.04304 .30859 m
.04304 .19322 L
s
.42761 .59702 m
.42761 .34705 L
s
gsave
.43146 .46977 -61 -7.325 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 20.625000 moveto
 460.000000 20.625000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 20.625000 lineto
closepath
clip newpath
63.000000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(4) show
70.812500 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.42761 .61625 m
.42761 .59702 L
s
.36993 .65471 m
.36993 .59702 L
s
.38915 .65471 m
.36993 .65471 L
s
.36993 .65471 m
.3507 .65471 L
s
.36993 .59702 m
.42761 .59702 L
s
.31224 .55856 m
.31224 .34705 L
s
gsave
.31609 .45054 -61 -7.325 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 20.625000 moveto
 460.000000 20.625000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 20.625000 lineto
closepath
clip newpath
63.000000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(3) show
70.812500 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.31224 .61625 m
.31224 .55856 L
s
.50453 .55856 m
.31224 .55856 L
s
.36993 .05862 m
.36993 .09708 L
s
.36993 .05862 m
.04304 .05862 L
s
.04304 .05862 m
.04304 .1163 L
s
.94679 .05862 m
.63913 .05862 L
s
.63913 .05862 m
.36993 .05862 L
s
.63913 .05862 m
.63913 .09708 L
s
.04304 .1163 m
.04304 .13553 L
s
.94679 .2509 m
.94679 .05862 L
s
.54298 .30859 m
.63913 .30859 L
s
gsave
.58336 .3294 -61 -7.325 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 20.625000 moveto
 460.000000 20.625000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 20.625000 lineto
closepath
clip newpath
63.000000 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.187500 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(VOUT) show
94.437500 15.812500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 13.062500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.46607 .30859 m
.54298 .30859 L
s
.54298 .52011 m
.54298 .30859 L
s
.63913 .30859 m
.63913 .17399 L
s
.02 Mabswid
newpath
.42761 .73162 .00192 180 360 arc
s
newpath
.42761 .73162 .00192 0 180 arc
s
newpath
.54298 .73162 .00192 180 360 arc
s
newpath
.54298 .73162 .00192 0 180 arc
s
newpath
.36993 .27013 .00192 180 360 arc
s
newpath
.36993 .27013 .00192 0 180 arc
s
newpath
.36993 .65471 .00192 180 360 arc
s
newpath
.36993 .65471 .00192 0 180 arc
s
newpath
.42761 .59702 .00192 180 360 arc
s
newpath
.42761 .59702 .00192 0 180 arc
s
newpath
.31224 .55856 .00192 180 360 arc
s
newpath
.31224 .55856 .00192 0 180 arc
s
newpath
.04304 .05862 .00192 180 360 arc
s
newpath
.04304 .05862 .00192 0 180 arc
s
newpath
.36993 .05862 .00192 180 360 arc
s
newpath
.36993 .05862 .00192 0 180 arc
s
newpath
.04304 .1163 .00192 180 360 arc
s
newpath
.04304 .1163 .00192 0 180 arc
s
newpath
.63913 .05862 .00192 180 360 arc
s
newpath
.63913 .05862 .00192 0 180 arc
s
newpath
.54298 .30859 .00192 180 360 arc
s
newpath
.54298 .30859 .00192 0 180 arc
s
newpath
.63913 .30859 .00192 180 360 arc
s
newpath
.63913 .30859 .00192 0 180 arc
s
0 0 m
1 0 L
1 .75144 L
0 .75144 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{469, 352.313},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Netlist Reader", "ExampleSection"],

Cell[TextData[{
  "For circuit analysis and design tasks which combine symbolic and numerical \
calculations Analog Insydes features interfaces to the circuit simulator \
SPICE. Instead of time-consuming manual netlist input SPICE circuit \
descriptions can be converted automatically to the Analog Insydes format by \
applying the Analog Insydes function ",
  StyleBox["ReadNetlist", "MR"],
  ". Additionally, operating-point information can be extracted from the \
simulator output file. The example below illustrates the import of the SPICE \
netlist file ",
  StyleBox["\"Buffer.net\"", "TI"],
  "."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007000012a000`40O003
h00Oo`00`@00003oHaS0HaP100000?mS6<1S604000009F<H00<006<HHaP0
1V<H00<006<HHaP0iV<H00=246<HHaP0B6<H00=oof<H@Q005f<H00=oof<H
@Q0066<H00=246<HHaP05V<H00=oof<HHaP00V<H00E246<HHaQ246<H0092
40=S604000009F<H00<006<HHaP01V<H00<006<HHaP0iV<H00=246<HHaP0
B6<H00=oof<H@Q005f<H00=oof<H@Q0066<H00=246<HHaP05V<H00=oof<H
HaP00V<H0T8@00AS648@@Q1S6092409S604000001V<H00<006<HHaP00f<H
0`000V<H00<006<HHaP00V<H00<006<HHaP00V<H00<006<H00000`0000AS
6000HaQS60<00003HaP0000000=S6004001S60000002HaP00`00HaQS6004
0002HaP20003HaP20004HaP00`00HaQS6004HaP00`00HaQS6035HaP00d8@
HaQS60050002HaP00`00HaQS6003HaP01000HaQS60001F<H0`000f<H0`00
0V<H00<006<HHaP00V<H00<006<HHaP07f<H00=oof<H@Q005f<H00=oof<H
@Q0066<H00=246<HHaP05V<H00=oof<HHaP00f<H1D8@00AS648@HaQS6040
00001V<H00<006<HHaP00V<H00L006<HHaQS6000HaP00004HaP00`00HaQS
6002HaP00`00HaP00002HaP00`00HaP00002HaP01000HaQS60001F<H0P00
0V<H00<006<H00000V<H00H006<HHaP006<H0002HaP00`00HaP00002HaP0
1@00HaQS66<H00001V<H00<006<HHaP0aF<H00A246<HHaP000=S6004001S
66<H0005HaP00`00HaQS6005HaP01`00HaQS66<H001S6000009S6004001S
66<H0004HaP00`00HaQS600OHaP00gooHaQ2400GHaP00gooHaQ2400HHaP0
0d8@HaQS600FHaP00gooHaQS6004HaP00goo@Q1S6002@Q03HaP1000000IS
6003001S66<H009S6007001S66<HHaP006<H000016<H00<006<HHaP00V<H
00<006<H00000`0000ES6000HaQS6000009S6003001S66<H00=S6007001S
66<HHaP006<H00000V<H10000V<H0`000V<H0`000f<H00<006<HHaP016<H
00<006<HHaP0aF<H00A246<HHaP000=S6004001S66<H0005HaP00`00HaQS
6005HaP00`00HaQS6002HaP20002HaP01000HaQS600016<H00<006<HHaP0
7f<H00=oof<H@Q005f<H00=oof<H@Q0066<H00=246<HHaP05V<H00=oof<H
HaP01F<H1D8@0V<H0@000006HaP00`00HaQS6002HaP01`00HaQS66<H001S
600000AS6003001S66<H009S6003001S6000009S6003001S6000009S6004
001S66<H0005HaP01`00HaQS66<H001S6000009S6006001S66<H001S6000
16<H00<006<HHaP016<H00<006<HHaP016<H00<006<HHaP0aF<H00A246<H
HaP000=S6004001S66<H0005HaP00`00HaQS6005HaP00`00HaQS6003HaP0
1000HaQS60000V<H00<006<HHaP00V<H00<006<HHaP07f<H00=oof<H@Q00
5f<H00=oof<H@Q0066<H00=246<HHaP05V<H00=oof<HHaP01V<H00=ood8@
HaP00f<H0@000006HaP400000f<H001S6002HaP01000HaP000000f<H1P00
00MS6000HaQS6000HaP00002HaP01000HaQS60001F<H0P000V<H00H006<H
000006<H0002HaP00`00HaP00002HaP00`00HaP00002HaP01000HaQS66<H
1@000V<H00<006<HHaP0aF<H00A246<HHaP000=S60800003HaP006<H00AS
6003001S66<H00ES6003001S66<H00=S6004001S66<H0002HaP00`00HaQS
6002HaP00`00HaQS600OHaP00gooHaQ2400GHaP00gooHaQ2400HHaP00d8@
HaQS600FHaP00gooHaQS6007HaP2@Q03HaP1000000IS6003001S66<H00=S
60<0009S608000=S6003001S66<H009S6003001S600000<00004HaP006<H
HaP30006HaP01000HaP000000V<H0P0000=S600000000P000V<H0P000f<H
0P0016<H00<006<HHaP016<H00<006<HHaP0aF<H00A246<HHaP000=S6004
001S60000005HaP00`00HaQS6005HaP00`00HaQS6002HaP00`00HaP00002
0002HaP00`00HaQS6002HaP00`00HaQS600OHaP00gooHaQ2400GHaP00goo
HaQ2400HHaP00d8@HaQS600FHaP00gooHaQS6008HaP2@Q02HaP1000000IS
6003001S66<H00eS6003001S66<H009S6003001S66<H00AS6003001S66<H
02=S6003001S66<H00=S60800<MS6004@Q1S66<H000;HaP20007HaP01@00
HaQS66<H00001f<H00@006<HHaQS6080025S6003OomS648@01MS6003OomS
648@01QS6003@Q1S66<H01IS6003OomS66<H00aS604000001V<H1@002f<H
00<006<HHaP00V<H00<006<HHaP016<H00<006<HHaP08f<H1P0000=S6000
HaP0aV<H00A246<HHaP000aS6003001S66<H00IS60<000QS6003001S66<H
009S6003001S66<H01mS6003OomS648@01MS6003OomS648@01QS6003@Q1S
66<H01IS6003OomS66<H00aS60400000of<H66<H00=246<HHaP0B6<H00=o
of<H@Q005f<H00=oof<H@Q0066<H00=246<HHaP05V<H00=oof<HHaP036<H
0@00003oHaPHHaQ;@Q000gooHaQ2400G@Q000gooHaQ2400F@Q02HaPI@Q00
0gooHaQS600<HaP100000?mS6<1S60400000of<H`6<H0@000003HaP00d8@
HaQS603oHaRjHaP1000000=S6003@Q0007oo0?mookMoo`=S604000000f<H
00=24000Ool0ogoo]goo0f<H0@000003HaP00d8@001oo`3oOongOol3HaP1
000000=S6003@Q0007oo0?mookMoo`=S604000000f<H00=24000Ool0ogoo
]goo0f<H0@000003HaP00d8@001oo`3oOongOol3HaP1000000=S6003@Q00
07oo0?mookMoo`=S604000000f<H00=24000Ool0ogoo]goo0f<H0@000003
HaP00d8@001oo`3oOongOol3HaP1000000=S6003@Q0007oo0?mookMoo`=S
604000000f<H00=24000Ool0ogoo]goo0f<H0@000003HaP00d8@001oo`3o
OongOol3HaP1000000=S6003@Q0007oo0?mookMoo`=S604000000f<H00=2
4000Ool0ogoo]goo0f<H0@000003HaP00d8@001oo`3oOongOol3HaP10000
00=S6003@Q0007oo0?mookMoo`=S604000000f<H00=24000Ool0ogoo]goo
0f<H0@000003HaP00d8@001oo`3oOongOol3HaP1000000=S6003@Q0007oo
0?mookMoo`=S604000000f<H00=24000Ool0ogoo]goo0f<H0@000003HaP0
0d8@001oo`3oOongOol3HaP1000000=S6003@Q0007oo0?mookMoo`=S6040
00000f<H00=24000Ool0ogoo]goo0f<H0@000003HaP00d8@001oo`3oOong
Ool3HaP1000000=S6003@Q0007oo0?mookMoo`=S604000000f<H00=24000
Ool0ogoo]goo0f<H0@000003HaP00d8@001oo`3oOongOol3HaP1000000=S
6003@Q0007oo0?mookMoo`=S604000000f<H00=24000Ool0ogoo]goo0f<H
0@000003HaP00d8@001oo`3oOongOol3HaP1000000=S6003@Q0007oo0?mo
okMoo`=S604000000f<H00=24000Ool0ogoo]goo0f<H0@000003HaP00d8@
001oo`3oOongOol3HaP1000000=S6003@Q0007oo0?mookMoo`=S60400000
0f<H00=24000Ool0ogoo]goo0f<H0@000003HaP00d8@001oo`3oOongOol3
HaP1000000=S6003@Q0007oo0?mookMoo`=S604000000f<H00=24000Ool0
ogoo]goo0f<H0@000003HaP00d8@001oo`3oOongOol3HaP1000000=S6003
@Q0007oo0?mookMoo`=S604000000f<H00=24000Ool0ogoo]goo0f<H0@00
0003HaP00d8@001oo`3oOongOol3HaP1000000=S6003@Q0007oo0?mookMo
o`=S604000000f<H00=24000Ool0ogoo]goo0f<H0@000003HaP00d8@001o
o`3oOongOol3HaP1000000=S6003@Q0007oo0?mookMoo`=S604000000f<H
00=24000Ool0ogoo]goo0f<H0@000003HaP00d8@001oo`3oOongOol3HaP1
000000=S6003@Q0007oo0?mookMoo`=S604000000f<H00=24000Ool0ogoo
]goo0f<H0@000003HaP00d8@001oo`07Ool400000goo000000040020Ool4
003oOolQOol3HaP1000000=S6003@Q0007oo00Moo`<000Uoo`@000=oo`@0
03eoo`8000Yoo`03001oogoo009oo`<000Aoo`8000=oo`@000Uoo`D000Qo
o`<000=oo`P0009oo`03001oogoo00@0009oo`@0009oo`D0009oo`@00?Yo
o`=S604000000f<H00=24000Ool01Woo0P0000=oo`0000002Woo00<007oo
Ool00Woo00<007ooOol0?goo00<007ooOol01goo0`000Woo0P000Woo00@0
07oo0000009oo`8000=oo`03001oogoo00Qoo`8000Yoo`800003Ool00000
009oo`8000Aoo`03001oo`000080009oo`03001oogoo00=oo`8000Aoo`80
00Eoo`03001oogoo0?]oo`=S604000000f<H00=24000Ool01Woo00D007oo
Oomoo`0000Yoo`03001oogoo00=oo`03001oogoo03]oo`@000Uoo`03001o
o`00009oo`07001oogooOol007oo000017oo00D007ooOomoo`0000]oo`03
001oogoo00Qoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Ool0
07oo00000goo00<007ooOol00goo00<007ooOol017oo00<007ooOol00goo
00<007ooOol0nWoo0f<H0@000003HaP00d8@001oo`06Ool01@00Oomoogoo
00002Woo00<007ooOol017oo00<007ooOol0>Woo00@007ooOol000Qoo`04
001oogoo0002Ool01`00Oomoogoo001oo`0000Aoo`05001oogooOol0000<
Ool00`00Oomoo`07Ool01@00Oomoogoo000017oo00T007ooOomoo`00Ool0
07oo000017oo00<007ooOol00goo00<007ooOol00goo00<007ooOol017oo
00<007ooOol0nGoo0f<H0@000003HaP00d8@001oo`06Ool01@00Oomoogoo
00002Woo00<007ooOol017oo0P00>goo0P0000=oo`00Ool01goo00@007oo
Ool0009oo`07001oogooOol007oo000017oo00D007ooOomoo`0000eoo`80
00Moo`05001oogooOol00005Ool200000goo00000002Ool00`00Oomoo`02
Ool20005Ool00`00Oomoo`03Ool20004Ool2003jOol3HaP1000000=S6003
@Q0007oo00Ioo`05001oogooOol0000:Ool00`00Oomoo`05Ool00`00Oomo
o`0jOol00`00Ool00008Ool01`00Oomoogoo001oo`0000=oo`03001oo`00
00Aoo`05001oogooOol0000>Ool00`00Oomoo`05Ool01@00Oomoogoo0000
1Woo00<007oo00000goo00<007ooOol00goo00<007ooOol00goo00<007oo
Ool017oo00<007ooOol00goo00<007ooOol0n7oo0f<H0@000003HaP00d8@
001oo`07Ool30008Ool60002Ool4000mOol20007Ool20002Ool300000goo
0000000200000goo00000002Ool90007Ool50008Ool30003Ool700000goo
0000000200000goo000000020002Ool40002Ool50002Ool4003jOol3HaP1
000000=S6003@Q0007oo0?mookMoo`=S604000000f<H00=24000Ool0ogoo
]goo0f<H0@000003HaP00d8@001oo`3oOongOol3HaP1000000=S6003@Q00
07oo00Moo`05001oo`00001oo`060020Ool01000Ool00000ogoo8Goo0f<H
0@000003HaP00d8@001oo`07Ool30009Ool40003Ool3000mOol00`00Oomo
o`03Ool20004Ool30003Ool40009Ool3000:Ool30009Ool30003Ool80002
Ool00`00Oomoo`040003Ool20004Ool30003Ool00`00Oomoo`02Ool20002
Ool2003cOol3HaP1000000=S6003@Q0007oo00Moo`03001oo`0000]oo`03
001oogoo009oo`04001oogoo000lOol00`00Oomoo`02Ool01000Oomoo`00
0Woo00<007ooOol00P000goo00<007ooOol027oo00D007ooOomoo`0000Qo
o`05001oogooOol00008Ool00`00Ool00003Ool00`00Oomoo`03Ool00`00
Oomoo`020002Ool00`00Oomoo`06Ool01000Oomoo`000goo00@007ooOol0
00Aoo`05001oogooOol0003dOol3HaP1000000=S6003@Q0007oo00Ioo`05
001oogooOol0000:Ool00`00Oomoo`05Ool00`00Oomoo`0iOol00`00Ool0
0002Ool00`00Oomoo`02Ool00`00Ool00003Ool01@00Oomoogoo00003Woo
00<007ooOol02Woo00<007ooOol01Goo00D007ooOomoo`0000=oo`03001o
ogoo009oo`05001oo`00Ool00002Ool20007Ool01000Oomoo`000goo00D0
07ooOomoo`0000=oo`D00?Aoo`=S604000000f<H00=24000Ool01Woo00D0
07ooOomoo`0000Yoo`03001oogoo00Eoo`03001oogoo03Uoo`06001oogoo
001oo`0017oo00<007oo00000goo00D007ooOomoo`0000ioo`03001oogoo
00Yoo`03001oogoo00Eoo`05001oogooOol00004Ool02@00Oomoogoo001o
o`00Ool00004Ool00`00Oomoo`02Ool30002Ool01@00Oomoogoo000017oo
00D007ooOomoo`00009oo`03001oogoo0?9oo`=S604000000f<H00=24000
Ool01Woo00D007ooOomoo`0000Yoo`03001oogoo009oo`<003aoo`06001o
ogoo001oo`0017oo00<007oo00000goo00D007ooOomoo`0000aoo`<000Qo
o`@000Qoo`05001oogooOol00005Ool200000goo00000002Ool00`00Oomo
o`02Ool20002Ool01000Oomoo`000Woo00D007ooOomoo`0000Aoo`04001o
ogooOol4003dOol3HaP1000000=S6003@Q0007oo00Ioo`05001oogooOol0
000:Ool00`00Oomoo`02Ool00`00Oomoo`0kOol01`00Oomoogoo001oo`00
00Aoo`03001oo`0000=oo`05001oogooOol0000>Ool00`00Oomoo`06Ool0
0`00Oomoo`09Ool01@00Oomoogoo00001Woo00<007oo00000goo00<007oo
Ool00goo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool2003eOol3HaP1000000=S6003@Q0007oo00Moo`03001o
o`0000Qoo`06001oogoo001oo`000Woo00<007ooOol0>goo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoogoo0P000Woo00@007ooOol0
00Moo`05001oogooOol00008Ool00`00Oomoo`0:Ool00`00Ool00003Ool0
1`00Oomoogoo001oo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo
00@007ooOol000=oo`04001oogoo0002Ool01@00Oomoogoo0000mWoo0f<H
0@000003HaP00d8@001oo`07Ool30008Ool60002Ool4000iOol30002Ool2
0002Ool20002Ool20002Ool90008Ool30009Ool50008Ool30004Ool30000
17oo000007oo100000Aoo`00000000Aoo`<000=oo`<000=oo`@0009oo`80
0?Ioo`=S604000000f<H00=24000Ool0ogoo]goo0f<H0@000003HaP00d8@
001oo`3oOongOol3HaP1000000=S6003@Q0007oo00Moo`05001oo`00001o
o`06001]Ool01000Oomoo`00ogoo=7oo0f<H0@000003HaP00d8@001oo`08
Ool2001fOol2003oOoleOol3HaP1000000=S6003@Q0007oo00Moo`<000Uo
o`@000Eoo`8003eoo`8000]oo`8000Qoo`D000Qoo`@0009oo`P00003Ool0
0000009oo`@000=oo`<0009oo`D0009oo`03001oogoo009oo`80009oo`80
0?moo`Moo`=S604000000f<H00=24000Ool01Woo00D007ooOomoo`0000Yo
o`03001oogoo00Aoo`03001oogoo03eoo`03001oogoo00Uoo`03001oogoo
00]oo`03001oogoo00Eoo`05001oogooOol00003Ool00`00Oomoo`02Ool0
1@00Ool007oo00000Woo00<007ooOol01goo00<007oo00000goo00D007oo
Oomoo`0000=oo`05001oogooOol0003oOol8Ool3HaP1000000=S6003@Q00
07oo00Ioo`05001oogooOol0000:Ool00`00Oomoo`02Ool4000kOol40008
Ool5000<Ool00`00Oomoo`05Ool01@00Oomoogoo00000goo0P000goo00D0
07oo001oo`0000=oo`8000Aoo`800004Ool007oo0003Ool01000Oomoogoo
0P000goo1000ogoo27oo0f<H0@000003HaP00d8@001oo`06Ool01@00Oomo
ogoo00002Woo00<007ooOol00Woo00<007oo0000?7oo00@007ooOol000Uo
o`03001oo`0000Uoo`@000Qoo`05001oogooOol00005Ool00`00Oomoo`02
0002Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo0P0000=oo`00Ool0
0Woo00<007ooOol00Woo00D007ooOomoo`00009oo`03001oogoo0?moo`Io
o`=S604000000f<H00=24000Ool01Woo00D007ooOomoo`0000Yoo`03001o
ogoo00=oo`8003eoo`03001oo`0000Yoo`8000Uoo`03001oogoo00Uoo`05
001oogooOol00006Ool01000Ool000000Woo00<007ooOol00goo00@007oo
Ool000=oo`03001oo`0000=oo`03001oogoo009oo`03001oogoo009oo`80
0?moo`Uoo`=S604000000f<H00=24000Ool01goo00<007oo000027oo00H0
07ooOol007oo0004Ool00`00Oomoo`0lOol2000;Ool00`00Oomoo`07Ool0
0`00Oomoo`0:Ool01000Oomoo`000Woo00L007ooOomoo`00Ool00003Ool0
1000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000=oo`04001oogoo
0002Ool01@00Oomoogoo0000ogoo2Woo0f<H0@000003HaP00d8@001oo`07
Ool30008Ool60004Ool00`00Oomoo`0mOol00`00Oomoo`09Ool00`00Oomo
o`07Ool50008Ool30004Ool3000017oo000007oo100000Aoo`00000000Ao
o`<000=oo`<000=oo`@0009oo`800?moo`Yoo`=S604000000f<H00=24000
Ool0ogoo]goo0f<H0@000003HaP00d8@001oo`3oOongOol3HaP1000000=S
6003@Q0007oo00Moo`05001oo`00001oo`06001]Ool01000Oomoo`00ogoo
=7oo0f<H0@000003HaP00d8@001oo`08Ool2001fOol2003oOoleOol3HaP1
000000=S6003@Q0007oo00Moo`<000Uoo`@000=oo`@003]oo`@000]oo`80
00Qoo`D000Qoo`@0009oo`P00003Ool00000009oo`@000=oo`<0009oo`D0
009oo`03001oogoo009oo`80009oo`800?moo`Moo`=S604000000f<H00=2
4000Ool01Woo00D007ooOomoo`0000Yoo`03001oogoo00Eoo`03001oogoo
03aoo`03001oogoo00Uoo`03001oogoo00]oo`03001oogoo00Eoo`05001o
ogooOol00003Ool00`00Oomoo`02Ool01@00Ool007oo00000Woo00<007oo
Ool01goo00<007oo00000goo00D007ooOomoo`0000=oo`05001oogooOol0
003oOol8Ool3HaP1000000=S6003@Q0007oo00Ioo`05001oogooOol0000:
Ool00`00Oomoo`05Ool00`00Oomoo`0lOol00`00Oomoo`06Ool5000<Ool0
0`00Oomoo`05Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007oo
001oo`0000=oo`03001oogoo00Ioo`03001oo`0000=oo`05001oogooOol0
0004Ool4003oOol8Ool3HaP1000000=S6003@Q0007oo00Ioo`05001oogoo
Ool0000:Ool00`00Oomoo`03Ool3000lOol30008Ool200000goo001oo`08
Ool50007Ool01@00Oomoogoo000017oo0P000Woo0`0000=oo`00Ool00goo
00@007ooOomoo`D00003Ool007oo009oo`03001oogoo009oo`05001oogoo
Ool00002Ool00`00Oomoo`3oOol6Ool3HaP1000000=S6003@Q0007oo00Io
o`05001oogooOol0000:Ool00`00Oomoo`05Ool00`00Oomoo`0lOol00`00
Oomoo`08Ool20009Ool00`00Oomoo`09Ool01@00Oomoogoo00001Woo00@0
07oo0000009oo`03001oogoo00=oo`04001oogoo0003Ool00`00Ool00003
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool2003oOol9Ool3HaP1000000=S
6003@Q0007oo00Ioo`800003Ool0000000Moo`06001oogoo001oo`000Woo
00@007ooOol003]oo`04001oogoo000:Ool20009Ool00`00Oomoo`09Ool2
0002Ool01000Oomoo`000goo00<007oo00000goo00@007ooOol0009oo`04
001oogoo0003Ool00`00Ool00003Ool01@00Oomoo`00Ool00P000goo0P00
ogoo2Goo0f<H0@000003HaP00d8@001oo`07Ool30008Ool60002Ool3000l
Ool4000;Ool00`00Oomoo`07Ool50008Ool30004Ool3000017oo000007oo
100000Aoo`00000000Aoo`<000=oo`<000=oo`@0009oo`800?moo`Yoo`=S
604000000f<H00=24000Ool0ogoo]goo0f<H0@000003HaP00d8@001oo`3o
OongOol3HaP1000000=S6003@Q0007oo0;Moo`<001Yoo`03001oogoo021o
o`03001oogoo00aoo`03001oogoo03Aoo`03001oogoo00aoo`03001oogoo
03Aoo`03001oogoo031oo`=S604000000f<H00=24000Ool037oo1P00YWoo
00<007ooOol067oo00<007ooOol027oo0P0067oo00<007ooOol02goo00<0
07ooOol06goo00<007ooOol05goo00<007ooOol02Woo00<007ooOol06goo
0P0067oo00<007ooOol0<7oo0f<H0@000003HaP00d8@001oo`07Ool30009
Ool40003Ool4000lOol00`00Oomoo`03Ool20004Ool30003Ool40009Ool3
0008Ool40004Ool3000:Ool40002Ool30003Ool4000?Ool30003Ool01000
Oomoo`000Woo10002Woo00<007ooOol00goo0`0017oo0P0017oo0`000goo
0`000goo100017oo00<007ooOol02Goo00<007ooOol00Woo10000goo0P00
17oo10000Woo0P0000=oo`00Ool00Woo0P000goo1@000Woo0`0017oo00<0
07oo000017oo00<007ooOol02Goo00<007ooOol00goo0`0017oo0P000goo
10000goo10000goo0P0017oo0`000goo0`000goo100017oo00<007ooOol0
;goo0f<H0@000003HaP00d8@001oo`08Ool00`00Oomoo`0:Ool00`00Oomo
o`02Ool00`00Oomoo`0lOol30002Ool20002Ool2000017oo001oogoo0P00
0goo00<007ooOol027oo00D007ooOomoo`0000Qoo`03001oogoo00800003
Ool007oo009oo`03001oogoo00Qoo`05001oogooOol00003Ool01P00Oomo
o`00Ool0011oo`05001oo`00001oo`050004Ool00`00Oomoo`09Ool00`00
Oomoo`02Ool01@00Oomoogoo00000goo0P001Goo00D007ooOomoo`0000=o
o`03001oo`00009oo`03001oogoo00=oo`03001oogoo00Uoo`03001oogoo
009oo`04001oogoo0003Ool20005Ool00`00Oomoo`02Ool01000Ool00000
0goo0`000Woo0P001Goo00@007ooOol0009oo`04001oo`000004Ool00`00
Oomoo`09Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo0P000goo0P00
17oo00@007oo000000Aoo`8000Eoo`05001oogooOol00003Ool01P00Oomo
o`00Ool000Eoo`03001oogoo02moo`=S604000000f<H00=24000Ool027oo
00<007ooOol02Woo00<007ooOol00goo00<007ooOol0>goo00<007oo0000
0Woo00<007ooOol00Woo00<007oo00000goo00D007ooOomoo`0000Yoo`05
001oogooOol00008Ool01`00Oomoogoo001oo`0000ioo`05001oogooOol0
0003Ool01P00Oomoo`00Ool0011oo`07001oogoo001oo`00Ool00`0017oo
00<007ooOol02Goo00<007ooOol00Woo00D007ooOomoo`0000Yoo`05001o
ogooOol00003Ool00`00Ool00002Ool00`00Oomoo`03Ool00`00Oomoo`09
Ool00`00Oomoo`02Ool01000Oomoo`002Woo00<007ooOol00Woo00@007oo
Ool000Yoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`0017oo
00<007ooOol02Goo00<007ooOol00Woo00D007ooOomoo`0000Uoo`03001o
ogoo009oo`04001oogoo000;Ool01@00Oomoogoo00000goo00H007ooOol0
07oo0005Ool00`00Oomoo`0_Ool3HaP1000000=S6003@Q0007oo00Qoo`03
001oogoo00Yoo`03001oogoo00Aoo`03001oogoo03Yoo`06001oogoo001o
o`0017oo00<007oo00000goo00D007ooOomoo`0000Yoo`05001oogooOol0
0008Ool01`00Oomoogoo001oo`0000ioo`05001oogooOol00003Ool01P00
Oomoo`00Ool0011oo`07001oo`00001oo`00Ool00`0017oo00<007ooOol0
2Goo00<007ooOol00Woo00D007ooOomoo`0000Yoo`05001oogooOol00003
Ool00`00Ool00002Ool00`00Oomoo`03Ool00`00Oomoo`09Ool00`00Oomo
o`02Ool01000Oomoo`002Woo00<007ooOol00Woo00@007ooOol000Yoo`80
00=oo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol02Goo00<0
07ooOol00Woo00D007ooOomoo`0000Yoo`80009oo`04001oogoo000;Ool0
1@00Oomoogoo00000goo00H007ooOol007oo0005Ool00`00Oomoo`0_Ool3
HaP1000000=S6003@Q0007oo00Qoo`03001oogoo00Yoo`03001oogoo00Eo
o`03001oogoo03Uoo`06001oogoo001oo`0017oo00<007oo00000goo00D0
07ooOomoo`0000Yoo`05001oogooOol00008Ool01`00Oomoogoo001oo`00
00=oo`03001oogoo00Qoo`05001oogooOol00003Ool01P00Ool00000Ool0
00moo`@0009oo`<00003Ool0000000=oo`03001oogoo00Uoo`03001oogoo
009oo`05001oogooOol0000:Ool01@00Oomoogoo00000goo00<007oo0000
0Woo00<007ooOol00goo00<007ooOol02Goo00<007ooOol00Woo00@007oo
Ool000Yoo`04001oogooOol200000goo0000000<Ool01000Oomoo`000Woo
00D007oo000007oo008000Aoo`03001oogoo00Uoo`03001oogoo009oo`05
001oogooOol0000;Ool01@00Oomoo`00Ool00P002goo00D007ooOomoo`00
00=oo`06001oo`00001oo`001Goo00<007ooOol0;goo0f<H0@000003HaP0
0d8@001oo`08Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`0h
Ool01`00Oomoogoo001oo`0000Aoo`03001oo`0000=oo`05001oogooOol0
000:Ool01@00Oomoogoo000027oo00L007ooOomoo`00Ool00003Ool00`00
Oomoo`08Ool01@00Oomoogoo00000goo00<007ooOol08Goo00<007ooOol0
2Woo00D007ooOomoo`0000=oo`03001oogoo00Qoo`05001oogooOol00003
Ool00`00Oomoo`07Ool00`00Oomoo`0;Ool01@00Oomoogoo00000Woo00<0
07ooOol027oo00<007ooOol04Woo00@007ooOol0009oo`03001oogoo00Qo
o`03001oogoo00Yoo`05001oogooOol00003Ool00`00Oomoo`09Ool00`00
Oomoo`0?Ool01@00Oomoogoo00000goo00<007ooOol01goo00<007ooOol0
<7oo0f<H0@000003HaP00d8@001oo`07Ool30009Ool40003Ool4000iOol3
0002Ool200000goo0000000200000goo00000002Ool90007Ool50007Ool5
0002Ool50009Ool20003Ool5000QOol3000<Ool20002Ool50009Ool20003
Ool50008Ool2000=Ool01000Oomoogoo10002Goo0P0047oo1@000Woo1000
2Goo0P0037oo0P000Woo1@0027oo100047oo0P000goo1@002Goo00<007oo
Ool0<7oo0f<H0@000003HaP00d8@001oo`3oOongOol3HaP1000000=S6003
@Q0007oo0?mookMoo`=S604000000f<H00=24000Ool0ogoo]goo0f<H0@00
0003HaP00d8@001oo`0<Ool6003oOonUOol3HaP1000000=S6003@Q0007oo
00Qoo`03001oogoo00Yoo`03001oogoo009oo`<0009oo`<00003Ool007oo
03]oo`@000Qoo`@000Qoo`@000=oo`@000Uoo`<000Qoo`80009oo`80009o
o`<000Yoo`<00?moo`Qoo`=S604000000f<H00=24000Ool027oo00<007oo
Ool02Woo00<007ooOol00goo00D007ooOomoo`0000=oo`03001oogoo03]o
o`03001oogoo00Qoo`04001oogoo0008Ool01000Oomoo`000goo00@007oo
Ool000Qoo`05001oogooOol00007Ool00`00Oomoo`02Ool00`00Ool00003
Ool00`00Oomoo`08Ool00`00Oomoo`3oOol7Ool3HaP1000000=S6003@Q00
07oo00Moo`03001oo`0000Yoo`8000Eoo`05001oogooOol00002Ool2000m
Ool00`00Oomoo`08Ool01000Oomoo`0027oo00L007ooOomoo`00Ool0000@
Ool00`00Oomoo`05Ool600000goo001oo`0=Ool00`00Oomoo`3oOol7Ool3
HaP1000000=S6003@Q0007oo00Moo`03001oo`0000Uoo`04001oogoo0004
Ool02@00Oomoogoo001oo`00Ool0000mOol00`00Oomoo`08Ool01000Oomo
o`0027oo00L007ooOomoo`00Ool0000@Ool00`00Oomoo`06Ool01000Oomo
o`000Woo00<007ooOol037oo00<007ooOol0ogoo1goo0f<H0@000003HaP0
0d8@001oo`07Ool00`00Ool00009Ool01000Oomoo`0017oo00T007ooOomo
o`00Ool007oo0000?Goo00<007ooOol027oo00@007ooOol000Qoo`07001o
ogooOol007oo00000goo00<007ooOol027oo0`0027oo10000Woo00D007oo
Oomoo`0000Yoo`03001oogoo0?moo`Moo`=S604000000f<H00=24000Ool0
1Woo00D007ooOomoo`0000Qoo`05001oogooOol00003Ool01000Oomoogoo
0P000Woo00<007ooOol0>goo00<007ooOol027oo00@007ooOol000Qoo`07
001oogooOol007oo00000goo00<007ooOol02Woo00<007ooOol01goo0P00
0goo00D007ooOomoo`0000Yoo`03001oogoo0?moo`Moo`=S604000000f<H
00=24000Ool01Goo0`0000Aoo`00000000Ioo`80009oo`80009oo`<0009o
o`03001oogoo00<003]oo`8000Yoo`@000Qoo`@000=oo`@000Qoo`D000Qo
o`8000Aoo`D000Uoo`800?moo`Uoo`=S604000000f<H00=24000Ool0ogoo
]goo0f<H0@000003HaP00d8@001oo`3oOongOol3HaP1000000=S6003@Q00
07oo0?mookMoo`=S604000000f<H00=24000Ool037oo1P00ogooYGoo0f<H
0@000003HaP00d8@001oo`07Ool30009Ool40003Ool4000kOol40009Ool3
0008Ool40004Ool3000:Ool30003Ool4003oOolWOol3HaP1000000=S6003
@Q0007oo00Qoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo03Yo
o`03001oogoo00Uoo`05001oogooOol00008Ool01000Oomoo`000Woo00D0
07ooOomoo`0000Qoo`08001oogooOol007oo001oo`800?moobQoo`=S6040
00000f<H00=24000Ool027oo00<007ooOol02Woo00<007ooOol017oo00<0
07ooOol0>Woo0P002Woo00D007ooOomoo`0000Qoo`07001oogooOol007oo
000047oo00<007oo00000Woo00<007ooOol0ogoo9Woo0f<H0@000003HaP0
0d8@001oo`08Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0l
Ool00`00Oomoo`07Ool01@00Oomoogoo000027oo00L007ooOomoo`00Ool0
000@Ool00`00Ool00002Ool00`00Oomoo`3oOolVOol3HaP1000000=S6003
@Q0007oo00Qoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo03eo
o`03001oogoo00Ioo`05001oogooOol00008Ool01`00Oomoogoo001oo`00
00aoo`@0009oo`04001oogoo003oOolXOol3HaP1000000=S6003@Q0007oo
00Qoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo03eoo`03001o
ogoo00Ioo`05001oogooOol00008Ool01`00Oomoogoo001oo`0000=oo`03
001oogoo00Ioo`03001oogoo00=oo`04001oo`00003oOolXOol3HaP10000
00=S6003@Q0007oo00Qoo`03001oogoo00Yoo`03001oogoo009oo`<003ao
o`04001oogoo0008Ool01@00Oomoogoo000027oo00@007ooOol0009oo`03
001oogoo008000Qoo`03001oogoo0?moobmoo`=S604000000f<H00=24000
Ool01goo0`002Goo10001Goo00<007ooOol0>Woo10002Goo0`0027oo1000
17oo100027oo1@00ogoo;Goo0f<H0@000003HaP00d8@001oo`3oOongOol3
HaP1000000=S6003@Q0007oo0?mookMoo`=S604000000f<H00=24000Ool0
1goo00D007oo000007oo00H006eoo`04001oogoo003oOoldOol3HaP10000
00=S6003@Q0007oo00Qoo`8007Ioo`800?moocEoo`=S604000000f<H00=2
4000Ool01goo0`002Goo10000goo1000>goo10002Goo100027oo1@0027oo
10000Woo200000=oo`0000000Woo10000Woo1@0000=oo`0000000`000Woo
1000ogoo3Woo0f<H0@000003HaP00d8@001oo`06Ool01@00Oomoogoo0000
2Woo00<007ooOol017oo00<007ooOol0?Goo00<007ooOol02Goo00<007oo
Ool027oo00<007ooOol027oo00D007ooOomoo`0000=oo`03001oogoo009o
o`05001oo`00Ool00002Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00
Oomoo`03Ool00`00Oomoo`3oOol?Ool3HaP1000000=S6003@Q0007oo00Io
o`05001oogooOol0000:Ool00`00Oomoo`04Ool00`00Oomoo`0mOol00`00
Oomoo`09Ool00`00Oomoo`08Ool20009Ool01@00Oomoogoo00000goo0P00
0goo00D007oo001oo`0000=oo`8000Aoo`8000Eoo`03001oogoo00=oo`80
0?moo`moo`=S604000000f<H00=24000Ool01Woo00D007ooOomoo`0000Yo
o`03001oogoo00Aoo`03001oogoo03]oo`<000]oo`03001oogoo00Yoo`03
001oogoo00Ioo`05001oogooOol00005Ool00`00Oomoo`020002Ool00`00
Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`03Ool0
0`00Oomoo`3oOol=Ool3HaP1000000=S6003@Q0007oo00Ioo`05001oogoo
Ool0000:Ool00`00Oomoo`04Ool00`00Oomoo`0mOol00`00Oomoo`09Ool0
0`00Oomoo`0;Ool00`00Oomoo`05Ool01@00Oomoogoo00001Woo00@007oo
0000009oo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00=oo`03
001oogoo00=oo`03001oogoo0?moo`aoo`=S604000000f<H00=24000Ool0
1goo00<007oo000027oo00H007ooOol007oo0002Ool3000lOol01000Oomo
o`002Goo0`002Goo00D007ooOomoo`0000Qoo`04001oogoo0002Ool01`00
Oomoogoo001oo`0000=oo`04001oogoo0002Ool01000Oomoo`000goo00<0
07oo00000goo00@007ooOol0009oo`03001oogoo0?moo`aoo`=S60400000
0f<H00=24000Ool01goo0`0027oo1P0017oo00<007ooOol0>Woo10002goo
00<007ooOol027oo0`002Goo0`0017oo0`0000Aoo`00001oo`@00004Ool0
00000004Ool30003Ool30003Ool3003oOol?Ool3HaP1000000=S6003@Q00
07oo0?mookMoo`=S604000000f<H00=24000Ool0ogoo]goo0f<H0@000003
HaP00d8@001oo`0<Ool6003oOonUOol3HaP1000000=S6003@Q0007oo0?mo
okMoo`=S604000000f<H00=24000Ool027oo00<007ooOol02Woo00@007oo
Oomoo`@0009oo`D003]oo`D000Qoo`@000Qoo`@000=oo`@000Qoo`D00?mo
obMoo`=S604000000f<H00=24000Ool01goo00<007oo00002Woo0P0017oo
00@007ooOol0009oo`04001oogoo000oOol00`00Oomoo`06Ool01000Oomo
o`0027oo00L007ooOomoo`00Ool0000@Ool00`00Oomoo`3oOolUOol3HaP1
000000=S6003@Q0007oo00Moo`03001oo`0000Yoo`8000Aoo`04001oogoo
0002Ool01000Oomoo`00?goo00<007ooOol01Woo00@007ooOol000Qoo`07
001oogooOol007oo000047oo00<007ooOol0ogoo9Goo0f<H0@000003HaP0
0d8@001oo`07Ool00`00Ool00009Ool01000Oomoo`000goo00@007ooOol0
009oo`04001oogoo000kOol50008Ool01000Oomoo`0027oo00L007ooOomo
o`00Ool0000<Ool5003oOolWOol3HaP1000000=S6003@Q0007oo00Moo`03
001oo`0000Uoo`04001oogoo0003Ool01000Oomoo`000Woo00@007ooOol0
03]oo`03001oogoo00Yoo`04001oogoo0008Ool01`00Oomoogoo001oo`00
00=oo`03001oogoo00Ioo`03001oogoo0?moobUoo`=S604000000f<H00=2
4000Ool01Woo00D007ooOomoo`0000Qoo`05001oogooOol00002Ool01000
Ool000000Woo00@007ooOol003]oo`03001oogoo00Yoo`04001oogoo0008
Ool00`00Oomoo`0200000goo00000002Ool00`00Oomoo`06Ool00`00Oomo
o`3oOolYOol3HaP1000000=S6003@Q0007oo00Eoo`<00004Ool000000006
Ool20002Ool200000goo000000020002Ool4000lOol50008Ool40008Ool4
0003Ool40008Ool5003oOolWOol3HaP1000000=S6003@Q0007oo0?mookMo
o`=S604000000f<H00=24000Ool0ogoo]goo0f<H0@000003HaP00d8@001o
o`3oOongOol3HaP1000000=S6003@Q0007oo0?mookMoo`=S604000000f<H
00=24000Ool0ogoo]goo0f<H0@000003HaP00d8@001oo`3oOongOol3HaP1
000000=S6003@Q0007oo0?mookMoo`=S604000000f<H00=24000Ool0ogoo
]goo0f<H0@000003HaP00d8@001oo`3oOongOol3HaP1000000=S6003@Q00
07oo0?mookMoo`=S604000000f<H00=24000Ool0ogoo]goo0f<H0@000003
HaP00d8@001oo`3oOongOol3HaP1000000=S6003@Q0007oo0?mookMoo`=S
604000000f<H00=24000Ool0ogoo]goo0f<H0@000003HaP00d8@001oo`3o
OongOol3HaP1000000=S6003@Q0007oo0?mookMoo`=S604000000f<H00=2
4000Ool0ogoo]goo0f<H0@000003HaP00d8@001oo`3oOongOol3HaP10000
00=S6003@Q0007oo0?mookMoo`=S604000000f<H00=24000Ool0ogoo]goo
0f<H0@000003HaP00d8@001oo`3oOongOol3HaP1000000=S6003@Q0007oo
0?mookMoo`=S604000000f<H00=24000Ool0ogoo]goo0f<H0@000003HaP0
0d8@001oo`3oOongOol3HaP1000000=S6003@Q0007oo0?mookMoo`=S6040
00000f<H00=24000Ool0ogoo]goo0f<H0@000003HaP00d8@001oo`3oOong
Ool3HaP1000000=S6003@Q0007oo0?mookMoo`=S604000000f<H00=24000
Ool0ogoo]goo0f<H0@000003HaP00d8@001oo`3oOongOol3HaP1000000=S
6003@Q0007oo0?mookMoo`=S604000000f<H00=24000Ool0ogoo]goo0f<H
0@000003HaP00d8@001oo`3oOongOol3HaP1000000=S6003@Q0007oo0?mo
okMoo`=S604000000f<H00=24000Ool0ogoo]goo0f<H0@000003HaP00d8@
001oo`3oOongOol3HaP1000000=S6003@Q0007oo0?mookMoo`=S60400000
0f<H00=24000Ool0ogoo]goo0f<H0@000003HaP00d8@001oo`0COol50000
0goo0000000300000goo000000030002OolA0003Ool40002Ool30002Ool5
00000goo000000040006Ool30002Ool00`00Ool000050002Ool40002Ool4
0002Ool40002Ool50002Ool4003oOoldOol3HaP1000000=S6003@Q0007oo
01=oo`07001oogooOol007oo00001Woo00@007ooOol0009oo`03001oogoo
00=oo`07001oo`00Ool007oo00000goo00D007ooOomoo`0000Ioo`05001o
ogooOol0000:Ool00`00Oomoo`05Ool00`00Oomoo`0200000goo001oo`06
Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`06Ool01000Oomo
o`00ogoo=goo0f<H0@000003HaP00d8@001oo`07Ool3000;Ool300000goo
001oo`05Ool01000Oomoo`000Woo1@0000Moo`00Ool007oo001oo`050003
Ool00`00Oomoo`04Ool01@00Oomoogoo00001Goo1@0027oo00<007oo0000
0P0000=oo`00000010000Woo00<007ooOol017oo00<007ooOol00goo00<0
07ooOol00Woo10000goo00<007ooOol02Goo1000ogoo:7oo0f<H0@000003
HaP00d8@001oo`06Ool50008Ool30003Ool200000goo00000002Ool20000
1Goo001oogoo00000Woo0P0000=oo`0000000`001Goo00D007ooOomoo`00
00Ioo`04001oogooOol20002Ool00`00Ool00004Ool00`00Oomoo`05Ool2
0002Ool01000Ool000000Woo0P000Woo00<007ooOol017oo00<007ooOol0
0goo00<007ooOol00Woo00D007ooOomoo`00009oo`03001oogoo00Uoo`D0
0?moobMoo`=S604000000f<H00=24000Ool01goo0`002Goo00<007ooOol0
17oo10000Woo0`0017oo0P000Woo1P000Woo0`000Woo1@000goo0P001Goo
0`000Woo100027oo0P000Woo00@007ooOomoo`8000=oo`@000Aoo`03001o
ogoo009oo`8000Aoo`@0009oo`D000Uoo`800?moobUoo`=S604000000f<H
00=24000Ool01goo00<007oo00002Goo00<007ooOol00P0027oo00<007oo
Ool05goo00<007ooOol06goo0P000Woo00<007ooOol01goo00<007ooOol0
17oo00<007ooOol03goo00<007ooOol02Goo1000ogoo:7oo0f<H0@000003
HaP00d8@001oo`0COol300000goo001oo`06Ool2000POol00`00Oomoo`0C
Ool20002Ool3000>Ool20005Ool00`00Oomoo`3oOom1Ool3HaP1000000=S
6003@Q0007oo0?mookMoo`=S604000000f<H00=24000Ool0ogoo]goo0f<H
0@000003HaP00d8@001oo`3oOongOol3HaP1000000=S6003@Q0007oo0?mo
okMoo`=S604000000f<H00=240000000o`00]`000f<H0@000003HaSo@Q2k
@Q02HaP100000;iS6003@Q1S66<H0?iS604000001f<H<@001F<H8@001F<H
@@001F<H4@0016<H00=246<HHaP0oV<H0@000007HaP00goo@Q12400<@Q00
0`00Oom2400>@Q000`00@Q12400=@Q000`00HaQS6003HaP00goo@Q12400=
@Q000`00@Q12400=@Q000`00HaQS6003HaP00goo@Q12400<@Q000`00Oom2
400>@Q000`00@Q12400=@Q000`00@Q12400=@Q000`00HaQS6004HaP?@Q00
0`00HaQS6002HaP00d8@HaQS603nHaP1000000MS6003OomS66<H00aS6003
001oof<H00eS6003@Q0006<H00eS6003@Q0006<H00AS6003OomS66<H00aS
6003@Q0006<H00eS6003@Q0006<H00AS6003OomS66<H00aS6003001oof<H
00eS6003@Q0006<H00eS6003@Q0006<H00eS6003@Q0006<H01=S6003@Q00
06<H00=S6003@Q1S66<H0?iS604000001f<H00=oof<HHaP036<H00<007oo
HaP03F<H00=24000HaP00V<H2@000V<H00=24000HaP016<H00Aoof<HHaQS
60P000=S6003@Q0006<H00T00006HaP00000HaQ240001F<H00=oof<HHaP0
0f<H00E246<HHaQS67oo00AS6003001oof<H00IS60Ioo`03HaQ2400000=S
60=oo`M24003HaQ2400000iS6003@Q0006<H00IS60@000=S60@0009S6003
@Q0006<H00=S6003@Q1S66<H0?iS604000001f<H00Aoof<HHaQS60P000=S
6003001oof<H00P000ES6006@Q0006<HHaP004801@0000=S600000000V<H
00=24000HaP016<H00Aoof<HHaP000IS608000=S6004@Q0006<H0007Ool4
00000f<H@Q000005HaP00gooHaQS6002HaP0148@HaQ246<H0T8@16<H00<0
07ooHaP01F<H1d8@00=S648@00000V<H1D8@00=S67ooOol00Woo00A246<H
@Q0000iS6003@Q0006<H00IS6004001S60000003HaP01000HaP000000V<H
00=24000HaP00f<H00=246<HHaP0oV<H0@000007HaP01GooHaQS66<H0000
1Woo00L006<HHaQS6000OomS60030005@P020003HaP01T8@001S66<H0012
00D00003HaP00000009S6003@Q0006<H00AS6003OomS600000X0009S6004
@Q0006<H0004Ool60002HaP00d8@001S6004HaP00gooHaQS6002HaP01d8@
HaQ2448@OomS648@00=S6003001oof<H00ES6003@Q1ood8@00924006HaQ2
46<H@Q0006<H348@00=S648@00003V<H00=24000HaP01V<H2`000V<H00=2
4000HaP00f<H00=246<HHaP0oV<H0@000007HaP01GooHaQS66<H00001Woo
00X006<HHaQS6000OomS6000Oomoh0I20006001S66<HHaQ240000V<H00<0
048000001`000V<H00=24000HaP016<H00=oof<H000016<H0d8@00=S6000
00000V<H00A24000HaP000Aoo`04001S60<H@Q020002HaP00d8@001S6004
HaP00gooHaQS6003HaP3@Q02Ool01T8@HaQS66<H001oo`9S60E24003OomS
67oo009oo`05@Q1S648@001S6008@Q001f<H@Q12448@HaQ2400000AS60=o
o`=S6006@Q1S66<HHaQ2400026<H2P000V<H00=24000HaP00f<H00=246<H
HaP0oV<H0@000007HaP01GooHaQS66<H00001Woo00P006<HHaQS6000OomS
60000WoP2@0000=S648@00000V<H00<0048000001@0000I20000HaQS648@
0005HaP00gooHaP0000900001f<H001S648@001S600000Aoo`05000366<H
@Q000003HaP00d8@001S6004HaP00gooHaQS6004HaP4@Q04HaP01000OomS
66<H1D8@00Yood8@@Q1246<H@Q1S648@001S60I240=S6092409S6003@Q00
06<H009S60A240=S6092409S6003@Q0006<H00IS60/0009S6003@Q0006<H
00=S6003@Q1S66<H0?iS604000001f<H00Eoof<HHaQS600000Ioo`08001S
66<HHaP007ooHaP0009oh005Oomoh7oPOol00005HaP01d8@001S66<H0012
000000ES6080009S6003@Q0006<H00AS6003OomS66<H00L00009HaP00000
001S648@001S600000Aoo`050003o`<H@Q000003HaP00d8@001S6004HaP0
0gooHaQS6005HaP00d8@OomS6004HaP01P00OomS66<H@Q1S609oo`04@Q1o
od8@HaP3@Q0016<H@Q0006<H2d8@0V<H00=24000HaP00V<H0T8@1V<H00E2
46<HHaQ2400000QS60T000=S6003@Q0006<H00=S6003@Q1S66<H0?iS6040
00001f<H00Eoof<HHaQS600000Ioo`08001S66<HHaP007ooHaP0009oh0D0
00ES6007@Q0006<HHaP0048000001F<H0P000V<H00=24000HaP016<H00Io
of<HHaQS6000Ool800001F<H@Q0006<H000017oo1@000f<H00=24000HaP0
16<H00=oof<HHaP016<H0T8@00=oof<HHaP00f<H00@007ooHaQS60E24003
OomS66<H0092409S6003@Q0006<H00]2409S6003@Q0006<H009S60A240=S
6092409S6003@Q0006<H00QS60P000=S6003@Q0006<H00=S6003@Q1S66<H
0?iS604000001f<H00Eoof<HHaQS600000Aoo`<000=S6004001oof<HHaP2
0006HaP20002HaP01d8@001S66<H0012000000ES6080009S6003@Q0006<H
00AS6005OomS66<HHaP00006Ool02000HaQS66<H@Q0006<H0007Ool00`00
HaQS6002HaP00d8@001S6004HaP00gooHaQS6003HaP4@Q000gooHaQS6002
HaP01000OomS66<H2D8@0f<H00=24000HaP0148@0goo148@0V<H00=24000
HaP01V<H0d8@16<H00=24000HaP026<H0`000V<H0P0016<H00=24000HaP0
0f<H00=246<HHaP0oV<H0@000007HaP01GooHaQS66<H000017oo00<007oo
00000f<H00<007ooHaP02F<H0P000V<H00M24000HaQS6000@P000005HaP2
0002HaP00d8@001S6004HaP00gooHaQS6002HaP500000goo001S6002HaP0
148@001S60001Goo0`0016<H00=24000HaP016<H00=oof<HHaP00f<H00E2
47ooHaQ247oo00AS6005001oof<HHaQ24002HaP00d8@Oom24006HaP00d8@
001S600;@Q02HaP00d8@001S600=HaP00d8@001S6008HaP00`00HaP00002
HaP20004HaP00d8@001S6003HaP00d8@HaQS603nHaP1000000MS6004OomS
66<HHaP70004HaP00`00OomS6006HaP50002HaP0148@001S66<H2P000V<H
00=24000HaP016<H00=oof<HHaP00V<H1`000f<H00A24000HaP000Eoo`80
00ES6003@Q0006<H00AS6003OomS66<H00=S6004@Q1S66<H@Q05HaP01000
OomS66<H1D8@1f<H00A24000HaQS60U240=S6003@Q0006<H00eS6003@Q00
06<H00QS60<0009S608000AS6003@Q0006<H00=S6003@Q1S66<H0?iS6040
00001f<H00=oof<HHaP036<H00<007ooHaP03F<H00=24000HaP03F<H00=2
4000HaP016<H00=oof<HHaP036<H00=24000HaP01`001V<H00=24000HaP0
16<H00=oof<HHaP036<H00<007ooHaP03F<H00=24000HaP03F<H00=24000
HaP03F<H00=24000HaP04f<H00=24000HaP00f<H00=246<HHaP0oV<H0@00
0007HaP00gooHaQS600<HaP00`00OomS600=HaP00d8@001S600=HaP00d8@
001S6004HaP00gooHaQS600<HaP00d8@001S600=HaP00d8@001S6004HaP0
0gooHaQS600<HaP00`00OomS600=HaP00d8@001S600=HaP00d8@001S600=
HaP00d8@001S600CHaP00d8@001S6003HaP00d8@HaQS603nHaP1000000MS
60moo`03001oogoo00ioo`03001oogoo00eoo`03001S66<H00=S611oo`03
001oogoo00eoo`03001S66<H00=S60moo`03001oogoo00ioo`03001oogoo
00eoo`03001oogoo00eoo`03001S66<H00AS60moo`03001S66<H009S6003
@Q1S66<H0?iS60400000_V<H00=246<HHaP0oV<H0@00002nHaP00d8@HaQS
603nHaP1000000=S6?mook]oo`9S604000000f<Hod8@^d8@0V<H0@00003o
HaS0HaP100000;US6003001S66<H0?mS60AS6040000026<H1P005F<H1`00
56<H1`008f<H1`006F<H0P007f<H200026<H00<006<HHaP0of<H16<H0@00
0009HaP00`00HaQS6003HaP00`00HaP00002HaP3000=HaP50002HaP20000
16<H001S60000V<H00<006<HHaP02V<H10000V<H0`000f<H100000AS6000
HaQS60<00005HaP006<HHaP0000?HaP01@00HaQS66<H00000V<H0`000V<H
00@006<HHaP000eS6003001S6000009S6003001S66<H008000=S60<0009S
6004001S66<H000<HaP00`00HaQS6002HaP00`00HaQS60030002HaP00`00
HaP00002003oHaP4HaP1000000US6003001S66<H00=S6005001S6000HaP0
0002HaP00`00HaQS600;HaP00`00HaQS6003HaP00`00HaQS6002000016<H
001S600036<H00D006<HHaQS6000009S6006001S66<H001S60000f<H00<0
06<H00000V<H00<006<HHaP00P000V<H00<006<HHaP03F<H00L006<HHaQS
6000HaP00003HaP00`00HaP00002HaP00`00HaQS600;HaP00`00HaP00002
HaP00`00HaP00002HaP00`00HaP00003HaP00`00HaP00002HaP00`00HaQS
600:HaP00`00HaQS6002HaP00`00HaP00002HaP01P00HaQS6000HaP0009S
6003001S66<H0?mS605S604000002F<H00<006<HHaP00f<H00D006<H001S
6000011S6003001S66<H00=S6009001S66<HHaP006<H001S600000aS6005
001S66<HHaP00002HaP00`00HaQS6002HaP01`00HaQS66<H001S6000009S
6005001S66<HHaP00002HaP00`00HaQS600<HaP20003HaP00`00HaP00005
HaP300000f<H001S600;HaP00`00HaP00002HaP00`00HaQS6002HaP00`00
HaP00005HaP01000HaQS600036<H00<006<HHaP00V<H00<006<H00001F<H
00<006<H00000V<H00<006<HHaP0of<H0F<H0@000009HaP00`00HaQS6003
HaP01000HaP006<H10003F<H00<006<HHaP00f<H00T006<HHaQS6000HaP0
06<H00003f<H0P000V<H100000=S600000000`0000ES6000HaQS600000=S
6004001S66<H000=HaP40002HaP00`00HaP0000400001V<H00000000HaP0
00aS6003001S6000009S6003001S60000080009S60D00005HaP006<HHaP0
000<HaP00`00HaQS6002HaP00`00HaP000030002HaP00`00HaP00002HaP0
0`00HaQS603oHaP1HaP1000000US60D00006HaP006<H001S60000V<H00<0
06<HHaP02f<H10000V<H00<006<HHaP00P0000AS6000HaP000eS608000AS
6006001S66<H001S60000f<H00<006<H00000V<H00<006<HHaP00`0000=S
6000HaP036<H00@006<HHaP0009S6003001S600000=S6080009S6004001S
66<H000;HaP02000HaP00000HaP006<H0002HaP00`00HaP00003HaP00`00
HaP00002HaP00`00HaQS600:HaP600001F<H001S66<H00000V<H00<006<H
00000V<H00<006<HHaP0of<H0F<H0@000009HaP00`00HaQS6003HaP00`00
HaP00002HaP3000=HaP00`00HaQS6004HaP200000f<H001S6004000;HaP0
1@00HaQS66<H00000V<H0`000f<H0`000V<H0P0000MS6000000006<H001S
6002000=HaP01`00HaQS66<H001S6000009S60<00005HaP006<HHaP00002
HaP00`00HaQS6009HaP01@00HaP006<H00000f<H0P000f<H0`000V<H1000
36<H00<006<HHaP00V<H00<006<HHaP00`000V<H00<006<H00000P00of<H
16<H0@000009HaP00`00HaQS6005HaP00`00HaQS600@HaP00`00HaQS6007
HaP01@00HaQS66<H000036<H00D006<HHaQS600001AS6003001S66<H00eS
6003001S66<H00=S6003001S66<H01MS6003001S66<H019S6003001S66<H
00YS6003001S66<H009S6003001S66<H00ES6003001S66<H0?mS60IS6040
00002F<H1@0000AS6000HaP0019S60D000ES6003001S600000mS60@001AS
6003001S66<H00eS6003001S66<H00=S608001QS6003001S66<H01mS6003
001S66<H009S6003001S66<H00ES6003001S66<H0?mS60IS60400000of<H
`6<H0@00003oHaS0HaP1000000=S6?l04;/0409S604000000f<H0P0@2000
o`0@/@0@0V<H0@000003HaP20107HaP00d8@0000403o012;010F0002010;
00000`0@HaQS6001000000=S60804004Ool000000003Ool00d8@00004003
0104Ool30103Ool2010017oo010047oo0P0@0goo0`0@00Aoo`0@011oo`80
4004Ool0400@Ool20104Ool301000goo01004008010017oo010047oo0P0@
00=oo`0@Ool00`0@0goo0P0@00Aoo`0@010040=oo`<040Aoo`<04006Ool0
47ooOol047oo0P0@00=oo`0@01001@0@00=oo`0@01000P0@17oo00<047oo
01000P0@00Aoo`0@011oo`@040Eoo`8040Aoo`804003Ool0400@009oo`04
011oogooOol301000goo0100403]010:HaP00`00OomS6008HaP00`000100
4009HaP00d8@00004002HaP1000000=S60804003Ool000000080009oo`03
@Q00000@00<04004Ool0400@Ool2010017oo010047oo0P0@00Eoo`0@011o
o`0@009oo`D04003Ool0400@00<04004Ool0400@Ool201000goo01004003
01000goo01004009010017oo010047oo0P0@00=oo`0@Ool00P0@00=oo`0@
01000`0@00Aoo`0@011oo`<04004Ool0400@Ool301001Goo010047oo0100
0Woo00D047oo010047oo00L04003Ool0400@00804003Ool0400@00D04004
Ool0400@Ool501000goo01004004010017oo010047oo0P0@00Aoo`0@011o
o`804004Ool0400@Ool201000goo0100403]0102HaP50003HaP00`00OomS
6007000016<H0000400@0V<H0P000f<H00D006<H@Q00000@009S60400000
0f<H0P0@0goo00H007oo0000048@0004010017oo010047oo0P0@00Aoo`0@
011oo`804005Ool0400@Ool04005Ool201000goo01004003010017oo0100
47oo0P0@17oo0P0@00=oo`0@01002@0@00=oo`0@Ool00Woo00@047oo011o
o`804003Ool0400@00<04004Ool0400@Ool301000goo0100400401001Goo
010047oo01000Woo00D047oo010047oo00L04003Ool0400@008040Aoo`<0
409oo`804003Ool0400@00<04003Ool0400@00@04004Ool0400@Ool20100
17oo010047oo0P0@00Aoo`0@011oo`804003Ool0400@0>d040YS6004001o
of<H0005HaP00`00HaP000020103HaP200001f<H000006<H@Q00000@009S
604000000f<H0P0@0goo00H007ooG^00048@0004010017oo010047oo0P0@
00Aoo`0@011oo`804005Ool0400@Ool04002Ool2010017oo010047oo1@0@
00Aoo`0@011oo`804004Ool0400@Ool201000goo010040020103Ool40102
Ool20103Ool01@0@Ool0400@Ool01@0@00Aoo`0@011oo`<04003Ool0400@
0080409oo`<04006Ool047ooOol047oo0P0@00=oo`0@01001@0@00=oo`0@
01000P0@00Aoo`0@011oo`<0409oo`804003Ool0400@00<04003Ool0400@
00@04004Ool0400@Ool2010017oo010047oo0P0@00Aoo`0@011oo`804003
Ool0400@0>d040YS6004001oof<H0005HaP00`00HaP000020104HaP30002
HaP00d8@00004002HaP1000000=S60804005Ool00000001Nh002@P020004
0102Ool01@0@Ool0400@Ool00P0@00Aoo`0@011oo`804004Ool0400@Ool5
0102Ool40102Ool4010017oo010047oo0P0@00=oo`0@01002@0@0Woo0`0@
0Woo00<047oo01001`0@0Woo200@00=oo`0@0100100@00Ioo`0@Oomoo`0@
Ool:01000goo01004002010017oo010047oo1`0@00=oo`0@01000`0@00=o
o`0@0100100@00Aoo`0@Oomoo`804004Ool0400@Ool201000goo01004003
0102Ooo^010:HaP01000OomS60001F<H00<006<H00000P0@16<H0`000V<H
00=2400001000V<H0@000003HaP20104Ool01@00On1205kP0000100@00=o
o`0@01002@0@00Aoo`0@011ooaX04003Ool0400@00T0409oo`<0409ooa@0
4005Ool0400@011oo`0B01000goo0100400=01000goo0100400301000goo
0100400701000goo0100400301000goo0100403f010:HaP01000OomS6000
1F<H00<006<H00000P0@0f<H0P0000MS6000001S648@00004002HaP10000
00=S60804005Ool00000001oo`020002@P02000201000goo010040090100
17oo010047oo9P0@00=oo`0@01000`0@00=oo`0@01004P0@00=oo`0@0100
500@00=oo`0@01004`0@00=oo`0@01001`0@00=oo`0@0100o00@2V<H00<0
07ooHaP01`0000AS60000100409S608000=S6005001S648@00004002HaP1
000000=S60804003Ool0000000@00003On0000000?l048/040YS6003001o
of<H00QS60030000400@00US6003@Q00000@009S604000000f<H0P0@1d8@
0P00o`0@UP0@00<0000@0100200@00<0000@01002P0@00@0000@HaQS6040
00000f<Ho`0@^`0@0V<H0@00003oHaS0HaP100000?mS6<1S60400000of<H
`6<H0@000000\
\>"], "Picture",
  CellMargins->{{20, 0}, {0, 0}},
  Evaluatable->False,
  ImageSize->{448.063, 267},
  ImageMargins->{{11, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Buffer = ReadNetlist["\<Buffer.net\>", Simulator \[Rule] "\<PSpice\>"]; 
    \nDisplayForm\ @\ Buffer\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"\<\"Circuit:\"\>"},
          {
            TagBox[GridBox[{
                  {"\<\"  \"\>", 
                    InterpretationBox[GridBox[{
                          {GridBox[{
                                {
                                  \("Netlist ("\[InvisibleSpace]"Raw"\
\[InvisibleSpace]", "\[InvisibleSpace]9\[InvisibleSpace]" Entries):"\)},
                                {
                                  TagBox[GridBox[{
                                        {"\<\" \"\>", 
                                        InterpretationBox[GridBox[{
                                        {
                                        RowBox[{"{", 
                                        RowBox[{
                                        "\<\"V$VDD\"\>", ",", \({"5", "0"}\), 
                                        ",", \(Type \[Rule] VoltageSource\), 
                                        ",", 
                                        RowBox[{"Value", "\[Rule]", 
                                        RowBox[{"{", 
                                        RowBox[{
                                        RowBox[{"DC", "\[Rule]", 
                                        StyleBox["5.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->1]}], ",", 
                                        RowBox[{"Transient", "\[Rule]", 
                                        StyleBox["5.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->1]}]}], "}"}]}], ",", 
                                        \(Symbolic \[Rule] {DC \[Rule] V$VDD, 
                                        Transient \[Rule] V$VDD}\)}], "}"}]},
                                        {
                                        \({"Q$T1", {"3" \[Rule] "C", 
                                        "1" \[Rule] "B", "2" \[Rule] "E"}, 
                                        Model \[Rule] 
                                        Model["BJT", "Q2N2222A", "Q$T1"], 
                                        Selector \[Rule] 
                                        Selector["BJT", "Q2N2222A", "Q$T1"], 
                                        Parameters \[Rule] 
                                        Parameters["BJT", "Q2N2222A", "Q$T1"]}
                                        \)},
                                        {\({"I$I1", {"2", "0"}, 
                                        Type \[Rule] CurrentSource, 
                                        Value \[Rule] {DC \[Rule] 
                                        4.99999999999999911`*^-6, 
                                        Transient \[Rule] 
                                        4.99999999999999911`*^-6}, 
                                        Symbolic \[Rule] {DC \[Rule] I$I1, 
                                        Transient \[Rule] I$I1}}\)},
                                        {
                                        RowBox[{"{", 
                                        RowBox[{
                                        "\<\"V$VIN\"\>", ",", \({"1", "0"}\), 
                                        ",", \(Type \[Rule] VoltageSource\), 
                                        ",", 
                                        RowBox[{"Value", "\[Rule]", 
                                        RowBox[{"{", 
                                        RowBox[{
                                        RowBox[{"DC", "\[Rule]", 
                                        StyleBox["3.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->1]}], ",", 
                                        RowBox[{"AC", "\[Rule]", 
                                        StyleBox["1.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->1]}], ",", 
                                        RowBox[{"Transient", "\[Rule]", 
                                        StyleBox["3.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->1]}]}], "}"}]}], ",", 
                                        \(Symbolic \[Rule] V$VIN\)}], "}"}]},
                                        {
                                        \({"I$I2", {"VOUT", "0"}, 
                                        Type \[Rule] CurrentSource, 
                                        Value \[Rule] {DC \[Rule] 
                                        9.99999999999999822`*^-6, 
                                        Transient \[Rule] 
                                        \(InterpolatingFunction[{{
                                        \(-1.79769313486231441`*^308\), 
                                        1.79769313486231441`*^308}}, {1, 0, 
                                        True, 
                                        Real, {1}, {0}}, {{
                                        \(-1.79769313486231441`*^308\), 
                                        \(-10.`\), 0.`, 1.`*^-7, 2.`*^-7, 
                                        10.000000200000001`, 
                                        1.79769313486231441`*^308}}, {{
                                        9.99999999999999822`*^-6}, {
                                        9.99999999999999822`*^-6}, {
                                        9.99999999999999822`*^-6}, {
                                        0.00002`}, {
                                        9.99999999999999822`*^-6}, {
                                        9.99999999999999822`*^-6}, {
                                        9.99999999999999822`*^-6}}]\)[Time]}, 
                                        Symbolic \[Rule] {DC \[Rule] I$I2, 
                                        Transient \[Rule] I$I2}}\)},
                                        {
                                        \({"Q$T3", {"3" \[Rule] "C", 
                                        "4" \[Rule] "B", "5" \[Rule] "E"}, 
                                        Model \[Rule] 
                                        Model["BJT", "Q2N2907A", "Q$T3"], 
                                        Selector \[Rule] 
                                        Selector["BJT", "Q2N2907A", "Q$T3"], 
                                        Parameters \[Rule] 
                                        Parameters["BJT", "Q2N2907A", "Q$T3"]}
                                        \)},
                                        {
                                        \({"Q$T4", {"4" \[Rule] "C", 
                                        "4" \[Rule] "B", "5" \[Rule] "E"}, 
                                        Model \[Rule] 
                                        Model["BJT", "Q2N2907A", "Q$T4"], 
                                        Selector \[Rule] 
                                        Selector["BJT", "Q2N2907A", "Q$T4"], 
                                        Parameters \[Rule] 
                                        Parameters["BJT", "Q2N2907A", "Q$T4"]}
                                        \)},
                                        {
                                        \({"Q$T5", {"VOUT" \[Rule] "C", 
                                        "3" \[Rule] "B", "5" \[Rule] "E"}, 
                                        Model \[Rule] 
                                        Model["BJT", "Q2N2907A", "Q$T5"], 
                                        Selector \[Rule] 
                                        Selector["BJT", "Q2N2907A", "Q$T5"], 
                                        Parameters \[Rule] 
                                        Parameters["BJT", "Q2N2907A", "Q$T5"]}
                                        \)},
                                        {
                                        \({"Q$T2", {"4" \[Rule] "C", 
                                        "VOUT" \[Rule] "B", "2" \[Rule] "E"}, 
                                        Model \[Rule] 
                                        Model["BJT", "Q2N2222A", "Q$T2"], 
                                        Selector \[Rule] 
                                        Selector["BJT", "Q2N2222A", "Q$T2"], 
                                        Parameters \[Rule] 
                                        Parameters["BJT", "Q2N2222A", "Q$T2"]}
                                        \)}
                                        },
                                        RowSpacings->1,
                                        ColumnSpacings->3,
                                        RowAlignments->Baseline,
                                        ColumnAlignments->{Left}],
                                        TableForm[ {
                                        
                                        SequenceForm[ {"V$VDD", {"5", "0"}, 
                                        Type -> VoltageSource, Value -> {
                                        DC -> 5.0, Transient -> 5.0}, 
                                        Symbolic -> {DC -> V$VDD, 
                                        Transient -> V$VDD}}], 
                                        SequenceForm[ {"Q$T1", {"3" -> "C", 
                                        "1" -> "B", "2" -> "E"}, Model -> 
                                        Model[ "BJT", "Q2N2222A", "Q$T1"], 
                                        Selector -> Selector[ 
                                        "BJT", "Q2N2222A", "Q$T1"], 
                                        Parameters -> Parameters[ 
                                        "BJT", "Q2N2222A", "Q$T1"]}], 
                                        
                                        SequenceForm[ {"I$I1", {"2", "0"}, 
                                        Type -> CurrentSource, Value -> {
                                        DC -> .49999999999999987*^-5, 
                                        Transient -> .49999999999999987*^-5}, 
                                        Symbolic -> {DC -> I$I1, Transient -> 
                                        I$I1}}], 
                                        
                                        SequenceForm[ {"V$VIN", {"1", "0"}, 
                                        Type -> VoltageSource, Value -> {
                                        DC -> 3.0, AC -> 1.0, Transient -> 
                                        3.0}, Symbolic -> V$VIN}], 
                                        
                                        SequenceForm[ {"I$I2", {"VOUT", "0"}, 
                                        Type -> CurrentSource, Value -> {
                                        DC -> .99999999999999974*^-5, 
                                        Transient -> 
                                        InterpolatingFunction[
                                         {{-.17976931348623157*^309,
                                         .17976931348623157*^309}}, {1, 0, 
                                        True, Real, {1}, {
                                        0}}, {{-.17976931348623157*^309,
                                         -.1*^2, 
                                        0.0, .99999999999999995*^-7,
                                         .19999999999999999*^-6, 
                                        10.000000200000001,
                                         .17976931348623157*^309}},
                                         {{.99999999999999974*^-5},
                                         {.99999999999999974*^-5},
                                         {.99999999999999974*^-5},
                                         {.000020000000000000002},
                                         {.99999999999999974*^-5},
                                         {.99999999999999974*^-5},
                                         {.99999999999999974*^-5}}][ Time]}, 
                                        Symbolic -> {DC -> I$I2, Transient -> 
                                        I$I2}}], 
                                        
                                        SequenceForm[ {"Q$T3", {"3" -> "C", 
                                        "4" -> "B", "5" -> "E"}, Model -> 
                                        Model[ "BJT", "Q2N2907A", "Q$T3"], 
                                        Selector -> Selector[ 
                                        "BJT", "Q2N2907A", "Q$T3"], 
                                        Parameters -> Parameters[ 
                                        "BJT", "Q2N2907A", "Q$T3"]}], 
                                        
                                        SequenceForm[ {"Q$T4", {"4" -> "C", 
                                        "4" -> "B", "5" -> "E"}, Model -> 
                                        Model[ "BJT", "Q2N2907A", "Q$T4"], 
                                        Selector -> Selector[ 
                                        "BJT", "Q2N2907A", "Q$T4"], 
                                        Parameters -> Parameters[ 
                                        "BJT", "Q2N2907A", "Q$T4"]}], 
                                        
                                        SequenceForm[ {"Q$T5", {"VOUT" -> 
                                        "C", "3" -> "B", "5" -> "E"}, 
                                        Model -> Model[ 
                                        "BJT", "Q2N2907A", "Q$T5"], 
                                        Selector -> Selector[ 
                                        "BJT", "Q2N2907A", "Q$T5"], 
                                        Parameters -> Parameters[ 
                                        "BJT", "Q2N2907A", "Q$T5"]}], 
                                        
                                        SequenceForm[ {"Q$T2", {"4" -> "C", 
                                        "VOUT" -> "B", "2" -> "E"}, Model -> 
                                        Model[ "BJT", "Q2N2222A", "Q$T2"], 
                                        Selector -> Selector[ 
                                        "BJT", "Q2N2222A", "Q$T2"], 
                                        Parameters -> Parameters[ 
                                        "BJT", "Q2N2222A", "Q$T2"]}]}]]}
                                        },
                                      RowSpacings->1,
                                      ColumnSpacings->0,
                                      RowAlignments->Baseline,
                                      ColumnAlignments->{Left}],
                                    (
                                    TableForm[ #, TableSpacing -> {1, 0}]&)]}
                                },
                              GridBaseline->{Baseline, {1, 1}},
                              ColumnAlignments->{Left}]},
                          {
                            \("GlobalParameters["\[InvisibleSpace]\(Simulator 
                                \[Rule] "PSpice"\)\[InvisibleSpace]"]"\)}
                          },
                        RowSpacings->1,
                        ColumnSpacings->3,
                        RowAlignments->Baseline,
                        ColumnAlignments->{Left}],
                      TableForm[ {
                        SequenceForm[ 
                          DisplayForm[ 
                            
                            Netlist[ {"V$VDD", {"5", "0"}, Type -> 
                              VoltageSource, Value -> {DC -> 5.0, 
                              Transient -> 5.0}, Symbolic -> {DC -> V$VDD, 
                              Transient -> V$VDD}}, {"Q$T1", {"3" -> "C", 
                              "1" -> "B", "2" -> "E"}, Model -> Model[ 
                              "BJT", "Q2N2222A", "Q$T1"], Selector -> 
                              Selector[ "BJT", "Q2N2222A", "Q$T1"], 
                              Parameters -> Parameters[ 
                              "BJT", "Q2N2222A", "Q$T1"]}, {"I$I1", {"2", 
                              "0"}, Type -> CurrentSource, Value -> {
                              DC -> .49999999999999987*^-5, 
                              Transient -> .49999999999999987*^-5}, 
                              Symbolic -> {DC -> I$I1, Transient -> I$I1}}, {
                              "V$VIN", {"1", "0"}, Type -> VoltageSource, 
                              Value -> {DC -> 3.0, AC -> 1.0, Transient -> 
                              3.0}, Symbolic -> V$VIN}, {"I$I2", {"VOUT", 
                              "0"}, Type -> CurrentSource, Value -> {
                              DC -> .99999999999999974*^-5, Transient -> 
                              InterpolatingFunction[
                               {{-.17976931348623157*^309,
                                 .17976931348623157*^309}}, {1, 0, True, 
                                Real, {1}, {
                                0}}, {{-.17976931348623157*^309, -.1*^2, 
                                0.0, .99999999999999995*^-7,
                                 .19999999999999999*^-6, 
                                10.000000200000001, .17976931348623157*^309}},
                                 {{.99999999999999974*^-5},
                                 {.99999999999999974*^-5},
                                 {.99999999999999974*^-5},
                                 {.000020000000000000002},
                                 {.99999999999999974*^-5},
                                 {.99999999999999974*^-5},
                                 {.99999999999999974*^-5}}][ Time]}, 
                              Symbolic -> {DC -> I$I2, Transient -> I$I2}}, {
                              "Q$T3", {"3" -> "C", "4" -> "B", "5" -> "E"}, 
                              Model -> Model[ "BJT", "Q2N2907A", "Q$T3"], 
                              Selector -> Selector[ 
                              "BJT", "Q2N2907A", "Q$T3"], Parameters -> 
                              Parameters[ "BJT", "Q2N2907A", "Q$T3"]}, {
                              "Q$T4", {"4" -> "C", "4" -> "B", "5" -> "E"}, 
                              Model -> Model[ "BJT", "Q2N2907A", "Q$T4"], 
                              Selector -> Selector[ 
                              "BJT", "Q2N2907A", "Q$T4"], Parameters -> 
                              Parameters[ "BJT", "Q2N2907A", "Q$T4"]}, {
                              "Q$T5", {"VOUT" -> "C", "3" -> "B", "5" -> 
                              "E"}, Model -> Model[ 
                              "BJT", "Q2N2907A", "Q$T5"], Selector -> 
                              Selector[ "BJT", "Q2N2907A", "Q$T5"], 
                              Parameters -> Parameters[ 
                              "BJT", "Q2N2907A", "Q$T5"]}, {"Q$T2", {"4" -> 
                              "C", "VOUT" -> "B", "2" -> "E"}, Model -> 
                              Model[ "BJT", "Q2N2222A", "Q$T2"], Selector -> 
                              Selector[ "BJT", "Q2N2222A", "Q$T2"], 
                              Parameters -> Parameters[ 
                              "BJT", "Q2N2222A", "Q$T2"]}]]], 
                        SequenceForm[ 
                          DisplayForm[ 
                            GlobalParameters[ Simulator -> "PSpice"]]]}]]}
                  },
                RowSpacings->1,
                ColumnSpacings->0,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #, TableSpacing -> {1, 0}]&)]}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      ColumnForm[ {"Circuit:", 
        TableForm[ {{"  ", 
          TableForm[ {
            SequenceForm[ 
              DisplayForm[ 
                
                Netlist[ {"V$VDD", {"5", "0"}, Type -> VoltageSource, 
                  Value -> {DC -> 5.0, Transient -> 5.0}, Symbolic -> {DC -> 
                  V$VDD, Transient -> V$VDD}}, {"Q$T1", {"3" -> "C", "1" -> 
                  "B", "2" -> "E"}, Model -> Model[ 
                  "BJT", "Q2N2222A", "Q$T1"], Selector -> Selector[ 
                  "BJT", "Q2N2222A", "Q$T1"], Parameters -> Parameters[ 
                  "BJT", "Q2N2222A", "Q$T1"]}, {"I$I1", {"2", "0"}, Type -> 
                  CurrentSource, Value -> {DC -> .49999999999999987*^-5, 
                  Transient -> .49999999999999987*^-5}, Symbolic -> {DC -> 
                  I$I1, Transient -> I$I1}}, {"V$VIN", {"1", "0"}, Type -> 
                  VoltageSource, Value -> {DC -> 3.0, AC -> 1.0, Transient -> 
                  3.0}, Symbolic -> V$VIN}, {"I$I2", {"VOUT", "0"}, Type -> 
                  CurrentSource, Value -> {DC -> .99999999999999974*^-5, 
                  Transient -> 
                  InterpolatingFunction[ {{-.17976931348623157*^309,
                     .17976931348623157*^309}}, {1, 0, True, Real, {1}, {
                    0}}, {{-.17976931348623157*^309, -.1*^2, 
                    0.0, .99999999999999995*^-7, .19999999999999999*^-6, 
                    10.000000200000001, .17976931348623157*^309}},
                     {{.99999999999999974*^-5}, {.99999999999999974*^-5},
                     {.99999999999999974*^-5}, {.000020000000000000002},
                     {.99999999999999974*^-5}, {.99999999999999974*^-5},
                     {.99999999999999974*^-5}}][ Time]}, Symbolic -> {DC -> 
                  I$I2, Transient -> I$I2}}, {"Q$T3", {"3" -> "C", "4" -> 
                  "B", "5" -> "E"}, Model -> Model[ 
                  "BJT", "Q2N2907A", "Q$T3"], Selector -> Selector[ 
                  "BJT", "Q2N2907A", "Q$T3"], Parameters -> Parameters[ 
                  "BJT", "Q2N2907A", "Q$T3"]}, {"Q$T4", {"4" -> "C", "4" -> 
                  "B", "5" -> "E"}, Model -> Model[ 
                  "BJT", "Q2N2907A", "Q$T4"], Selector -> Selector[ 
                  "BJT", "Q2N2907A", "Q$T4"], Parameters -> Parameters[ 
                  "BJT", "Q2N2907A", "Q$T4"]}, {"Q$T5", {"VOUT" -> "C", 
                  "3" -> "B", "5" -> "E"}, Model -> Model[ 
                  "BJT", "Q2N2907A", "Q$T5"], Selector -> Selector[ 
                  "BJT", "Q2N2907A", "Q$T5"], Parameters -> Parameters[ 
                  "BJT", "Q2N2907A", "Q$T5"]}, {"Q$T2", {"4" -> "C", 
                  "VOUT" -> "B", "2" -> "E"}, Model -> Model[ 
                  "BJT", "Q2N2222A", "Q$T2"], Selector -> Selector[ 
                  "BJT", "Q2N2222A", "Q$T2"], Parameters -> Parameters[ 
                  "BJT", "Q2N2222A", "Q$T2"]}]]], 
            SequenceForm[ 
              DisplayForm[ 
                GlobalParameters[ Simulator -> "PSpice"]]]}]}}, 
          TableSpacing -> {1, 0}]}],
      Editable->False]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Simulation Data Import", "ExampleSection"],

Cell[TextData[{
  "Analog Insydes supports import of simulation data generated by PSpice or \
HSPICE, thus allowing to use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s graphical visualization facilities for postprocessing and displaying \
simulation results. The example below demonstrates the import of the PSpice \
simulation output file ",
  StyleBox["\"Buffer.csd\"", "TI"],
  " using the Analog Insydes function ",
  StyleBox["ReadSimulationData", "MR"],
  ". In addition, an example for further postprocessing of the simulation \
results is shown."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007a0001XA000`40O003
h00Oo`00lP0000000f<H@Q12403o@Q3^@Q0100000003HaQoof<H0?mS6>eS
60524040000000=S67ooHaP0of<HkF<H0D8@0@00000016<HOomS66<Hogoo
f7oo56<H0D8@0@0000001F<HOomS66<H@Q00;f<H00<006<HHaP02f<H00<0
06<HHaP0of<HUV<H00=oof<HHaP00f<H00Eood8@@Q1S67oo00924004HaQo
od8@@Q04HaP1@Q0100000005HaQoof<HHaQ2400_HaP00`00HaQS600;HaP0
0`00HaQS603oHaRFHaP00gooHaQS6004HaP01Goo@Q1246<HOol00T8@00AS
67oo@Q1240=S60524040000000ES67ooHaQS648@02mS6003001S66<H00AS
6003001S66<H00AS6003001S66<H0?mS69IS6003OomS66<H00ES6005Oom2
448@HaQoo`02@Q000f<HOom24003HaP1@Q0100000005HaQoof<HHaQ24003
HaP00`00HaQS6006HaP40003HaP00`00HaQS6004HaP00`00HaQS6004HaP0
1000HaQS66<H10000f<H00D006<HHaP006<H00<000=S6003001S66<H00=S
6003001S6000008000=S6003001S66<H009S60@000AS60<000AS60<000IS
6003001S66<H00MS6003001S66<H0?mS66MS6003OomS66<H00IS6005Oom2
448@HaQoo`02@Q000f<HOomS6002HaP1@Q0100000005HaQoof<HHaQ24003
HaP00`00HaQS6005HaP00`00HaQS6002HaP01000HaQS60001V<H00<006<H
HaP016<H00@006<HHaP000AS6004001S66<H0002HaP20003HaP00`00HaQS
6006HaP20003HaP01000HaQS60000f<H00<006<HHaP00V<H00@006<HHaP0
00=S6004001S66<H0003HaP00`00HaQS6003HaP00`00HaQS6007HaP00`00
HaQS603oHaQWHaP00gooHaQS6007HaP01Goo@Q1246<HOol00T8@16<H0D8@
0@0000001F<HOomS66<H@Q000f<H00<006<HHaP01F<H00<006<HHaP00V<H
00@006<HHaP000IS6003001S66<H00AS6004001S66<H0007HaP01000HaQS
600016<H00<006<HHaP01V<H00<006<HHaP00V<H00@006<HHaP000=S6003
001S66<H00US6003001S66<H00AS6003001S66<H00=S6003001S66<H00MS
6003001S66<H0?mS66MS6003OomS66<H00QS6005Oom2448@HaQoo`02@Q03
HaP1@Q0100000005HaQoof<HHaQ24003HaP00`00HaQS6005HaP00`00HaQS
6002HaP01000HaQS60001V<H00<006<HHaP016<H00<006<HHaP01P000V<H
00@006<HHaP000AS6003001S66<H00IS6003001S66<H009S6004001S66<H
0003HaP60003HaP30004HaP30006HaP00`00HaQS6007HaP00`00HaQS603o
HaQWHaP00gooHaQS6009HaP01Woo@Q1246<HOom240=S60524040000000ES
67ooHaQS648@00=S6003001S66<H00ES6003001S66<H009S6004001S66<H
0006HaP00`00HaQS6004HaP01000HaQS600016<H00@006<HHaP0009S6003
001S66<H009S6003001S66<H00IS6003001S66<H009S6004001S66<H0003
HaP00`00HaQS6002HaP01000HaQS60001V<H00<006<HHaP01f<H00<006<H
HaP01f<H00<006<HHaP0of<HIf<H00=oof<HHaP02V<H00Eood8@@Q1S67oo
00=S60524040000000ES67ooHaQS648@00=S60H0009S6003001S66<H009S
6003001S66<H008000ES60P0009S6003001S66<H009S6004001S66<H0002
HaP20003HaP00`00HaQS6006HaP20003HaP00`00HaQS60020002HaP00`00
HaQS6002HaP01000HaQS60000f<H00@006<HHaP000=S6003001S66<H00=S
60H000AS6003001S66<H0?mS66MS6003OomS66<H00]S6003Oom2448@00AS
60524040000000ES67ooHaQS648@00=S6003001S66<H00IS60@000=S6003
001S600000AS6003001S66<H00AS6004001S66<HHaP40003HaP01@00HaQS
6000HaP00`002F<H00<006<H00000P000f<H00<006<H00000V<H100016<H
0`0016<H0`001V<H00<006<HHaP01f<H00<006<HHaP0of<HIf<H00=oof<H
HaP036<H00=ood8@@Q000f<H0D8@0@0000001F<HOomS66<H@Q000f<H00<0
06<HHaP056<H00<006<HHaP016<H00<006<HHaP026<H00<006<HHaP0<f<H
00<006<HHaP01f<H00<006<HHaP0of<HIf<H00=oof<HHaP03F<H00=ood8@
HaP00V<H0D8@0@0000001F<HOomS66<H@Q000f<H00<006<HHaP056<H00<0
06<HHaP016<H00<006<HHaP026<H00<006<HHaP0<f<H00<006<HHaP01F<H
0`00of<HJF<H00=oof<HHaP03V<H00Eoof<HHaQS648@0040000000ES67oo
HaQS648@00=S60L0011S6003001S66<H00AS6003001S66<H00QS6003001S
66<H03=S60L000=S6003001S66<H0?mS66MS6003OomS66<H019S60524040
000000ES67ooHaQS648@0?mS6=IS6003OomS66<H019S60524040000000ES
67ooHaQS648@0?mS6=IS6003OomS66<H019S60524040000000ES67ooHaQS
648@0?mS6=IS6003OomS66<H019S60524040000000AS67ooHaQS6?m24=M2
4003OomS66<H019S60524040000000=S67ooHaP0of<HkF<H0D8@0@000000
0f<HOomS603oHaS]HaP1@Q0100000004HaQoof<HHaSoOooZOol2HaP1@Q01
00000005HaQoof<HHaQ2403oHaSXHaP017ooHaQS648@0@0000001F<HOomS
66<H@Q00o`00i`0000ES67ooHaQS648@0040000000ES67ooHaQS648@0?l0
0>L00005HaQoof<HHaQ2400100000005HaQoof<HHaQ2403o003W00001F<H
OomS66<H@Q000@0000001F<HOomS66<H@Q00o`00i`0000ES67ooHaQS648@
0040000000ES67ooHaQS648@0?l000l0009F]@H000IF]@<0009F]@04001F
]EJe0002E[D40004E[Fg00001F<HOomS66<H@Q000@0000001F<HOomS66<H
@Q00o`003`000UJe1P001UJe0`000UJe00@005JeE[D0009F]@<000IF]KH0
0005HaQoof<HHaQ2400100000005HaQoof<HHaQ2403o000?0002E[D80002
E[D50002E[D01000E[EF]@000UJe0P000eJe^P0000ES67ooHaQS648@0040
000000ES67ooHaQS648@0?l000l0009F]@P0009F]@D0009F]@04001F]EJe
0002E[D20008E[Fe00001F<HOomS66<H@Q000@0000001F<HOomS66<H@Q00
o`003`000UJe20000UJe1@000UJe00@005JeE[D0009F]@8000QF]KD00005
HaQoof<HHaQ2400100000005HaQoof<HHaQ2403o000?0002E[D80002E[D5
0002E[D01000E[EF]@000UJe0P000UJe10000UJe]@0000ES67ooHaQS648@
0040000000ES67ooHaQS648@0?l000l0009F]@P0009F]@D0009F]@04001F
]EJe0002E[D20003E[D20003E[Fe00001F<HOomS66<H@Q000@0000001F<H
OomS66<H@Q00o`003`000UJe1P0015Je1@0025Je0`001UJe]P0000ES67oo
HaQS648@0040000000ES67ooHaQS648@0?l000l0009F]@H000AF]@D0009F
]@05001F]EJe001F]@050004E[Fg00001F<HOomS66<H@Q000@0000001F<H
OomS66<H@Q00o`003`000UJeeP0000ES67ooHaQS648@0040000000ES67oo
HaQS648@0?l000`000QF]M<00005HaQoof<HHaQ2400100000005HaQoof<H
HaQ2403o000<0008E[D50002E[G<00001F<HOomS66<H@Q000@0000001F<H
OomS66<H@Q00o`006@000UJec00000ES67ooHaQS648@0040000000ES67oo
HaQS648@0?l00>L00005HaQoof<HHaQ2400100000005HaQoof<HHaQ2403o
003W00001F<HOomS66<H@Q000@0000001F<HOomS66<H@Q00o`00i`0000ES
67ooHaQS648@0040000000ES67ooHaQS648@0?l00>L00005HaQoof<HHaQ2
400100000005HaQoof<HHaQ2403o003W00001F<HOomS66<H@Q000@000000
1F<HOomS66<H@Q00OP000UJe;@000UJeo`00>00000ES67ooHaQS648@0040
000000ES67ooHaQS648@07d0009F]Bl0009F]Ol003L00005HaQoof<HHaQ2
400100000005HaQoof<HHaQ2401l0002E[Da0002E[Go000f00001F<HOomS
66<H@Q000@0000001F<HOomS66<H@Q00L`000UJe1`0000=F]@0000002000
0UJe1`0015Je1P0015Je1`000UJe2@0000=F]@000000o`00=00000ES67oo
HaQS648@0040000000ES67ooHaQS648@078000AF]@D0009F]@T000AF]@D0
00IF]@@000IF]@H0009F]@T0009F]Ol003D00005HaQoof<HHaQ240010000
0005HaQoof<HHaQ2401O0005:nX=0002E[D20002E[D40002E[D80002E[D2
0002E[D30003E[D20003E[D20003E[D20003E[D50002E[D90002E[Go000e
00001F<HOomS66<H@Q000@0000001F<HOomS66<H@Q00G`0000D[jP000000
02_Z00`0009F]@@0009F]@<0009F]@L0009F]@@0009F]@80009F]@@0009F
]@80009F]@@0009F]@D0009F]@T0009F]Ol003D00005HaQoof<HHaQ24001
00000005HaQoof<HHaQ2401O00001B_Z00000000:nX030000UJe10000UJe
0`000UJe1`000UJe10000UJe0P000UJe10000UJe0P000UJe10000UJe1@00
0UJe2@000UJeo`00=@0000ES67ooHaQS648@0040000000ES67ooHaQS648@
05l00005:nX00000000[jP0<0002E[D40002E[D30002E[D70002E[D40002
E[D20002E[D40002E[D20002E[D40002E[D50002E[D90002E[Go000e0000
1F<HOomS66<H@Q000@0000001F<HOomS66<H@Q00G`001B_Z30000UJe1000
0UJe0`000UJe1`000UJe10000UJe0P000UJe10000UJe0P000UJe10000UJe
1@000UJe2@000UJeo`00=@0000ES67ooHaQS648@0040000000ES67ooHaQS
648@0700009F]@@0009F]@<0009F]@L0009F]@@0009F]@80009F]@@0009F
]@80009F]@@0009F]@D0009F]@T0009F]Ol003D00005HaQoof<HHaQ24001
00000005HaQoof<HHaQ2401`0002E[D40002E[D30002E[D70002E[D40002
E[D20002E[D40002E[D20002E[D40002E[D50002E[D90002E[Go000e0000
1F<HOomS66<H@Q000@0000001F<HOomS66<H@Q00L0000UJe10000UJe1000
00=F]@0000001@000UJe10000UJe0P000eJe0P000eJe0P000UJe10000UJe
1@000UJe2@0000=F]@000000o`00=00000ES67ooHaQS648@0040000000ES
67ooHaQS648@0700009F]@@0009F]@@0009F]@H0009F]@@0009F]@<000IF
]@<0009F]@@0009F]@8000QF]@D0009F]Ol003H00005HaQoof<HHaQ24001
00000005HaQoof<HHaQ2401`0002E[D40002E[D50002E[D50002E[D40002
E[D40004E[D40002E[D40002E[D20008E[D40002E[Go000g00001F<HOomS
66<H@Q000@0000001F<HOomS66<H@Q00OP000UJe;@000UJeo`00>00000ES
67ooHaQS648@0040000000ES67ooHaQS648@0?l00>L00005HaQoof<HHaQ2
400100000005HaQoof<HHaQ2403o003W00001F<HOomS66<H@Q000@000000
1F<HOomS66<H@Q00o`00i`0000ES67ooHaQS648@0040000000ES67ooHaQS
648@0?l00>L00005HaQoof<HHaQ2400100000005HaQoof<HHaQ2403o003W
00001F<HOomS66<H@Q000@0000001F<HOomS66<H@Q00o`00i`0000ES67oo
HaQS648@0040000000ES67ooHaQS648@0?l00>L00005HaQoof<HHaQ24001
00000005HaQoof<HHaQ2401E0004E[D60004E[F_0004E[D60003E[D00`00
E[EF]@040004E[FB0002E[D70004E[D60003E[D00`00E[EF]@040004E[D9
00001F<HOomS66<H@Q000@0000001F<HOomS66<H@Q00E0001UJe10001UJe
[@001UJe10001eJe0`001UJeT@000UJe1P001UJe10001eJe0`001UJe2000
00ES67ooHaQS648@0040000000ES67ooHaQS648@05<000=F]@8000=F]@80
009F]@@0009F]J/000=F]@8000=F]@8000=F]@8000=F]@80009F]@@0009F
]I00009F]@D000=F]@8000=F]@8000=F]@8000=F]@80009F]@@0009F]@L0
0005HaQoof<HHaQ2400100000005HaQoof<HHaQ2401C0002E[D40002E[D7
0003E[Fa0002E[D20002E[D40002E[D70003E[F@0002E[D50002E[D40002
E[D20002E[D40002E[D70003E[D700001F<HOomS66<H@Q000@0000001F<H
OomS66<H@Q00D`000UJe10000UJe0`001UJe/P000UJe0P000UJe10000UJe
0`001UJeT@000UJe1@000UJe10000UJe0P000UJe10000UJe0`001UJe2000
00ES67ooHaQS648@0040000000ES67ooHaQS648@05<0009F]@04001F]EJe
0002E[D20003E[Fe0003E[D20002E[D40002E[D20003E[FE0002E[D50002
E[D01000E[EF]@000UJe0P000UJe10000UJe0P000eJe300000ES67ooHaQS
648@0040000000ES67ooHaQS648@05<0009F]@04001F]EJe0002E[D20002
E[D40002E[F[0007E[D30002E[D40002E[D20002E[D40002E[F@0002E[D5
0002E[D01000E[EF]@000UJe0P000UJe10000UJe0P000UJe10000UJe1`00
00ES67ooHaQS648@0040000000ES67ooHaQS648@05<0009F]@@0009F]@<0
00IF]J`000IF]@@0009F]@@0009F]@<000IF]I40009F]@D0009F]@@0009F
]@80009F]@@0009F]@<000IF]@P00005HaQoof<HHaQ2400100000005HaQo
of<HHaQ2401C0002E[D40002E[D40004E[F]0002E[D80002E[D40002E[D4
0004E[FB0002E[D50002E[D40002E[D20002E[D40002E[D40004E[D90000
1F<HOomS66<H@Q000@0000001F<HOomS66<H@Q00D`000eJe0P000eJe]@00
0UJeZ00015Je1@000eJe0P000eJe6`0000ES67ooHaQS648@0040000000ES
67ooHaQS648@05@000IF]KH000QF]J8000AF]@H000IF]A`00005HaQoof<H
HaQ2400100000005HaQoof<HHaQ2401E0004E[Fg0008E[FT0002E[D70004
E[DM00001F<HOomS66<H@Q000@0000001F<HOomS66<H@Q00o`00i`0000ES
67ooHaQS648@0040000000ES67ooHaQS648@0?l00>L00005HaQoof<HHaQ2
400100000005HaQoof<HHaQ2403o003W00001F<HOomS66<H@Q000@000000
1F<HOomS66<H@Q00o`00i`0000ES67ooHaQS648@0040000000ES67ooHaQS
648@0?l00>L00005HaQoof<HHaQ2400100000005HaQoof<HHaQ2403o003W
00001F<HOomS66<H@Q000@0000001F<HOomS66<H@Q00o`00i`0000ES67oo
HaQS648@0040000000ES67ooHaQS648@0?l00>L00005HaQoof<HHaQ24001
00000005HaQoof<HHaQ2400Q0008E[D50002E[D70004E[D60004E[D70002
E[D=00000eJe0000002o00000eJe0000002o00000eJe0000000400001F<H
OomS66<H@Q000@0000001F<HOomS66<H@Q008@0025Je1@000UJe1P001UJe
10001UJe1@0015Je300000=F]@000000_`0000=F]@000000_`0000=F]@00
0000100000ES67ooHaQS648@0040000000ES67ooHaQS648@024000=F]A40
00=F]@8000=F]@8000=F]@8000=F]@<0009F]@80009F]@/00003E[D00000
0;l00003E[D000000;l00003E[D0000000@00005HaQoof<HHaQ240010000
0005HaQoof<HHaQ2400R0003E[DF0002E[D20002E[D40002E[D20002E[D4
0002E[D:00000eJe0000002o00000eJe0000002o00000eJe000000040000
1F<HOomS66<H@Q000@0000001F<HOomS66<H@Q008`000eJe5@000UJe0P00
0eJe0P000eJe0P000UJe10000UJe2P0000=F]@000000_`0000=F]@000000
_`0000=F]@000000100000ES67ooHaQS648@0040000000ES67ooHaQS648@
02@000=F]A0000=F]@03001F]EJe008000MF]@<0009F]@@0009F]@D000]F
]@@000IF]@@000IF]@@000IF]@@000IF]@@000IF]@@000IF]@@000IF]@@0
00IF]@@000IF]@@000IF]@@000IF]@@000IF]@@000IF]@@000IF]@@000IF
]@@000IF]@@000IF]@@000IF]@@000IF]@@000IF]@@000IF]@@000IF]@@0
00IF]@@000IF]@@000IF]@@000IF]@@000IF]@@000IF]@@000IF]@@000IF
]@@000IF]@@000IF]@@000IF]@@000IF]@@000IF]@@000IF]@@000IF]@@0
00UF]@H00005HaQoof<HHaQ2400100000005HaQoof<HHaQ2400U0003E[D>
0007E[D20002E[D01000E[EF]EJe10000UJe10000UJe2P0000=F]@000000
o`00PP0000=F]@000000100000ES67ooHaQS648@0040000000ES67ooHaQS
648@02H000=F]@`000=F]@8000=F]@80009F]@P0009F]@@0009F]@X00003
E[D000000?l008800003E[D0000000@00005HaQoof<HHaQ2400100000005
HaQoof<HHaQ2400W0002E[D<0002E[D40002E[D20002E[D80002E[D40002
E[D:00000eJe0000003o002200000eJe0000000400001F<HOomS66<H@Q00
0@0000001F<HOomS66<H@Q008@000eJe0P000eJe30000eJe0P000eJe0P00
0eJe0P000eJe0P000UJe10000UJe2P0000=F]@000000o`00PP0000=F]@00
0000100000ES67ooHaQS648@0040000000ES67ooHaQS648@028000IF]@h0
00IF]@@000IF]@<0009F]@@0009F]@X00003E[D000000?l008800003E[D0
000000@00005HaQoof<HHaQ2400100000005HaQoof<HHaQ2400S0004E[D@
0004E[D60004E[D40002E[D40002E[Go002F00001F<HOomS66<H@Q000@00
00001F<HOomS66<H@Q00o`00i`0000ES67ooHaQS648@0040000000ES67oo
HaQS648@0?l00>L00005HaQoof<HHaQ2400100000005HaQoof<HHaQ2403o
003W00001F<HOomS66<H@Q000@0000001F<HOomS66<H@Q00F`0000=F]@00
0000o`00PP0000=F]@000000100000ES67ooHaQS648@0040000000ES67oo
HaQS648@05/00003E[D000000?l008800003E[D0000000@00005HaQoof<H
HaQ2400100000005HaQoof<HHaQ2401K00000eJe0000003o002200000eJe
0000000400001F<HOomS66<H@Q000@0000001F<HOomS66<H@Q00F`0000=F
]@000000o`00PP0000=F]@000000100000ES67ooHaQS648@0040000000ES
67ooHaQS648@05/00003E[D000000?l008800003E[D0000000@00005HaQo
of<HHaQ2400100000005HaQoof<HHaQ2401K00000eJe0000003o00220000
0eJe0000000400001F<HOomS66<H@Q000@0000001F<HOomS66<H@Q00o`00
i`0000ES67ooHaQS648@0040000000ES67ooHaQS648@0?l00>L00005HaQo
of<HHaQ2400100000005HaQoof<HHaQ2403o000N00000eJe000000360000
1F<HOomS66<H@Q000@0000001F<HOomS66<H@Q00o`00i`0000ES67ooHaQS
648@0040000000ES67ooHaQS648@05/00003E[D000000?l008800003E[D0
000000@00005HaQoof<HHaQ2400100000005HaQoof<HHaQ2401K00000eJe
0000003o002200000eJe0000000400001F<HOomS66<H@Q000@0000001F<H
OomS66<H@Q00F`0000=F]@000000o`00PP0000=F]@000000100000ES67oo
HaQS648@0040000000ES67ooHaQS648@05/00003E[D000000?l008800003
E[D0000000@00005HaQoof<HHaQ2400100000005HaQoof<HHaQ2401K0000
0eJe0000003o002200000eJe0000000400001F<HOomS66<H@Q000@000000
1F<HOomS66<H@Q00F`0000=F]@000000o`00PP0000=F]@000000100000ES
67ooHaQS648@0040000000ES67ooHaQS648@0?l00>L00005HaQoof<HHaQ2
400100000005HaQoof<HHaQ2403o003W00001F<HOomS66<H@Q000@000000
1F<HOomS66<H@Q00o`00i`0000ES67ooHaQS648@0040000000ES67ooHaQS
648@0?l00>L00005HaQoof<HHaQ2400100000005HaQoof<HHaQ2401K0000
0eJe0000003o002200000eJe0000000400001F<HOomS66<H@Q000@000000
1F<HOomS66<H@Q00F`0000=F]@000000o`00PP0000=F]@000000100000ES
67ooHaQS648@0040000000ES67ooHaQS648@05/00003E[D000000?l00880
0003E[D0000000@00005HaQoof<HHaQ2400100000005HaQoof<HHaQ2401K
00000eJe0000003o002200000eJe0000000400001F<HOomS66<H@Q000@00
00001F<HOomS66<H@Q00F`0000=F]@000000o`00PP0000=F]@0000001000
00ES67ooHaQS648@0040000000ES67ooHaQS648@05/00003E[D000000?l0
08800003E[D0000000@00005HaQoof<HHaQ2400100000005HaQoof<HHaQ2
403o003W00001F<HOomS66<H@Q000@0000001F<HOomS66<H@Q00o`007P00
00=F]@000000aP0000ES67ooHaQS648@0040000000ES67ooHaQS648@0?l0
0>L00005HaQoof<HHaQ2400100000005HaQoof<HHaQ2403o003W00001F<H
OomS66<H@Q000@0000001F<HOomS66<H@Q00F`0000=F]@000000o`00PP00
00=F]@000000100000ES67ooHaQS648@0040000000ES67ooHaQS648@05/0
0003E[D000000?l008800003E[D0000000@00005HaQoof<HHaQ240010000
0005HaQoof<HHaQ2401K00000eJe0000003o002200000eJe000000040000
1F<HOomS66<H@Q000@0000001F<HOomS66<H@Q00F`0000=F]@000000o`00
PP0000=F]@000000100000ES67ooHaQS648@0040000000ES67ooHaQS648@
05/00003E[D0000000@00003:nX000000?l007/00003E[D0000000@00005
HaQoof<HHaQ2400100000005HaQoof<HHaQ2401K00000eJe000000040000
0b_Z0000003o001k00000eJe0000000400001F<HOomS66<H@Q000@000000
1F<HOomS66<H@Q00HP0000<[jP000000o`00PP0000ES67ooHaQS648@0040
000000ES67ooHaQS648@0640008[j_l008@00005HaQoof<HHaQ240010000
0005HaQoof<HHaQ2401Q00000b_Z000[jP3o002300001F<HOomS66<H@Q00
0@0000001F<HOomS66<H@Q00H@0000<[jP00:nX0o`00P`0000ES67ooHaQS
648@0040000000ES67ooHaQS648@05/00003E[D0000000<00003:nX002_Z
0?l007`00003E[D0000000@00005HaQoof<HHaQ2400100000005HaQoof<H
HaQ2401K00000eJe0000000300000b_Z000[jP3o001l00000eJe00000004
00001F<HOomS66<H@Q000@0000001F<HOomS66<H@Q00F`0000=F]@000000
0`0000<[jP00:nX0o`00O00000=F]@000000100000ES67ooHaQS648@0040
000000ES67ooHaQS648@05/00003E[D0000000800004:nX00000:n[o001l
00000eJe0000000400001F<HOomS66<H@Q000@0000001F<HOomS66<H@Q00
F`0000=F]@0000000P0000@[jP00000[j_l007`00003E[D0000000@00005
HaQoof<HHaQ2400100000005HaQoof<HHaQ2401K00000eJe000000020000
12_Z000002_Z^@0000=F]@000000_`0000=F]@000000100000ES67ooHaQS
648@0040000000ES67ooHaQS648@06000004:nX00000:n[o002300001F<H
OomS66<H@Q000@0000001F<HOomS66<H@Q00H00000@[jP00000[j_l008<0
0005HaQoof<HHaQ2400100000005HaQoof<HHaQ2401P000012_Z000002_Z
o`00P`0000ES67ooHaQS648@0040000000ES67ooHaQS648@06000004:nX0
0000:n[o002300001F<HOomS66<H@Q000@0000001F<HOomS66<H@Q00F`00
00=F]@0000000P0000@[jP00000[j_l007`00003E[D0000000@00005HaQo
of<HHaQ2400100000005HaQoof<HHaQ2401K00000eJe00000002000012_Z
000002_Zo`00O00000=F]@000000100000ES67ooHaQS648@0040000000ES
67ooHaQS648@05/00005E[D00000000[jP0300000b_Z0000003o001j0000
0eJe0000000400001F<HOomS66<H@Q000@0000001F<HOomS66<H@Q00F`00
00EF]@00000002_Z00@00003:nX000000?l007T00003E[D0000000@00005
HaQoof<HHaQ2400100000005HaQoof<HHaQ2401K00001EJe00000000:nX0
100000<[jP000000o`00N@0000=F]@000000100000ES67ooHaQS648@0040
000000ES67ooHaQS648@05/00005E[D00000000[jP0400000b_Z0000003o
001i00000eJe0000000400001F<HOomS66<H@Q000@0000001F<HOomS66<H
@Q00G`0000<[jP0000000P0000<[jP000000o`00P00000ES67ooHaQS648@
0040000000ES67ooHaQS648@05l00003:nX0000000800003:nX000000?l0
08000005HaQoof<HHaQ2400100000005HaQoof<HHaQ2400Q0008E[D50002
E[D70004E[D60004E[D70002E[DA00000b_Z0000000200000b_Z0000003o
002000001F<HOomS66<H@Q000@0000001F<HOomS66<H@Q008@0025Je1@00
0UJe1P001UJe10001UJe1@0015Je400000<[jP0000000P0000<[jP000000
o`00P00000ES67ooHaQS648@0040000000ES67ooHaQS648@024000=F]A40
00=F]@8000=F]@8000=F]@8000=F]@<0009F]@80009F]@/00005E[D00000
000[jP0500000b_Z0000003o001h00000eJe0000000400001F<HOomS66<H
@Q000@0000001F<HOomS66<H@Q008P000eJe5P000UJe0P000UJe10000UJe
0P000UJe10000UJe2P0000EF]@00000002_Z00D00003:nX000000?l007P0
0003E[D0000000@00005HaQoof<HHaQ2400100000005HaQoof<HHaQ2400S
0003E[DE0002E[D20003E[D20003E[D20002E[D40002E[D:00001EJe0000
0000:nX01@0000<[jP000000o`00N00000=F]@000000100000ES67ooHaQS
648@0040000000ES67ooHaQS648@02@000=F]A0000=F]@03001F]EJe00<0
00IF]@<0009F]@@0009F]@D000IF]@<00003:nX0000000<00003:nX00000
01X00003E[D0000002@00003E[D0000002<00003E[D0000002@00003E[D0
000002@00003E[D0000002@00003E[D0000002@00003E[D0000002<00003
E[D0000002@00003E[D0000002@00003E[D0000000@00005HaQoof<HHaQ2
400100000005HaQoof<HHaQ2400U0003E[D>0007E[D40004E[D40002E[D4
0002E[D:00001EJe00000000:nX01@0000<[jP000000o`00N00000=F]@00
0000100000ES67ooHaQS648@0040000000ES67ooHaQS648@02H000=F]@`0
00=F]@8000=F]@<0009F]@80009F]@<0009F]@@0009F]@X00005E[D00000
000[jP0500000b_Z0000003o001h00000eJe0000000400001F<HOomS66<H
@Q000@0000001F<HOomS66<H@Q009`000UJe30000UJe10000UJe0P000UJe
10000UJe0P000UJe10000UJe3P0000<[jP0000000`0000<[jP000000o`00
O`0000ES67ooHaQS648@0040000000ES67ooHaQS648@024000=F]@8000=F
]@`000=F]@8000=F]@8000=F]@8000=F]@80009F]@@0009F]@h00003:nX0
000000@00003:nX000000?l007h00005HaQoof<HHaQ2400100000005HaQo
of<HHaQ2400R0006E[D>0006E[D40006E[D30002E[D40002E[D>00000b_Z
0000000400000b_Z0000003o001n00001F<HOomS66<H@Q000@0000001F<H
OomS66<H@Q008`0015Je400015Je1P0015Je10000UJe10000UJe3P0000<[
jP000000100000<[jP000000o`00OP0000ES67ooHaQS648@0040000000ES
67ooHaQS648@05/00005E[D00000000[jP0600000b_Z0000003o001g0000
0eJe0000000400001F<HOomS66<H@Q000@0000001F<HOomS66<H@Q00F`00
00EF]@00000002_Z00H00003:nX000000?l007L00003E[D0000000@00005
HaQoof<HHaQ2400100000005HaQoof<HHaQ2401K00001EJe00000000:nX0
1P0000<[jP000000o`00M`0000=F]@000000100000ES67ooHaQS648@0040
000000ES67ooHaQS648@05/00005E[D00000000[jP0600000b_Z0000003o
001g00000eJe0000000400001F<HOomS66<H@Q000@0000001F<HOomS66<H
@Q00F`0000EF]@00000002_Z00H00003:nX000000?l007L00003E[D00000
00@00005HaQoof<HHaQ2400100000005HaQoof<HHaQ2401K00001EJe0000
0000:nX01`0000<[jP000000o`00MP0000=F]@000000100000ES67ooHaQS
648@0040000000ES67ooHaQS648@05l00003:nX0000000D00003:nX00000
0?l007d00005HaQoof<HHaQ2400100000005HaQoof<HHaQ2401O00000b_Z
0000000500000b_Z0000003o001m00001F<HOomS66<H@Q000@0000001F<H
OomS66<H@Q00G`0000<[jP0000001@0000<[jP000000o`00O@0000ES67oo
HaQS648@0040000000ES67ooHaQS648@05l00003:nX0000000D00003:nX0
00000?l007d00005HaQoof<HHaQ2400100000005HaQoof<HHaQ2401K0000
1EJe00000000:nX01`0000<[jP000000o`00MP0000=F]@000000100000ES
67ooHaQS648@0040000000ES67ooHaQS648@05/00005E[D00000000[jP07
00000b_Z0000000n0003:nYb00000eJe0000002o00000eJe000000040000
1F<HOomS66<H@Q000@0000001F<HOomS66<H@Q00F`0000EF]@00000002_Z
00L00003:nX0000003d00004:nX00000:n[o000e00000eJe000000040000
1F<HOomS66<H@Q000@0000001F<HOomS66<H@Q00F`0000AF]@00000[jPP0
0003:nX0000003d00005:nX00000000[jP3o000d00000eJe000000040000
1F<HOomS66<H@Q000@0000001F<HOomS66<H@Q00F`0000AF]@00000[jPP0
0003:nX0000003`00003:nX0000000800003:nX000000?l003800003E[D0
000000@00005HaQoof<HHaQ2400100000005HaQoof<HHaQ2401K000015Je
000002_Z2@0000<[jP000000>`0000<[jP0000000`000R_Zo`00<P0000=F
]@000000100000ES67ooHaQS648@0040000000ES67ooHaQS648@05h00003
:nX0000000L00003:nX0000003X00003:nX0000000D00003:nX000000?l0
03L00005HaQoof<HHaQ2400100000005HaQoof<HHaQ2401N00000b_Z0000
000700000b_Z0000000j00000b_Z0000000600000b_Z0000003o000f0000
1F<HOomS66<H@Q000@0000001F<HOomS66<H@Q00GP0000<[jP0000001`00
00<[jP000000>@0000<[jP0000001`0000<[jP000000o`00=P0000ES67oo
HaQS648@0040000000ES67ooHaQS648@05h00003:nX0000000L00003:nX0
000003T00003:nX0000000P00003:nX000000?l003D00005HaQoof<HHaQ2
400100000005HaQoof<HHaQ2401K000015Je000002_Z2@0000<[jP000000
>00000<[jP0000002P0000<[jP000000o`00;@0000=F]@000000100000ES
67ooHaQS648@0040000000ES67ooHaQS648@05/00004E[D00000:nX90000
0b_Z0000000h00000b_Z0000000:00000b_Z0000003o000]00000eJe0000
000400001F<HOomS66<H@Q000@0000001F<HOomS66<H@Q00F`0000AF]@00
000[jPT00003:nX0000003L00003:nX0000000`00003:nX000000?l002`0
0003E[D0000000@00005HaQoof<HHaQ2400100000005HaQoof<HHaQ2401K
000015Je000002_Z2@0000<[jP000000=P0000<[jP0000003@0000<[jP00
0000o`00;00000=F]@000000100000ES67ooHaQS648@0040000000ES67oo
HaQS648@05/00004E[D00000:nX:00000b_Z0000000e00000b_Z0000000>
00000b_Z0000003o000[00000eJe0000000400001F<HOomS66<H@Q000@00
00001F<HOomS66<H@Q00F`0000AF]@00000[jPX00003:nX0000003@00003
:nX0000000l00003:nX000000?l002/00003E[D0000000@00005HaQoof<H
HaQ2400100000005HaQoof<HHaQ2401N00000b_Z0000000800000b_Z0000
000d00000b_Z0000000@00000b_Z0000003o000a00001F<HOomS66<H@Q00
0@0000001F<HOomS66<H@Q00GP0000<[jP000000200000<[jP000000=000
00<[jP000000400000<[jP000000o`00<@0000ES67ooHaQS648@00400000
00ES67ooHaQS648@05h00003:nX0000000P00003:nX0000003<00003:nX0
000001800003:nX000000?l003000005HaQoof<HHaQ2400100000005HaQo
of<HHaQ2401N00000b_Z0000000800000b_Z0000000c00000b_Z0000000B
00000b_Z0000003o000`00001F<HOomS66<H@Q000@0000001F<HOomS66<H
@Q00F`0000AF]@00000[jPX00003:nX0000003<00003:nX0000001800003
:nX0000006H00003E[D000000;l00003E[D0000000@00005HaQoof<HHaQ2
400100000005HaQoof<HHaQ2401K00000eJe000[jP0;00000b_Z0000000c
00000b_Z0000000B00000b_Z0000003o000Y00000eJe0000000400001F<H
OomS66<H@Q000@0000001F<HOomS66<H@Q00F`0000=F]@00:nX02`0000<[
jP000000<P0000<[jP000000500000<[jP000000o`00:00000=F]@000000
100000ES67ooHaQS648@0040000000ES67ooHaQS648@05/00003E[D002_Z
00`00003:nX0000003400003:nX0000001@00003:nX000000?l002P00003
E[D0000000@00005HaQoof<HHaQ2400100000005HaQoof<HHaQ2401K0000
0eJe000[jP0<00000b_Z0000000a00000b_Z0000000D00000b_Z0000003o
000X00000eJe0000000400001F<HOomS66<H@Q000@0000001F<HOomS66<H
@Q00F`0000=F]@00:nX0300000<[jP000000<00000<[jP0000005P0000<[
jP000000o`009`0000=F]@000000100000ES67ooHaQS648@0040000000ES
67ooHaQS648@05d00003:nX0000000X00003:nX0000003000003:nX00000
01H00003:nX000000?l002h00005HaQoof<HHaQ2400100000005HaQoof<H
HaQ2401M00000b_Z0000000:00000b_Z0000000`00000b_Z0000000G0000
0b_Z000000110007:n[T00001F<HOomS66<H@Q000@0000001F<HOomS66<H
@Q00G@0000<[jP0000002P0000<[jP000000<00000<[jP0000005`0000<[
jP000000@00000<[jP0000001@0000<[jP000000h@0000ES67ooHaQS648@
0040000000ES67ooHaQS648@05d00003:nX0000000X00003:nX0000002l0
0003:nX0000001T00003:nX0000003l00003:nX0000000D00003:nX00000
0>400005HaQoof<HHaQ2400100000005HaQoof<HHaQ2401K00000eJe000[
jP0<00000b_Z0000000_00000b_Z0000000I00000b_Z0000000l0003:nX9
0005:n[G00000eJe0000000400001F<HOomS66<H@Q000@0000001F<HOomS
66<H@Q00F`0000=F]@00:nX0300000<[jP000000;`0000<[jP0000006@00
00<[jP000000>`0000<[jP0000003P0000<[jP000000e@0000=F]@000000
100000ES67ooHaQS648@0040000000ES67ooHaQS648@05/00003E[D002_Z
00`00003:nX0000002h00003:nX0000001X00003:nX0000003/00003:nX0
000000l00003:nX000000=@00003E[D0000000@00005HaQoof<HHaQ24001
00000005HaQoof<HHaQ2401K00000eJe000[jP0<00000b_Z0000000^0000
0b_Z0000000K00000b_Z0000000i00000b_Z0000000@00000b_Z0000003D
00000eJe0000000400001F<HOomS66<H@Q000@0000001F<HOomS66<H@Q00
F`0000=F]@00:nX0300000<[jP000000;P0000<[jP0000006`0000<[jP00
0000>@0000<[jP0000004@0000<[jP000000d`0000=F]@000000100000ES
67ooHaQS648@0040000000ES67ooHaQS648@05/00003E[D002_Z00d00003
:nX0000002d00003:nX0000001/00003:nX0000003P00003:nX000000180
0003:nX000000=<00003E[D0000000@00005HaQoof<HHaQ2400100000005
HaQoof<HHaQ2401M00000b_Z0000000;00000b_Z0000000/00000b_Z0000
000M00000b_Z0000000g00000b_Z0000000C00000b_Z0000003I00001F<H
OomS66<H@Q000@0000001F<HOomS66<H@Q00G@0000<[jP0000002`0000<[
jP000000;00000<[jP0000007@0000<[jP000000=P0000<[jP0000005000
00<[jP000000f@0000ES67ooHaQS648@0040000000ES67ooHaQS648@05d0
0003:nX0000000/00003:nX0000002`00003:nX0000001h00003:nX00000
03D00003:nX0000001D00003:nX0000000l00003E[D000000<H00005HaQo
of<HHaQ2400100000005HaQoof<HHaQ2401M00000b_Z0000000;00000b_Z
0000000/00000b_Z0000000N00000b_Z0000000d00000b_Z0000000G0000
0b_Z0000003G00001F<HOomS66<H@Q000@0000001F<HOomS66<H@Q00F`00
00=F]B_Z00003@0000<[jP000000:`0000<[jP000000800000<[jP000000
<`0000<[jP0000005`0000<[jP000000d00000=F]@000000100000ES67oo
HaQS648@0040000000ES67ooHaQS648@05/00003E[D[jP0000d00003:nX0
000002/00003:nX0000002000003:nX0000003800003:nX0000001T00003
:nX0000003d0010[jX800003E[D0000000@00005HaQoof<HHaQ240010000
0005HaQoof<HHaQ2401K00000eJe:nX0000=00000b_Z0000000[00000b_Z
0000000P00000b_Z0000000a00000b_Z0000000J00000b_Z0000000l0000
0b_Z0000000=00000b_Z0000002000000eJe0000000400001F<HOomS66<H
@Q000@0000001F<HOomS66<H@Q00F`0000=F]B_Z00003@0000<[jP000000
:`0000<[jP000000800000<[jP000000<@0000<[jP0000006P0000<[jP00
0000?00000<[jP0000003P0000<[jP000000O`0000=F]@000000100000ES
67ooHaQS648@0040000000ES67ooHaQS648@05/00003E[D[jP0000d00003
:nX0000002X00003:nX0000002800003:nX0000002l00003:nX0000001`0
0003:nX0000003X00003:nX0000000l00003:nX0000007l00003E[D00000
00@00005HaQoof<HHaQ2400100000005HaQoof<HHaQ2401K00000eJe:nX0
000>00000b_Z0000000Y00000b_Z0000000R00000b_Z0000000_00000b_Z
0000000L0003:nXf0005:nXB0003:nYn00000eJe0000000400001F<HOomS
66<H@Q000@0000001F<HOomS66<H@Q00G00000<[jP0000003@0000<[jP00
0000:@0000<[jP0000008P0000<[jP000000;P0000<[jP0000007`0000<[
jP000000<`0000<[jP0000005`0000<[jP000000P`0000ES67ooHaQS648@
0040000000ES67ooHaQS648@05`00003:nX0000000d00003:nX0000002P0
0003:nX0000002@00003:nX0000002d00003:nX0000002000003:nX00000
03800003:nX0000001P00003:nX0000008800005HaQoof<HHaQ240010000
0005HaQoof<HHaQ2401L00000b_Z0000000=00000b_Z0000000X00000b_Z
0000000T00000b_Z0000000/00000b_Z0000000Q00000b_Z0000000a0000
0b_Z0000000I00000b_Z0000002200001F<HOomS66<H@Q000@0000001F<H
OomS66<H@Q00G00000<[jP0000003@0000<[jP000000:00000<[jP000000
900000<[jP000000;00000<[jP0000008P0000<[jP000000<00000<[jP00
00006P000b_Z=`006R_Z<00000ES67ooHaQS648@0040000000ES67ooHaQS
648@05/00003E[D[jP0000h00003:nX0000002P00003:nX0000002@00003
:nX0000002`00003:nX0000002<00003:nX0000002h00003:nX0000001h0
0003:nX0000003<00003:nX0000001P00003:nX0000002H00003E[D00000
00@00005HaQoof<HHaQ2400100000005HaQoof<HHaQ2400S0004E[D70002
E[D70004E[D60004E[D70002E[D=00000eJe:nX0000>00000b_Z0000000W
00000b_Z0000000V00000b_Z0000000Z00000b_Z0000000T00000b_Z0000
000^00000b_Z0000000N00000b_Z0000000c00000b_Z0000000H00000b_Z
0000000V00000eJe0000000400001F<HOomS66<H@Q000@0000001F<HOomS
66<H@Q008P001UJe1P000UJe1P001UJe10001UJe1@0015Je300000=F]B_Z
00003P0000<[jP0000009`0000<[jP0000009P0000<[jP000000:P0000<[
jP0000009@0000<[jP000000:P000b_Z8P000b_Z;@001B_Z70001B_Z8`00
00=F]@000000100000ES67ooHaQS648@0040000000ES67ooHaQS648@0240
00=F]@8000=F]@`000=F]@8000=F]@8000=F]@8000=F]@<0009F]@80009F
]@/00003E[D[jP0000l00003:nX0000002H00003:nX0000002H00003:nX0
000002X00003:nX0000002D00003:nX0000002T00003:nX0000002D00003
:nX0000002X00003:nX0000002<00003:nX0000002400003E[D0000000@0
0005HaQoof<HHaQ2400100000005HaQoof<HHaQ2400W0002E[D<0002E[D4
0002E[D20002E[D40002E[D20002E[D40002E[D:00000b_Z0000000?0000
0b_Z0000000V00000b_Z0000000W00000b_Z0000000X00000b_Z0000000W
00000b_Z0000000X00000b_Z0000000V00000b_Z0000000Y00000b_Z0000
000T00000b_Z0000000P00000eJe0000000400001F<HOomS66<H@Q000@00
00001F<HOomS66<H@Q009P000eJe30000UJe10000UJe0P000UJe10000UJe
0P000UJe10000UJe2P0000<[jP0000003`0000<[jP0000009@0000<[jP00
0000:00000<[jP000000:00000<[jP0000009`0000<[jP0000009`0000<[
jP0000009`0000<[jP000000:00000<[jP0000009@0000<[jP0000008000
00=F]@000000100000ES67ooHaQS648@0040000000ES67ooHaQS648@02@0
00AF]@d0009F]@04001F]EJe0002E[D20002E[D01000E[EF]@000UJe0P00
0UJe10000UJe1@001EJe00<[jP0000003`0000<[jP0000004P0000=F]@00
0000400000<[jP0000004@0000=F]@0000005@0000<[jP0000002`0000=F
]@0000006@0000<[jP000000200000=F]@0000007@0000<[jP0000001000
00=F]@0000007`0000<[jP0000000P0000=F]@0000008`000b_Z8`001B_Z
8`0000=F]@0000000P001b_Z8P0000ES67ooHaQS648@0040000000ES67oo
HaQS648@02@000=F]@h0009F]@04001F]EJe0002E[D20002E[D01000E[EF
]@000UJe0P000UJe10000UJe700000<[jP0000009@0000<[jP000000:@00
00<[jP0000009`0000<[jP000000:00000<[jP0000009@0000<[jP000000
:`0000<[jP0000008@0000<[jP000000<00000<[jP000000800000ES67oo
HaQS648@0040000000ES67ooHaQS648@02H0009F]@d0009F]@@0009F]@80
009F]@@0009F]@80009F]@@0009F]A`00003:nX0000002D00003:nX00000
02X00003:nX0000002D00003:nX0000002X00003:nX0000002@00003:nX0
000002`00003:nX0000001l00003:nX0000003800003:nX0000001l00005
HaQoof<HHaQ2400100000005HaQoof<HHaQ2400W0002E[D<0002E[D40002
E[D20002E[D40002E[D20002E[D40002E[DM00000b_Z0000000T00000b_Z
0000000Z00000b_Z0000000U00000b_Z0000000Z00000b_Z0000000S0000
0b_Z0000000]00000b_Z0000000O00000b_Z0000000b00000b_Z0000000O
00001F<HOomS66<H@Q000@0000001F<HOomS66<H@Q008@000eJe0P000eJe
30000eJe0P000eJe0P000eJe0P000eJe0P000UJe10000UJe2P0000=F]@00
0000400000<[jP000000900000<[jP000000:P0000<[jP0000009@0000<[
jP000000:`0000<[jP00000080000b_Z<00012_Z6`000b_Z=@006b_Z1P00
00ES67ooHaQS648@0040000000ES67ooHaQS648@028000IF]@h000IF]@@0
00IF]@<0009F]@@0009F]@X00003E[D0000001000003:nX0000002<00003
:nX0000002/00003:nX0000002@00003:nX0000002d00003:nX0000001h0
0003:nX0000003D00003:nX0000001L00003:nX0000005000003E[D00000
00@00005HaQoof<HHaQ2400100000005HaQoof<HHaQ2400S0004E[D@0004
E[D60004E[D40002E[D40002E[D:00000eJe0000000@00000b_Z0000000S
00000b_Z0000000/00000b_Z0000000S00000b_Z0000000]00000b_Z0000
000N00000b_Z0000000e00000b_Z0000000G00000b_Z0000001@00000eJe
0000000400001F<HOomS66<H@Q000@0000001F<HOomS66<H@Q00F`0000=F
]@000000400000<[jP0000008`0000<[jP000000;00000<[jP0000008P00
00<[jP000000;`0000<[jP000000700000<[jP000000=`001B_Z3@001b_Z
D`0000=F]@000000100000ES67ooHaQS648@0040000000ES67ooHaQS648@
05/00003E[D0000001000003:nX0000002<00003:nX0000002`00003:nX0
000002400003:nX0000003000003:nX0000001/00003:nX0000003`00003
:nX0000000X00003:nX0000005P00003E[D0000000@00005HaQoof<HHaQ2
400100000005HaQoof<HHaQ2401K00000eJe0000000A00000b_Z0000000Q
00000b_Z0000000^00000b_Z0000000P00000b_Z0000000a00000b_Z0000
000J00000b_Z0000000m00000b_Z0000000900000b_Z0000001H00000eJe
0000000400001F<HOomS66<H@Q000@0000001F<HOomS66<H@Q00K`0000<[
jP0000008@0000<[jP000000;P0000<[jP0000007`0000<[jP000000<P00
00<[jP0000006@0000<[jP000000?P0000<[jP000000200000<[jP000000
H00000ES67ooHaQS648@0040000000ES67ooHaQS648@06l00003:nX00000
02400003:nX0000002l00003:nX0000001h00003:nX0000003<000<[jQH0
00<[jT4000/[jV800005HaQoof<HHaQ2400100000005HaQoof<HHaQ2401_
00000b_Z0000000Q00000b_Z0000000_00000b_Z0000000N00000b_Z0000
000e00000b_Z0000000C00000b_Z0000002_00001F<HOomS66<H@Q000@00
00001F<HOomS66<H@Q00K`0000<[jP000000800000<[jP000000<@0000<[
jP000000700000<[jP000000=`0000<[jP0000004P0000<[jP000000[`00
00ES67ooHaQS648@0040000000ES67ooHaQS648@05/00003E[D000000180
0003:nX0000001l00003:nX0000003400003:nX0000001`00003:nX00000
03L00003:nX0000001400003:nX000000:T00003E[D0000000@00005HaQo
of<HHaQ2400100000005HaQoof<HHaQ2401K00000eJe0000000B00000b_Z
0000000O00000b_Z0000000a00000b_Z0000000L00000b_Z0000000h0003
:nX>0003:nZ[00000eJe0000000400001F<HOomS66<H@Q000@0000001F<H
OomS66<H@Q00F`0000=F]@0000004P0000<[jP0000007`0000<[jP000000
<@0000<[jP000000700000<[jP000000>`0000<[jP0000002P0000<[jP00
0000[00000=F]@000000100000ES67ooHaQS648@0040000000ES67ooHaQS
648@05/00003E[D0000001800003:nX0000001l00003:nX0000003800003
:nX0000001X00003:nX0000003`00003:nX0000000X00003:nX000000:`0
0003E[D0000000@00005HaQoof<HHaQ2400100000005HaQoof<HHaQ2401K
00000eJe0000000B00000b_Z0000000N00000b_Z0000000c00000b_Z0000
000J00000b_Z0000000f00000eJe00000004000<:nZ_00000eJe00000004
00001F<HOomS66<H@Q000@0000001F<HOomS66<H@Q00F`0000=F]@000000
4P0000<[jP0000007P0000<[jP000000<`0000<[jP0000006@0000<[jP00
0000n@0000=F]@000000100000ES67ooHaQS648@0040000000ES67ooHaQS
648@07400003:nX0000001d00003:nX0000003@00003:nX0000001P00003
:nX000000?l000400005HaQoof<HHaQ2400100000005HaQoof<HHaQ2401a
00000b_Z0000000M00000b_Z0000000d00000b_Z0000000G00000b_Z0000
003o000200001F<HOomS66<H@Q000@0000001F<HOomS66<H@Q00L@0000<[
jP0000007@0000<[jP000000=@0000<[jP0000005P0000<[jP000000o`00
0P0000ES67ooHaQS648@0040000000ES67ooHaQS648@07400003:nX00000
01d00003:nX0000003D00003:nX0000001D00003:nX000000?l000<00005
HaQoof<HHaQ2400100000005HaQoof<HHaQ2401K00000eJe0000000C0000
0b_Z0000000L00000b_Z0000000g00000b_Z0000000D00000b_Z0000003k
00000eJe0000000400001F<HOomS66<H@Q000@0000001F<HOomS66<H@Q00
F`0000=F]@000000500000<[jP0000006`0000<[jP000000=`0000<[jP00
00004`0000<[jP000000o00000=F]@000000100000ES67ooHaQS648@0040
000000ES67ooHaQS648@05/00003E[D0000001@00003:nX0000001/00003
:nX0000003P00003:nX0000001800003:nX000000?`00003E[D0000000@0
0005HaQoof<HHaQ2400100000005HaQoof<HHaQ2401K00000eJe0000000D
00000b_Z0000000K00000b_Z0000000h00000b_Z0000000A00000b_Z0000
003m00000eJe0000000400001F<HOomS66<H@Q000@0000001F<HOomS66<H
@Q00F`0000=F]@000000500000<[jP0000006P0000<[jP000000>P0000<[
jP000000400000<[jP000000o@0000=F]@000000100000ES67ooHaQS648@
0040000000ES67ooHaQS648@05/00003E[D0000001@00003:nX0000001X0
0003:nX0000003X00003:nX0000000d000<[j_l000400003E[D0000000@0
0005HaQoof<HHaQ2400100000005HaQoof<HHaQ2401b00000b_Z0000000J
00000b_Z0000000j00000b_Z0000000<00000b_Z0000003o000900001F<H
OomS66<H@Q000@0000001F<HOomS66<H@Q00L`0000<[jP0000006@0000<[
jP000000>`0000<[jP0000002`0000<[jP000000o`002@0000ES67ooHaQS
648@0040000000ES67ooHaQS648@07<00003:nX0000001P00003:nX00000
03`00003:nX0000000X00003:nX000000?l000X00005HaQoof<HHaQ24001
00000005HaQoof<HHaQ2401c00000b_Z0000000H00000b_Z0000000m0003
:nX900000b_Z0000003o000:00001F<HOomS66<H@Q000@0000001F<HOomS
66<H@Q00F`0000=F]@0000005@0000<[jP000000600000<[jP000000@000
00<[jP0000001@0000<[jP000000o`00100000=F]@000000100000ES67oo
HaQS648@0040000000ES67ooHaQS648@05/00003E[D0000001H00003:nX0
000001H00003:nX0000004400003:nX0000000D00003:nX000000?l000@0
0003E[D0000000@00005HaQoof<HHaQ2400100000005HaQoof<HHaQ2401K
00000eJe0000000F00000b_Z0000000F00000b_Z000000120007:n[o0007
00000eJe0000000400001F<HOomS66<H@Q000@0000001F<HOomS66<H@Q00
F`0000=F]@0000005P0000<[jP0000005P0000<[jP000000S@0000=F]@00
0000_`0000=F]@000000100000ES67ooHaQS648@0040000000ES67ooHaQS
648@05/00003E[D0000001H00003:nX0000001H00003:nX000000?l00500
0003E[D0000000@00005HaQoof<HHaQ2400100000005HaQoof<HHaQ2401K
00000eJe0000000G00000b_Z0000000D00000b_Z0000003o001A00000eJe
0000000400001F<HOomS66<H@Q000@0000001F<HOomS66<H@Q00M@0000<[
jP000000500000<[jP000000o`00F00000ES67ooHaQS648@0040000000ES
67ooHaQS648@07D00003:nX0000001@00003:nX000000?l005P00005HaQo
of<HHaQ2400100000005HaQoof<HHaQ2401f00000b_Z0000000C00000b_Z
0000003o001H00001F<HOomS66<H@Q000@0000001F<HOomS66<H@Q00MP00
00<[jP0000004`0000<[jP000000o`00F00000ES67ooHaQS648@00400000
00ES67ooHaQS648@05/00003E[D0000001P00003:nX0000001800003:nX0
00000?l005800003E[D0000000@00005HaQoof<HHaQ2400100000005HaQo
of<HHaQ2401K00000eJe0000000H00000b_Z0000000B00000b_Z0000003o
001B00000eJe0000000400001F<HOomS66<H@Q000@0000001F<HOomS66<H
@Q00F`0000=F]@0000006@0000<[jP0000004@0000<[jP000000o`00DP00
00=F]@000000100000ES67ooHaQS648@0040000000ES67ooHaQS648@05/0
0003E[D0000001T00003:nX0000001400003:nX000000?l005800003E[D0
000000@00005HaQoof<HHaQ2400100000005HaQoof<HHaQ2401K00000eJe
0000000I00000b_Z0000000@00000b_Z0000003o001C00000eJe00000004
00001F<HOomS66<H@Q000@0000001F<HOomS66<H@Q00F`0000=F]@000000
6@0000<[jP000000400000<[jP000000o`00D`0000=F]@000000100000ES
67ooHaQS648@0040000000ES67ooHaQS648@07P00003:nX0000000h00003
:nX000000?l005/00005HaQoof<HHaQ2400100000005HaQoof<HHaQ2401h
00000b_Z0000000>00000b_Z0000003o001K00001F<HOomS66<H@Q000@00
00001F<HOomS66<H@Q00N00000<[jP0000003P0000<[jP000000o`00F`00
00ES67ooHaQS648@0040000000ES67ooHaQS648@07P00003:nX0000000d0
0003:nX000000?l005`00005HaQoof<HHaQ2400100000005HaQoof<HHaQ2
401K00000eJe0000000K00000b_Z0000000<00000b_Z0000003o001E0000
0eJe0000000400001F<HOomS66<H@Q000@0000001F<HOomS66<H@Q00F`00
00=F]@0000006`0000<[jP000000300000<[jP000000TP0000=F]@000000
_`0000=F]@000000100000ES67ooHaQS648@0040000000ES67ooHaQS648@
05/00003E[D0000001`00003:nX0000000/00003:nX000000?l005D00003
E[D0000000@00005HaQoof<HHaQ2400100000005HaQoof<HHaQ2401K0000
0eJe0000000L00000b_Z0000000:00000b_Z0000003o001F00000eJe0000
000400001F<HOomS66<H@Q000@0000001F<HOomS66<H@Q00F`0000=F]@00
00007@0000<[jP0000002@0000<[jP000000o`00EP0000=F]@0000001000
00ES67ooHaQS648@0040000000ES67ooHaQS648@05/00003E[D0000001d0
0003:nX0000000P00003:nX000000?l005L00003E[D0000000@00005HaQo
of<HHaQ2400100000005HaQoof<HHaQ2401l00000b_Z0000000700000b_Z
0000003o001N00001F<HOomS66<H@Q000@0000001F<HOomS66<H@Q00O000
00<[jP0000001P0000<[jP000000o`00G`0000ES67ooHaQS648@00400000
00ES67ooHaQS648@07d00003:nX0000000<000<[j_l006400005HaQoof<H
HaQ2400100000005HaQoof<HHaQ2401m00000b_Z0000000200000b_Z0000
003o001R00001F<HOomS66<H@Q000@0000001F<HOomS66<H@Q00F`0000=F
]@000000800000D[jP00000002_Z0?l005d00003E[D0000000@00005HaQo
of<HHaQ2400100000005HaQoof<HHaQ2401K00000eJe0000000P000012_Z
000002_Zo`00GP0000=F]@000000100000ES67ooHaQS648@0040000000ES
67ooHaQS648@05/00003E[D00000024000<[j_l005h00003E[D0000000@0
0005HaQoof<HHaQ2400100000005HaQoof<HHaQ2401K00000eJe0000003o
002200000eJe0000000400001F<HOomS66<H@Q000@0000001F<HOomS66<H
@Q008`0015Je1`000UJe1`0015Je100025Je1@000UJe3@0000=F]@000000
o`00PP0000=F]@000000100000ES67ooHaQS648@0040000000ES67ooHaQS
648@028000IF]@H0009F]@H000IF]@<000QF]@@000AF]@`00003E[D00000
0?l008800003E[D0000000@00005HaQoof<HHaQ2400100000005HaQoof<H
HaQ2400Q0003E[D20003E[D<0003E[D20003E[D20003E[D80002E[D20002
E[D;00000eJe0000003o002200000eJe0000000400001F<HOomS66<H@Q00
0@0000001F<HOomS66<H@Q009`000UJe30000UJe10000UJe0`000eJe1P00
0UJe10000UJe2P0000=F]@000000o`00PP0000=F]@000000100000ES67oo
HaQS648@0040000000ES67ooHaQS648@02H000=F]@`0009F]@@0009F]@@0
00=F]@D0009F]@@0009F]@X00003E[D000000?l008800003E[D0000000@0
0005HaQoof<HHaQ2400100000005HaQoof<HHaQ2400T0004E[D=0002E[D0
1000E[EF]@000UJe1@000eJe10000UJe10000UJe1@002eJe10001UJe1000
1UJe10001UJe10001UJe10001UJe10001UJe10001UJe10001UJe10001UJe
10001UJe10001UJe10001UJe10001UJe10001UJe10001UJe10001UJe1000
1UJe10001UJe10001UJe10001UJe10001UJe10001UJe10001UJe10001UJe
10001UJe10001UJe10001UJe10001UJe10001UJe10001UJe10001UJe1000
1UJe10001UJe10001UJe10001UJe10001UJe10001UJe10002EJe1P0000ES
67ooHaQS648@0040000000ES67ooHaQS648@02@000=F]@h0009F]@04001F
]EJe0002E[D60003E[D30002E[D40002E[Go002F00001F<HOomS66<H@Q00
0@0000001F<HOomS66<H@Q009P000UJe3@000UJe10000UJe1`000eJe0P00
0UJe10000UJeo`00UP0000ES67ooHaQS648@0040000000ES67ooHaQS648@
02L0009F]@`0009F]@@0009F]@P0009F]@80009F]@@0009F]Ol009H00005
HaQoof<HHaQ2400100000005HaQoof<HHaQ2400Q0003E[D20003E[D<0003
E[D20003E[D20003E[D20003E[D20002E[D40002E[Go002F00001F<HOomS
66<H@Q000@0000001F<HOomS66<H@Q008P001UJe3P001UJe10001UJe0`00
0UJe10000UJeo`00UP0000ES67ooHaQS648@0040000000ES67ooHaQS648@
02<000AF]A0000AF]@H000AF]@@0009F]@@0009F]Ol009H00005HaQoof<H
HaQ2400100000005HaQoof<HHaQ2403o003W00001F<HOomS66<H@Q000@00
00001F<HOomS66<H@Q00o`00i`0000ES67ooHaQS648@0040000000ES67oo
HaQS648@0?l00>L00005HaQoof<HHaQ2400100000005HaQoof<HHaQ2403o
003W00001F<HOomS66<H@Q000@0000001F<HOomS66<H@Q00o`00i`0000ES
67ooHaQS648@0040000000ES67ooHaQS648@0?l00>L00005HaQoof<HHaQ2
400100000005HaQoof<HHaQ2403o003W00001F<HOomS66<H@Q000@000000
1F<HOomS66<H@Q00o`00i`0000ES67ooHaQS648@0040000000ES67ooHaQS
648@0?l00>L00005HaQoof<HHaQ2400100000005HaQoof<HHaQ2403o003W
00001F<HOomS66<H@Q000@0000001F<HOomS66<H@Q00o`00i`0000ES67oo
HaQS648@0040000000ES67ooHaQS648@0?l00>L00005HaQoof<HHaQ24001
00000005HaQoof<HHaQ2403o003W00001F<HOomS66<H@Q000@0000001F<H
OomS66<H@Q00o`00i`0000ES67ooHaQS648@0040000000ES67ooHaQS648@
0?l00>L00005HaQoof<HHaQ2400100000005HaQoof<HHaQ2403o003W0000
1F<HOomS66<H@Q000@0000001F<HOomS66<H@Q00o`00i`0000ES67ooHaQS
648@0040000000ES67ooHaQS648@0?l00>L00005HaQoof<HHaQ240010000
0005HaQoof<HHaQ2403o003W00001F<HOomS66<H@Q000@0000001F<HOomS
66<H@Q00o`00i`0000ES67ooHaQS648@0040000000ES67ooHaQS648@0?l0
0>L00005HaQoof<HHaQ2400100000005HaQoof<HHaQ2403o003W00001F<H
OomS66<H@Q000@00000016<HOomS66<Hod8@jD8@00Aoof<HHaQ240400000
00=S67ooHaP0of<HkF<H0D8@0@0000000f<HOomS603oHaS]HaP1@Q010000
0003HaQoof<H0?mS6>eS60524040000000=S67ooHaP01f<HA@0026<HA@00
26<HG00026<HG00026<HG00026<H7@000V<H0D8@0@0000000f<HOomS6007
HaP00goo@Q12400C@Q000`00Oom2400D@Q000`00Oom2400D@Q000`00HaQS
6006HaP00goo@Q12400C@Q000`00Oom2400D@Q000`00Oom2400D@Q000`00
HaQS6006HaP00goo@Q12400C@Q000`00Oom2400D@Q000`00Oom2400D@Q00
0`00Oom2400D@Q000`00HaQS6006HaP00goo@Q12400C@Q000`00Oom2400D
@Q000`00Oom2400D@Q000`00Oom2400D@Q000`00HaQS6006HaP00goo@Q12
400C@Q000`00Oom2400D@Q000`00Oom2400D@Q000`00Oom2400D@Q000`00
HaQS6006HaP00goo@Q12400C@Q000`00Oom24004@Q02HaP1@Q0100000003
HaQoof<H00MS6003OomS66<H019S6003@Q0007oo01AS6003@Q0007oo01AS
6003@Q0006<H00MS6003OomS66<H019S6003@Q0007oo01AS6003@Q0007oo
01AS6003@Q0006<H00MS6003OomS66<H019S6003@Q0007oo01AS6003@Q00
07oo01AS6003@Q0007oo01AS6003@Q0006<H00MS6003OomS66<H019S6003
@Q0007oo01AS6003@Q0007oo01AS6003@Q0007oo01AS6003@Q0006<H00MS
6003OomS66<H019S6003@Q0007oo01AS6003@Q0007oo01AS6003@Q0007oo
01AS6003@Q0006<H00MS6003OomS66<H019S6003@Q0007oo00MS60524040
000000=S67ooHaP01f<H00=oof<HHaP04V<H00=24000Ool056<H00=24000
Ool056<H00=24000HaP01f<H00=oof<HHaP04V<H00=24000Ool056<H00=2
4000Ool056<H00=24000HaP01f<H00=oof<HHaP04V<H00=24000Ool056<H
00=24000Ool056<H00=24000Ool056<H00=24000HaP01f<H00=oof<HHaP0
4V<H00=24000Ool056<H00=24000Ool056<H00=24000Ool056<H00=24000
HaP01f<H00=oof<HHaP04V<H00=24000Ool056<H00=24000Ool056<H00=2
4000Ool056<H00=24000HaP01f<H00Aoof<HHaQS609oo`ES609oo`ES609o
o`04HaQ24000Ool7HaP1@Q0100000003HaQoof<H00MS6003OomS66<H019S
6003@Q0007oo009S60/000MS6003@Q0007oo01AS6003@Q0006<H00MS6003
OomS66<H00IS609oo`YS6003@Q0007oo01AS6003@Q0007oo00YS60Uoo`03
HaQ2400000QS6003OomS66<H00aS6003001S66<H00=S6003@Q0007oo00iS
6003001S66<H00=S6003@Q0007oo00iS6003001S66<H00=S6003@Q0007oo
00iS6003001S66<H00=S6003@Q0006<H00MS6003OomS66<H019S6003@Q00
07oo009S60al0080009l009S6003@Q0007oo01AS6003@Q0007oo01AS6003
@Q0006<H00MS6005OomS66<HHaP0000=HaP01P00HaQS648@001oo`9S60=l
00AS608000=S6003001S600000=S6003@Q0007oo00QS60@07`QS6003@Q00
07oo00eS608000ES6003@Q0006<H00MS6003OomS66<H0092409oo`=S6092
4003OomS66<H009S6092409S6003@Q0007oo00MS60524040000000=S67oo
HaP01f<H00=oof<HHaP04V<H00=24000Ool00V<H0P002D8000<006<HHaP0
16<H00=24000Ool016<H2`001F<H00=24000HaP01f<H00=oof<HHaP01F<H
0T8@00AS67ooHaQS609oo`ES6003@Q0007oo00YS60Uoo`04HaQ24000Ool5
HaP4Ool9@Q0017ooHaQ2400026<H00=oof<HHaP02f<H00<00480000016<H
00=24000Ool03F<H00<00480000016<H00=24000Ool03F<H00<004800000
16<H00=24000Ool03F<H00<00480000016<H00=24000HaP01f<H00Aoof<H
HaQS60h000=S6003@Q0007oo00ES6003O01S66<H009S6004O01S66<HHaP2
00001f<HO01S66<H@Q0007oo00AS608000QS608000AS6003@Q0007oo00=S
60h000=S6003@Q0006<H00MS6006OomS66<H001S600036<H00H006<HHaQ2
4000Ool3HaP4O003HaP200000f<H001S6002HaP01P00HaQS648@001oo`MS
60<07`03HaP07`0O00MS6003@Q0007oo00IS60Al00=S608000ES6003@Q00
06<H00MS6004OomS66<HHaP2@Q02Ool2HaP2@Q04HaP2@Q03HaP00d8@001o
o`07HaP1@Q0100000003HaQoof<H00MS6004OomS66<HHaP;0006HaP00d8@
001oo`02HaP00`00Ool00009@P000`00HaQS6003HaP00d8@001oo`03HaP0
0`00HaQS6007HaP00`00HaP00004HaP00d8@001S6007HaP00gooHaQS6004
HaP01T8@OomS648@OomS60924003HaQoof<H00=S6003@Q0007oo00US60U2
4005OomS648@001oo`04HaP6@Q000gooHaQoo`04Ool01D8@OomS648@0000
26<H00=oof<HHaP02V<H00D00480HaQoh00000=S6003@Q0007oo00aS6005
001207ooOn000003HaP00d8@001oo`04HaP900001480Oomoh0000f<H00=2
4000Ool036<H00D00480001oh00000=S6003@Q0006<H00MS6005OomS66<H
HaP00003Ool01`00Oomoo`00Ool007oo00<000=S6003@Q0007oo00ES6006
O01S6000001S67`00f<H0P0000MS67`0HaQS648@001oo`05HaP20006HaP2
0005HaP00d8@001oo`03HaP00`00Oomoo`0:Ool01P00HaQS66<H@Q0000QS
6006OomS66<H001S600036<H00H006<HHaQ24000Ool6HaP2O003HaP00`00
HaP00003HaP01P00HaQS648@001oo`IS60<07`=S60807`IS6003@Q0007oo
00ES60Il009S608000ES6003@Q0006<H00MS6003OomS66<H009S60924004
OomS66<HHaP2Ool2HaP2@Q04HaP00d8@001oo`03HaP2Ool2HaP1@Q010000
0003HaQoof<H00MS6004OomS66<HHaP20009@P000`00HaQS6003HaP00d8@
001oo`02HaP01000On1oo`002D8000<006<HHaP00V<H00=24000Ool00V<H
3@0000=S6000HaP00V<H00=24000HaP01f<H00=oof<HHaP016<H00Y247oo
HaQ247oo@Q1oof<H@Q1oo`AS6003@Q0007oo00US6003@Q1oof<H00Eoo`06
@Q1oof<H@Q0007oo0f<H1d8@00=ood8@@Q000d8@00IS648@OomS648@0008
HaP00gooHaQS6009HaP01@00@P1S67oP000016<H00=24000Ool02f<H00D0
0480Oomoh00000AS6003@Q0007oo00AS6003001oogoo00Aoo`05001207oo
On000004HaP00d8@001oo`0;HaP01@00@P1oogoP000016<H00=24000HaP0
1f<H00Eoof<HHaQS600000=oo`07001oogoo001oo`00Ool00`000f<H00=2
4000Ool01F<H00Il06<H000006<HO003HaP20004HaP00d8@001oo`06HaP2
0004HaP20006HaP00d8@001oo`03HaP00`00Oomoo`0:Ool01P00HaQS66<H
@Q0000QS6005OomS66<HHaP0000@HaP00d8@001oo`07HaP2O0000f<H0000
00020003HaP01P00HaQS648@001oo`IS60<07`]S6003@Q0007oo00AS609l
00AS609l00QS6003@Q0006<H00MS6003OomS66<H00=S6004@Q1oogooHaP2
@Q001GooHaQS648@Ool016<H00=24000Ool00V<H0d8@0V<H0D8@0@000000
0f<HOomS6007HaP01gooHaQS66<H001oo`0000U20003001S66<H009S6003
@Q0007oo009S6005001oogoPOol00009@P001`00HaQS66<H@Q0007oo009S
6003001S66<H00AS60=oh09S60<000=S6003@Q0006<H00MS6003OomS66<H
00AS600:@Q1S67oo@Q1ood8@OomS648@Ool4HaP00d8@001oo`04HaP5Ool0
0d8@Oom24004@Q001f<H@Q1oof<H@Q0007oo00=S60M24003OomS67oo009o
o`07HaQood8@OomS648@000026<H00=oof<HHaP016<H0`0000IS6000@P1S
67oP0005HaP00d8@001oo`06HaP300001V<H001207ooOn0000ES6003@Q00
07oo00AS6003001oo`0000800005Ool00480Oomoh0020004HaP00d8@001o
o`06HaP300001V<H001207ooOn0000ES6003@Q0006<H00MS6005OomS66<H
HaP00003Ool01`00Oomoo`00Ool007oo00<000=S6003@Q0007oo00ES6006
O01S6000001S67`00f<H0P0016<H00=24000Ool016<H00<006<HHaP00P00
0V<H0P000V<H00<006<HHaP00V<H00=24000Ool00f<H00<007ooOol02Woo
00H006<HHaQS648@0008HaP017ooHaQS66<H3`000V<H00=24000Ool00V<H
00<006<HHaP00f<H0W`000AS6000HaP000=S6006001S66<H@Q0007oo1V<H
0`0O0V<H0`0O1V<H00=24000Ool00f<H0W`01V<H0W`00P001F<H00=24000
HaP01f<H00=oof<HHaP00f<H0T8@00Ioof<H@Q1247ooHaP2@Q05HaP00d8@
001oo`02HaP3@Q02HaP1@Q0100000003HaQoof<H00MS6008OomS66<HHaP0
07oPOol000U20007001S66<HHaQ24000Ool00V<H00D007oPOomoh7oo00X0
00=S6003@Q0007oo009S6003001S66<H00AS60=2409S6003001S600000=S
6003@Q0006<H00MS6003OomS66<H00ES60=24005Oom247ooOom24005HaP0
0d8@001oo`03HaP7@Q000gooHaQoo`04Ool01T8@OomS648@001oo`=S60M2
4005Oom2448@@Q1S6003@Q0017ooHaQ2400026<H00=oof<HHaP00V<H0P00
0f<H0P0000=S67oP00001V<H00=24000Ool016<H0P000f<H0P0000=oogoP
00001V<H00=24000Ool016<H0P000goo0P0000EoogoP001oo`0000AS6003
@Q0007oo00AS608000=S60800003Oomoh00000IS6003@Q0006<H00MS6005
OomS66<HHaP00003Ool01`00Oomoo`00Ool007oo00<000=S6003@Q0007oo
009S60800003HaQl06<H008000ES608000AS6003@Q0007oo00=S60<0009S
60@0009S60<000=S6003@Q0007oo00=S60h000=S6003@Q0006<H00MS6005
OomS66<HHaP0000@HaP00d8@001oo`02HaP20005HaP027`0HaP00000HaP0
06<H0003HaP00d8@001oo`02HaP3O00016<H01l07`0O0V<H0`0O0`800f<H
00=24000Ool00f<H00=l06<HHaP01V<H00=l000000001F<H00=24000HaP0
1f<H00=oof<HHaP016<H00=247ooOol00T8@0V<H00=247ooHaP016<H00=2
4000Ool01f<H0D8@0@0000000f<HOomS6007HaP02GooHaQS66<H001oogoP
Ool00009@P001P00HaQS648@001oo`9S600;001oogoPOomoh7ooOn1oogoP
Ool00007HaP00d8@001oo`02HaP=0002HaP01@00HaQS648@000026<H00=o
of<HHaP01f<H00=247oo@Q000T8@1V<H00=24000Ool00f<H00=247ooHaP0
0goo00=247oo@Q00148@00MS648@OomS648@001oo`03HaP7@Q000gooHaQS
6002HaP00d8@Oom24002HaP00d8@001S6007HaP01GooHaQS66<H00000f<H
00@07d8@HaQS608000MS6003@Q0007oo00=S6003001S66<H00AS6003Ool0
000000MS6003@Q0007oo00=S6003001oogoo00Eoo`80009oo`03001S66<H
009S6003@Q0007oo00=S60030012448@00E2408000MS6003@Q0006<H00MS
6005OomS66<HHaP00003Ool01`00Oomoo`00Ool007oo00<000=S6003@Q00
07oo009S60800003HaQl06<H00@000=S608000AS6003@Q0007oo009S6005
001oo`00Ool00002HaP20002HaP01@00Ool007oo00000V<H00=24000Ool0
0f<H00<007ooOol02Woo00H006<HHaQS648@0008HaP01GooHaQS66<H0000
46<H00=24000Ool00f<H0P0016<H0W`000=S600000001V<H00=24000Ool0
0V<H0g`00V<H1P0O1@800V<H00=24000Ool00V<H0W`026<H00=l00000000
1F<H00=24000HaP01f<H00=oof<HHaP016<H0T8@00Aoof<HOomoo`9240IS
6003@Q0007oo00MS60524040000000=S67ooHaP01f<H00Uoof<HHaQS6000
On1oogoPOol02P000V<H00=24000Ool00V<H00/007oPOomoh7ooOn1oogoP
Oomoh00000MS6003@Q0007oo009S6003001S66<H00QS6005001S6000HaP0
0002HaP00d8@001S6007HaP00gooHaQS6007HaP3@Q08HaP00d8@001oo`03
HaP00d8@Oom24004@Q001GooHaQoogooHaP00Woo00I247ooHaQ24000Ool3
HaP7@Q05Ool2@Q001GooHaQS648@000026<H00Eoof<HHaQS600000=S6005
01m246<HHaP00008HaP00d8@001oo`03HaP00`00HaQS6004HaP00goo001S
6007HaP00d8@001oo`03HaP00`00Ool07`0401l00goo001oo`02Ool00`00
HaQS6002HaP00d8@001oo`03HaP00`00@Q1oo`04Ool00d8@001S6007HaP0
0d8@001S6007HaP01GooHaQS66<H00000goo00L007ooOol007oo001oo`03
0003HaP00d8@001oo`02HaP200000f<HO01S600400000f<H000000040002
HaP00d8@001oo`02HaP2Ool00`00Oomoo`060002Ool00`00Oomoo`02HaP0
0d8@001oo`03HaP00`00Oomoo`0:Ool01P00HaQS66<H@Q0000QS6006OomS
66<HHaP007`03f<H00=24000Ool016<H0P0000ES6000HaQS67`000US6003
@Q0007oo00=S609l009S6003O0007`0O00807`82009S6082009S6003@Q00
07oo009S60<00005HaP00000001S60030002O0030002HaP00d8@001S6007
HaP00gooHaQS6005HaP01d8@Oom2448@Oom247oo00IS6003@Q0007oo00MS
60524040000000=S67ooHaP01f<H00moof<HHaQS6000Oomoh7ooOn1oogoP
Oomoh7oo00001V<H00=24000Ool00V<H00@007ooOn1oo`L000MS6003@Q00
07oo00=S60X00003HaP006<H0080009S6003@Q0006<H00MS6003OomS66<H
00QS6003@Q1oogoo00MS6003@Q0007oo00=S6003@Q1oof<H00=oo`05@Q1o
od8@@Q1S6004@Q02HaP00d8@001oo`03HaP>@Q001GooHaQS648@000026<H
00Aoof<HHaP0009S60D07`03@Q1S600000MS6003@Q0007oo009S6003001S
66<H00D07`03HaQoo`0000MS6003@Q0007oo009S6004001oogoo01l3Ool0
100OOomoo`000Woo00<006<HHaP00V<H00=24000Ool00V<H00<006<H@Q00
1Goo00=246<H00001f<H00=24000HaP01f<H00Eoof<HHaQS600000=oo`07
001oogoo001oo`00Ool00`000f<H00=24000Ool00V<H0P0000=S67`0HaP0
0P000f<H1P000V<H00=24000Ool00V<H1`000V<H1`000V<H00=24000Ool0
0f<H3P000f<H00=24000HaP01f<H00Eoof<HHaQS6000009l00ES6003O01S
66<H00=S6006O01S66<H@Q0007oo1F<H0`000V<H0W`026<H00=24000Ool0
0f<H1W`000=246<HHaP00P800V<H0P800V<H00=24000Ool00V<H0`0000ES
6000000006<H00P0009S6003@Q0006<H00MS6003OomS66<H00ES60I240MS
6003@Q0007oo00MS60524040000000=S67ooHaP01f<H00moof<HHaQS6000
On1oogoPOomoh7ooOn1oogoP00001V<H00=24000Ool00f<H0`0026<H0`00
0f<H00=24000Ool016<H00<007ooOol01Woo00D006<H001S6000009S6003
@Q0006<H00MS6003OomS66<H00MS60=24003OomS66<H00ES6003@Q0007oo
00=S6003@Q1ood8@00A24007OomS66<HHaQ247oo@Q000f<H00=24000Ool0
0f<H3T8@00Eoof<HHaQ2400000QS6004OomS66<H0002HaP501l00d8@HaP0
0007HaP00d8@001oo`02HaP00`00OomS600501l00f<HOol00007HaP00d8@
001oo`02HaP01000Oomoo`0O0goo00@07gooOol0009oo`03001S66<H009S
6003@Q0007oo009S6003001S648@00Eoo`03@Q1S600000MS6003@Q0006<H
00MS6005OomS66<HHaP00003Ool01`00Oomoo`00Ool007oo00<000=S6003
@Q0007oo009S60@00003HaP0000000]S6003@Q0007oo009S609oo`04001o
ogoo0004HaP01000Oomoo`000Woo0V<H00=24000Ool00f<H00<007ooOol0
2Woo00H006<HHaQS648@0008HaP01WooHaQS66<H001S609l00=S60=l00=S
609l009S6003@Q0007oo00ES60<000=S6003O01S66<H00IS6003@Q0007oo
00=S60Il0003@Q1S66<H0082009S6082009S6003@Q0007oo00eS60800003
O01S66<H009S6003@Q0006<H00MS6004OomS66<HHaP3Ool00f<HOom24003
@Q03Ool026<HOomoogooHaQ24000Ool7HaP1@Q0100000003HaQoof<H00MS
6008OomS66<HHaP007ooOn1oo`L000IS6003@Q0007oo00AS608000US6080
00=S6003@Q0007oo00ES6003001oo`0000@00003Ool00000008000=S6003
@Q0006<H00MS6003OomS66<H00MS6003@Q1ood8@009oo`IS6003@Q0007oo
00=S6003@Q1oof<H009oo`03HaQ247oo00=oo`9240AS6003@Q0007oo00=S
60i24005OomS66<H@Q000008HaP017ooHaQS600016<H00<07d8@HaP00V<H
00<006<HHaP01F<H00=24000Ool00V<H00<007ooHaP01f<H00<006<HHaP0
1F<H00=24000Ool00V<H00@007ooOol07`=oo`0401moogoo0002Ool00`00
HaQS6002HaP00d8@001oo`02HaP00`00HaQ24005Ool00d8@HaP00007HaP0
0d8@001S6007HaP01GooHaQS66<H00000goo00L007ooOol007oo001oo`03
0003HaP00d8@001oo`02HaP400000f<H000000040007HaP00d8@001oo`02
HaP01@00Ool007oo00001V<H00D007oo001oo`00009S6003@Q0007oo00=S
60h000=S6003@Q0006<H00MS6005OomS66<HHaP00002HaP2O00016<HO01l
06<H0W`000=S67`0O0000f<H00=24000Ool016<H10000f<H0W`01f<H00=2
4000Ool00f<H0W`00V<H0W`000=246<HHaP01@800f<H00=24000Ool03F<H
0P000W`00f<H00=24000HaP01f<H00=oof<HHaP00d8@00=ood8@@Q001T8@
00Uood8@@Q1247ooHaQ24000Ool01f<H0D8@0@0000000f<HOomS6007HaP0
0gooHaQS6002HaP30008HaP30002HaP00d8@001oo`02HaP60002HaP01`00
HaQS66<H001S600000=S6003@Q0007oo00ES6003001oogoo00Ioo`03001S
66<H00=S6003@Q0006<H00MS6003OomS66<H00IS60924004HaQ2448@Ool6
HaP00d8@001oo`03HaP01D8@Oom2448@HaP01d8@1F<H00=24000Ool00f<H
148@1Woo148@00Eoof<HHaQ2400000QS6005OomS66<HHaP00003HaP01@0O
@Q1S66<H000026<H00=24000Ool00f<H00<007ooHaP01F<H00<006<HHaP0
1V<H00=24000Ool00f<H00<007oo01l0100O00=oo`0000000`0016<H00=2
4000Ool00f<H00<0048@Ool017oo00=24000HaP01f<H00=24000HaP01f<H
00Eoof<HHaQS600000=oo`07001oogoo001oo`00Ool00`000f<H00=24000
Ool00V<H0P0000=S67`0HaP01P001f<H00=24000Ool00f<H0`0026<H0`00
0f<H00=24000Ool00f<H00<007ooOol02Woo00H006<HHaQS648@0008HaP0
1GooHaQS66<H00000f<H0g`00f<H0g`016<H00=24000Ool036<H0W`01V<H
00=24000Ool00f<H0W`00V<H0W`000=246<HHaP00P800V<H0P800V<H00=2
4000Ool03f<H0W`00f<H00=24000HaP01f<H00=oof<HHaP00d8@00IS648@
@Q1246<HOol3@Q0016<H@Q12448@0V<H00=24000Ool01f<H0D8@0@000000
0f<HOomS6007HaP00gooHaQS600>HaP20002HaP00d8@001oo`02HaP60003
HaP30006HaP00d8@001oo`06HaP00`00Ool0000400000goo001S6004HaP0
0d8@001S6007HaP00gooHaQS6006HaP01T8@OomS66<H@Q1oo`IS6003@Q00
07oo00=S6003@Q1oof<H009S6003@Q1ood8@00US6003@Q0007oo00=S60i2
40=S6003@Q0006<H00MS6005OomS66<HHaP00007HaP00`00HaQS6006HaP0
0d8@001oo`03HaP00`00Oomoo`05HaP00`00HaQS6006HaP00d8@001oo`03
HaP00`00Oomoo`05Ool00`00HaQS6006HaP00d8@001oo`03HaP00`00@Q12
4005@Q000`00HaQS6006HaP00d8@001S6007HaP01GooHaQS66<H00000goo
00L007ooOol007oo001oo`030003HaP00d8@001oo`02HaP2000@HaP00d8@
001oo`04HaP00`00HaQS6008HaP00`00HaQS6002HaP00d8@001oo`03HaP>
0003HaP00d8@001S6007HaP01GooHaQS66<H000016<H00=l06<HHaP00f<H
00=l06<HHaP00f<H00=24000Ool00V<H40000V<H00=24000Ool00f<H1W`0
0V<H0`800V<H0P800V<H00=24000Ool03F<H0P0000=S67`0O0000V<H00=2
4000HaP01f<H00=oof<HHaP01f<H0T8@00=oof<HHaP01V<H00=24000Ool0
16<H00A246<HHaQ24040000000=S67ooHaP01f<H00=oof<HHaP02F<H00L0
06<HHaQS6000HaP00002HaP00d8@001oo`04HaP2000>HaP00d8@001oo`06
HaP00`00Oomoo`06Ool00`00HaQS6002HaP00d8@001S6007HaP00gooHaQS
6006HaP01T8@OomS66<H@Q1oo`IS6003@Q0007oo00=S6003@Q1oogoo009o
o`9240YS6003@Q0007oo00AS60a240AS6003@Q0006<H00MS6003OomS66<H
009S608000=S608000US6003@Q0007oo00AS6080009oo`03HaP0000000US
6003@Q0007oo00AS608000=oo`8000US6003@Q0007oo00AS608000=S6080
00US6003@Q0006<H00MS6004OomS66<HHaP>0003HaP00d8@001oo`02HaP6
000<HaP00d8@001oo`0DHaP00d8@001oo`03HaP>0003HaP00d8@001S6007
HaP01GooHaQS66<H000046<H00=24000Ool03F<H0g`016<H00=24000Ool0
16<H17`00f<H1P800f<H00=24000Ool03F<H0P000V<H00El06<HHaQ24000
00QS6003OomS66<H00MS60924003OomS66<H00IS6003@Q0007oo00=S6092
409S60524040000000=S67ooHaP01f<H00=oof<HHaP02V<H0`001F<H00=2
4000Ool016<H0P003V<H00=24000Ool01f<H2@0016<H00=24000HaP01f<H
00=oof<HHaP01V<H00E246<HHaQS648@00MS6003@Q0007oo00=S60I240]S
6003@Q0007oo00QS60A240QS6003@Q0006<H00MS6003OomS66<H00AS60<0
00]S6003@Q0007oo00IS60<000]S6003@Q0007oo00IS60<000]S6003@Q00
07oo00IS60<000]S6003@Q0006<H00MS6003OomS66<H019S6003@Q0007oo
009S60H000aS6003@Q0007oo01AS6003@Q0007oo01AS6003@Q0006<H00MS
6003OomS66<H019S6003@Q0007oo00mS60=l009S6003@Q0007oo01AS6003
@Q0007oo00eS6080009S6005O01S66<H@Q000008HaP00gooHaQS6007HaP2
@Q09HaP00d8@001oo`02HaP2@Q03HaP1@Q0100000003HaQoof<H00MS6003
OomS66<H019S6003@Q0007oo01AS6003@Q0007oo01AS6003@Q0006<H00MS
6003OomS66<H019S6003@Q0007oo01AS6003@Q0007oo01AS6003@Q0006<H
00MS6003OomS66<H019S6003@Q0007oo01AS6003@Q0007oo01AS6003@Q00
07oo01AS6003@Q0006<H00MS6003OomS66<H019S6003@Q0007oo01AS6003
@Q0007oo01AS6003@Q0007oo01AS6003@Q0006<H00MS6003OomS66<H019S
6003@Q0007oo01AS6003@Q0007oo01AS6003@Q0007oo01AS6003@Q0006<H
00MS6003OomS66<H019S6003@Q0007oo00MS60524040000000=S67ooHaP0
1f<H00=oof<HHaP04V<H00=24000Ool056<H00=24000Ool056<H00=24000
HaP01f<H00=oof<HHaP04V<H00=24000Ool056<H00=24000Ool056<H00=2
4000HaP01f<H00=oof<HHaP04V<H00=24000Ool056<H00=24000Ool056<H
00=24000Ool056<H00=24000HaP01f<H00=oof<HHaP04V<H00=24000Ool0
56<H00=24000Ool056<H00=24000Ool056<H00=24000HaP01f<H00=oof<H
HaP04V<H00=24000Ool056<H00=24000Ool056<H00=24000Ool056<H00=2
4000HaP01f<H00=oof<HHaP04V<H00=24000Ool01f<H0D8@0@0000000f<H
OomS6007HaPFOol00`00Oomoo`0DOol00`00Oomoo`0DOol00`00HaQS6006
HaPFOol00`00Oomoo`0DOol00`00Oomoo`0DOol00`00HaQS6006HaPFOol0
0`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0DOol00`00HaQS6006
HaPFOol00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0DOol00`00
HaQS6006HaPFOol00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0D
Ool00`00HaQS6006HaPFOol00`00Oomoo`04Ool2HaP1@Q0100000003HaQo
of<H0?mS6>eS60524040000000=S67ooHaP0of<HkF<H0D8@0@0000000f<H
OomS603oHaS]HaP1@Q0100000004HaQoof<HHaSoOooZOol2HaP1@Q010000
0004HaQoof<HHaSo@Q3Z@Q02HaP1@Q0100000003HaQoof<H0?mS6>eS6052
4040000000=S67ooHaP0of<HkF<H0D8@0@0000000f<HOomS6005HaP00acW
8@PQ200<8@P00a24HaQS603oHaSFHaP1@Q0100000003HaQoof<H00ES6003
?NmS66<H00aS60038@QS66<H0?mS66ES6003001S66<H03QS6200009S6100
00AS60524040000000=S67ooHaP01F<H00Dmkf<HHaQS65[F00ES6003F]IS
66<H009S60038@QS66<H00IS60P001iS60T001iS60T002]S60T001iS60T0
02eS60P0029S60d003=S60X000aS6003001S66<H03QS6003Oom2448@00a2
4003001ood8@00e24004001S66<HOol>@Q000`00HaQS6002HaP1@Q010000
0003HaQoof<H00ES6005?NmS66<HHaQJeP05HaP00e[FHaQS6002HaP00b48
HaQS603oHaQUHaP00`00HaQS600hHaP00gooHaQS600;HaP00d8@001oo`0=
HaP01D8@001S66<HOol03F<H00=24000HaP00f<H0D8@0@0000000f<HOomS
6005HaP00cg_HaQS600:HaP00ff<HaPQ2009HaP00`00HaQS6005HaP01000
HaQS60000f<H10004f<H1`000f<H0`0000ES6000HaQS600000=S6003001S
66<H019S6003001S66<H00=S6003001S66<H009S60@00004HaP006<HHaP4
0003HaP4000CHaP00`00HaQS6006HaP01000HaQS66<H100016<H00<006<H
HaP04V<H00<006<HHaP00f<H00@006<HHaQS60@000AS6005001S66<HHaP0
000FHaP00`00HaQS6004HaP40004HaP40003HaP01000HaQS66<H0`005F<H
00<006<HHaP00f<H00<006<HHaP00V<H00@006<HHaP000=S6004001S66<H
HaP300000f<H001S6002HaP40004HaP01@00HaQS66<H00004f<H00<006<H
HaP016<H00@006<HHaQS60@000=S6005001S66<H001S6003000fHaP017oo
HaQS66<H1P0016<H00=24000Ool00V<H1P001F<H00E24000HaQS67oo00eS
6003@Q0006<H00=S60524040000000=S67ooHaP01F<H00<mke[FHaP00U[F
00AS65[FF]IS609JeP05HaQUBV<HKH`Q2009HaP00`00HaQS6005HaP01000
HaQS60000V<H00<006<HHaP00V<H00<006<HHaP046<H00<006<HHaP01V<H
00@006<HHaQS6080009S6004001S66<H000EHaP00`00HaQS6003HaP01@00
HaQS66<H000016<H00@006<HHaP000AS6003001S600000AS6003001S66<H
011S6003001S66<H00IS6004001S66<H0004HaP01000HaQS60005F<H00<0
06<HHaP00f<H00@006<HHaP000AS6005001S66<HHaP00003HaP00`00HaQS
600DHaP00`00HaQS6003HaP00`00HaQS6002HaP01000HaQS600016<H00@0
06<HHaP0009S6005001S66<HHaP0000DHaP00`00HaQS6003HaP00`00HaQS
6002HaP01000HaQS60000f<H00@006<HHaP000=S6080009S6003001S66<H
009S6005001S66<HHaP00003HaP00`00HaQS600AHaP00`00HaQS6004HaP0
1000HaQS600016<H00@006<HHaP0009S608000=S6003001S66<H03=S6004
OomS66<HHaP60004HaP00d8@001oo`02HaP00`00HaQS6002HaP00`00HaQS
6003HaP01D8@001S66<HOol00f<H0P0016<H0P000V<H00=24000HaP00f<H
0D8@0@0000000f<HOomS6005HaP01Cg_HaQS66<HF]H01F<H0Vf<0f<H00<Q
26<HHaP01f<H00<006<HHaP01F<H00@006<HHaP0009S6003001S66<H01ES
6003001S66<H00IS6003001S66<H009S6004001S66<H0002HaP00`00HaQS
600CHaP00`00HaQS6003HaP01@00HaQS66<H000016<H00@006<HHaP000IS
6003001S66<H01ES6003001S66<H00IS6004001S66<H0004HaP01000HaQS
600056<H00<006<H000016<H00@006<HHaP000MS6007001S6000HaP006<H
00005F<H00<006<HHaP00f<H00<006<HHaP00V<H00@006<HHaP000AS6004
001S66<H0006HaP00`00HaQS600AHaP00`00HaP00003HaP00`00HaP00003
HaP01000HaQS60000f<H00@006<HHaP000AS6004001S66<H0004HaP02P00
HaQS6000HaP006<H001S60004V<H00<006<HHaP016<H00@006<HHaP000MS
6004001S66<H0004HaP00`00HaQS600cHaP00gooHaQS600;HaP00d8@001o
o`02HaP00`00HaQS6002HaP00`00HaQS6003HaP01D8@001S66<HOol016<H
0P000V<H0P000f<H00=24000HaP00f<H0D8@0@0000000f<HOomS6005HaP0
0cg_KHa]S002KH`4HaP00ff<HaQS6003HaP00b48HaQS6007HaP00`00HaQS
6005HaP01000HaQS60000V<H1P004V<H00<006<HHaP01V<H00<006<HHaP0
0V<H00@006<HHaP0009S6003001S66<H01=S6003001S66<H00=S6005001S
66<HHaP00004HaP01000HaQS60001V<H1P004V<H00<006<HHaP01V<H00@0
06<HHaP000AS6004001S66<H000DHaP00`00HaP00004HaP00`00HaQS6006
0002HaP01`00HaP006<H001S600001ES6003001S66<H00=S6003001S66<H
009S6004001S66<H0004HaP01000HaQS60000f<H0`0056<H00<006<H0000
0f<H00<006<H00000f<H00@006<HHaP000=S6004001S66<H0004HaP01000
HaQS600016<H00X006<HHaP006<H001S6000HaP0019S6003001S66<H00AS
6003001S66<H00H0009S6004001S66<H0004HaP00`00HaQS600cHaP00goo
HaQS600;HaP00d8@001oo`02HaP00`00HaQS6002HaP30003HaP01D8@001S
66<HOol01F<H100016<H00=24000HaP00f<H0D8@0@0000000f<HOomS6005
HaP01Sg_HaQS66<HGQ1]S0=S6003KHaJeV<H00=S60038@QS66<H00MS6003
001S66<H00ES6004001S66<H0002HaP00`00HaQS6002HaP00`00HaQS600@
HaP00`00HaQS6006HaP00`00HaQS6002HaP01000HaQS60000V<H00<006<H
HaP04f<H00<006<HHaP00f<H00<006<HHaP00V<H1@000V<H00<006<HHaP0
16<H00<006<HHaP00V<H00<006<HHaP046<H1P000f<H00@006<HHaP000AS
6004001S66<H000CHaP01@00HaQS66<H00000f<H00@006<HHaP000AS600:
001S66<H001S6000HaP006<H000EHaP00`00HaQS6003HaP00`00HaQS6002
HaP01000HaQS600016<H00@006<HHaP0009S6003001S66<H01ES6003001S
600000=S6003001S600000=S6004001S66<H0003HaP01000HaQS600016<H
00@006<HHaP000AS600:001S66<H001S6000HaP006<H000BHaP00`00HaQS
6004HaP01000HaQS600016<H00@006<HHaP0009S6003001S66<H009S6003
001S66<H03=S6003OomS66<H00]S6003@Q0007oo009S60H00003HaP006<H
009S6005@Q0006<HHaQoo`06HaP20005HaP00d8@001S6003HaP1@Q010000
0003HaQoof<H00ES6003?NmS66<H009S609VDP9S6003KHaS66<H00=S6003
8@QS66<H00MS60H0009S6004001S66<H0002HaP00`00HaQS6002HaP00`00
HaQS600@HaP60003HaP01000HaQS66<H0P000V<H00@006<HHaP001ES6003
001S66<H00=S6080009S6003001S66<H009S6004001S66<H0004HaP00`00
HaP00004HaP00`00HaQS600@HaP00`00HaQS6003HaP01000HaQS60000V<H
00<006<HHaP00V<H00@006<HHaP001=S6005001S66<HHaP00003HaP01000
HaQS600016<H00<006<H00000f<H00D006<HHaQS600001AS6003001S66<H
00=S6003001S66<H009S6004001S66<H0004HaP01000HaQS60000V<H00D0
06<HHaQS6000019S6007001S66<HHaP006<H00000f<H00@006<HHaP0009S
6080009S6004001S66<H0003HaP20002HaP00`00HaQS6002HaP00`00HaP0
0003HaP01@00HaQS66<H00004F<H20000V<H00<006<HHaP00V<H00@006<H
HaP0009S608000=S6003001S66<H03=S6003OomS66<H00]S6003@Q0007oo
009S60H00003HaP006<H009S6005@Q0006<HHaQoo`05HaP40004HaP00d8@
001S6003HaP1@Q0100000003HaQoof<H00ES600;?NmS66<HHaQJeV<HM<IS
66f<IU9JeP04HaP00b48HaQS6007HaP00`00HaQS6005HaP01000HaQS6000
0f<H10004f<H00<006<HHaP01f<H0`0000IS6000HaQS6000HaP3000DHaP0
0`00HaQS6003HaP00`00HaP00002HaP40004HaP40003HaP4000CHaP00`00
HaQS6004HaP00`00HaP00003HaP40002HaP3000AHaP00`00HaQS6003HaP0
1000HaQS60000f<H10000V<H00D006<HHaQS600000=S6003001S66<H019S
6003001S66<H00AS60@000AS60@000=S6004001S66<HHaP3000CHaP01`00
HaQS66<H001S600000=S6004001S66<H0002HaP01000HaP0000016<H0`00
00=S6000HaP00V<H10000V<H00D006<HHaQS600000=S6003001S66<H00mS
6003001S66<H00AS6004001S66<HHaP40003HaP01@00HaQS6000HaP00`00
=V<H00=oof<HHaP02f<H00=24000Ool016<H00<006<HHaP00V<H00H006<H
HaQS648@0002HaP00gooHaQS6002HaP20002HaP20003HaP00d8@001S6003
HaP1@Q0100000003HaQoof<H00ES6003?NmJeV<H009JeP04HaQJeVE:IU82
F]H01F<HF]IJeV<H8@P02F<H00<006<HHaP026<H00<006<HHaP066<H00<0
06<HHaP02f<H00<006<HHaP00f<H00<006<HHaP04f<H00<006<HHaP0;V<H
00<006<HHaP016<H00<006<H00002V<H00<006<HHaP046<H00<006<HHaP0
0f<H00<006<HHaP09f<H00<006<HHaP04f<H00<006<HHaP05V<H00<006<H
HaP00f<H00<006<HHaP00f<H00<006<HHaP03V<H00<006<HHaP08F<H00<0
06<HHaP016<H00<006<HHaP026<H00<006<HHaP0>f<H00=oof<HHaP02f<H
00=24000Ool016<H1P000f<H00E24000HaQS67oo00=S608000AS6080009S
6003@Q0006<H00=S60524040000000=S67ooHaP01F<H00<mkf<HHaP036<H
00<Q26<HHaP01f<H00<006<HHaP026<H00<006<HHaP066<H00<006<HHaP0
2f<H00<006<HHaP00f<H00<006<HHaP04f<H00<006<HHaP0;V<H00<006<H
HaP00f<H00@006<HHaP000YS6003001S66<H00mS6003001S66<H00ES6003
001S66<H02IS6003001S66<H01=S6003001S66<H01IS6003001S66<H00=S
6003001S66<H00=S6003001S66<H00iS6003001S66<H025S6003001S66<H
00AS6003001S66<H00QS6003001S66<H03]S6003OomS66<H00]S6003@Q00
07oo00AS60H000=S6005@Q0006<HHaQoo`0=HaP00d8@001S6003HaP1@Q01
00000003HaQoof<H00ES6005?NmS66<HHaQJeP05HaP00e[FHaQS6002HaP0
0b48HaQS6007HaP700001F<H001S66<H00006V<H1`001f<H00@006<HHaP0
01AS60T002aS60H000=S6003001S66<H01YS6003001S66<H00ES6003001S
6000029S60T0015S6003001S66<H01IS6003001S66<H00=S6003001S66<H
00=S6003001S600000iS6003001S66<H025S6003001S66<H00AS6003001S
66<H00QS6003001S66<H03]S6003OomS66<H00]S6003@Q0007oo00eS6005
@Q0006<HHaQoo`0=HaP00d8@001S6003HaP1@Q0100000003HaQoof<H00ES
6005?NmS66<HHaQJeP05HaP00e[FHaQS6002HaP00b48HaQS603oHaRPHaP?
Ool00`00Oomoo`0=Ool00`00HaQS600?Ool00`00HaQS6002HaP1@Q010000
0003HaQoof<H00ES60037>Lmkcg_00`mk`0348AS66<H0?mS6=IS60524040
000000=S67ooHaP0of<HkF<H0D8@0@0000000f<HOomS603oHaS]HaP1@Q01
00000004HaQoof<HHaSo013Z0102HaP1@Q0100000004HaQoof<HHaP20100
0a248@PQ200:8@P00c6<0100401n0104Oom40104Oooo010>0102HaP1@Q01
00000004HaQoof<HHaP201000cgWOnmok`0:Onl00b480100401n0102Oom8
0102OooI010P0002010@00020102HaP1@Q0100000004HaQoof<HHaP20102
?NL017o_?NMokcgW1go_00<Q200@0100OP0@0WooB00@0Woof@0@00=ood8@
@Q00348@00<007oo@Q003D8@00@0000@011oo`i240030000400@009S6052
4040000000AS67ooHaQS608040Hmi`037>0mibeP00@mi`038@P0400@00<0
409oo`80409oo`80409oo`80409oo`<040Eoo`80409oo`@040Eoo`@040Io
o`<0409oo`80409oo`80409oo`80409oo`H0409oo`P0409oo`@040Eoo`<0
40Ioo`@040Eooa00409oo`<040Ioo`@040Eoo`80409oo`80409oo`<040Eo
o`<0409oo`<0409oo`<040Eoo`<040Aoo`@040Ioo`<0409oomT04003OomS
66<H00]S6003@Q0007oo00eS6005@Q00000@011oo`0=HaP0148@0000400@
0V<H0D8@0@00000016<HOomS66<H0P0@00/Lh5kW?N1NicgPG^Mokek_:DXa
P6m_009ok`038@P0400@00<0409oo`80409oo`80409oo`80409oo`80409o
o`<0409oo`03011oogoo00<0409oo`<0409oo`80409oo`@0409oo`80409o
o`80409oo`80409oo`80409oo`H0409oo`P0409oo`<0409oo`<0409oo`80
40=oo`80409oo`80409oo`<0409oo`l0409oo`<040=oo`80409oo`80409o
o`04011oogooOol20102Ool20102Ool20102Ool30102Ool20102Ool70102
Ool30102Ool00`0@Oomoo`020102Ool20102Ool20103Ool30102OooI0100
17ooHaQS66<H1P0016<H00=24000Ool00V<H2@000V<H00E24000010047oo
00eS6004@Q00000@0102HaP1@Q0100000004HaQoof<HHaP201001AcWOnm>
IekW?NL00ekW00<YATYB<H000UkW00<0048@@Q000`0@0Woo00<047ooOol0
0Woo00<047ooOol00P0@0Woo0P0@0Woo1P0@0Woo0`0@0Woo0`0@0Woo0P0@
0Woo100@0Woo0P0@0Woo0P0@0Woo0P0@0Woo0P0@0Woo1P0@0Woo200@0Woo
0`0@0Woo0`0@0Woo0P0@0Woo0`0@0Woo0P0@0Woo500@0Woo0`0@0Woo0`0@
0Woo0P0@0Woo0P0@0Woo0P0@0Woo0P0@0Woo0P0@0Woo1`0@0Woo1`0@0Woo
2P0@0Woo0P0@0Woo0`0@0Woo0`0@0Woof@0@00Aoof<HHaQS60H000AS6003
@Q0007oo009S6003001S66<H00ES6005001S66<H@Q000002010017ooHaQS
66<H0P0016<H0P000V<H00A240000100409S60524040000000AS67ooHaQS
60804003?NMokacW00Hmk`03MkeF]Cg_008mk`037>M2400@0080409oo`03
011oogoo009oo`03011oogoo0080409oo`80409oo`H0409oo`<0409oo`<0
409oo`P0409oo`80409oo`80409oo`80409oo`80409oo`H0409oo`P0409o
o`<0409oo`<0409oo`80409oo`<0409oo`8040Moo`l0409oo`<0409oo`<0
409oo`80409oo`80409oo`80409oo`80409oo`8040Moo`80409oo`L0409o
o`L040Aoo`<0409oo`<0409oo`<0409oomT04003OomS66<H00]S6003@Q00
07oo009S6003001S66<H00ES6005001S66<H@Q00000201000gooHaQS6002
HaP20002HaP20003HaP0148@0000400@0V<H0D8@0@00000016<HOomS66<H
0P0@00Hmigo_?NlLicg_;F/2?Nl00be[?Nl]J`04?Nl0148@0100400@17oo
0P0@17oo0P0@0Woo0P0@0Woo1P0@0Woo0`0@0Woo0`0@0Woo1P0@0goo0`0@
0Woo0P0@0Woo0P0@0Woo0P0@0Woo1P0@1goo0`0@0Woo0`0@0Woo0`0@0Woo
0P0@0Woo0`0@0Woo0P0@0Woo0`0@0Woo1@0@1Goo1@0@0Woo0`0@0Woo0`0@
0Woo0P0@0Woo0P0@0Woo0P0@0Woo0P0@0Woo0P0@0Woo0`0@0Woo0P0@0Woo
1`0@0Woo1P0@0Woo1P0@0Woo0`0@0Woo0`0@0Woof@0@00=oof<HHaP02f<H
00=24000Ool00V<H00<006<HHaP01F<H00D006<HHaQ2400000804003OomS
66<H00=S60@000AS6004@Q00000@0102HaP1@Q0100000004HaQoof<HHaP2
01002cgWOnlmkck_0N0BI07P000Q20008@P00P000Sg_00A2400@010040Ao
o`8040Aoo`80409oo`80409oo`<0409oo`04011oogooOol20102Ool30102
Ool30104Ool50102Ool20103Ool01@0@Oomoogoo01000Woo1P0@0Woo100@
0Woo0P0@0goo0P0@0Woo0`0@0Woo0P0@0goo0P0@0Woo0P0@0Woo0`0@0Woo
3`0@0Woo0`0@0goo0P0@0Woo0P0@0Woo0P0@0Woo0P0@0Woo0P0@0Woo0P0@
0Woo0`0@0Woo0P0@0goo1P0@0Woo0`0@0Woo00<047ooOol00P0@0Woo0P0@
0Woo0P0@0goo0`0@0Woof@0@00=oof<HHaP02f<H00=24000Ool00V<H00<0
06<HHaP01F<H00D006<HHaQ2400000804003OomS66<H00AS608000ES6004
@Q00000@0102HaP1@Q0100000004HaQoof<HHaP201002cgWOnlmkbe[8@Pa
S2484V@aS248<H`00R4800=>Lcg_@Q000`0@0goo100@0goo0P0@0Woo0`0@
1Goo0P0@17oo0P0@1Goo0`0@0Woo200@0Woo0P0@1Goo00@047ooOomoo`L0
409oo`D0409oo`03011oogoo009oo`8040Eoo`<040Ioo`@040Eooa00409o
o`<040Ioo`<0409oo`80409oo`03011oogoo00Ioo`8040Eoo`<040Aoo`H0
40Eoo`<040Aoo`@040Ioo`<0409oomT04003OomS66<H00]S6003@Q0007oo
009S6003001S66<H00ES6005001S66<H@Q00000201000gooHaQS6003HaP4
0004HaP0148@0000400@0V<H0D8@0@00000016<HOomS66<H0P0@00/migo_
?Nlmk`008@P0003P4F@002480080008mk`04@Q00400@0103Ool40103OolL
0102Ool40102OolF0102Ool50102Ool?0102OolM0102Ool30102Ool?0102
Ool20102OolY0102Ool30102OooI01000gooHaQS600;HaP00d8@001oo`02
HaP00`00HaQS6005HaP01@00HaQS648@00000P0@00=oof<HHaP00V<H0P00
0V<H0P000f<H00A240000100409S60524040000000AS67ooHaQS60804006
?NMokcg_?Nl002480P0000<1h0008@P00P000Sg_00A2400@0100409oo`H0
409ooa`0409oo`@0409ooaH0409oo`@0409ooa00409ooad0409oo`<0409o
o`l0409oo`80409oobT0409oo`<0409oomT04003OomS66<H00]S6003@Q00
07oo009S60T0009S6005@Q00000@011oo`03HaP20004HaP20002HaP0148@
0000400@0V<H0D8@0@00000016<HOomS66<H0P0@00Hmigo_?Nl]Jb48<H`2
8@P0219T8@PQj07P8@Q>Lcg_@Q030102Ool60102Ool20102OolI0106Ool3
0102OolB0107OolA0102OolM0104Ool00`0@Oomoo`0@0102Ool20102OolX
0102Ool00`0@Oomoo`02OooI01000gooHaQS600;HaP00d8@001oo`02HaP9
0002HaP01D8@0000400@Ool03F<H00A240000100409S60524040000000AS
67ooHaQS60804080008mk`0<000Q2000000Qj07P8NP0007P?^lmkd8@o`0@
Y00@00=oof<HHaP02f<H00=24000Ool03F<H00E24000010047oo00eS6004
@Q00000@0102HaP1@Q0100000004HaQoof<HHaP4010013g_7>L002480P00
00<Q20008@P00P000Sg_00=2400@0100o`0@XP0@3goo00<007ooOol03Goo
00<0000@01003goo00<0000@01000V<H0D8@0@00000016<HOomS66<H100@
00<Licg_?Nl02Cg_00<Lia240100o`0@e`0@0V<H0D8@0@00000016<HOomS
66<Ho`0@jP0@0V<H0D8@0@0000000f<HOomS603oHaS]HaP1@Q0100000003
HaQoof<H0?mS6>eS60524040000000=S67ooOol0ogookGoo0D8@0@00003o
HaSaHaP100000001\
\>"], "Picture",
  CellMargins->{{20, 0}, {0, 0}},
  ImageSize->{498.125, 418},
  ImageMargins->{{11, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
    \(BufferDatTran\  = \ 
      ReadSimulationData["\<Buffer.csd\>", Simulator \[Rule] "\<PSpice\>"]
        \)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\<\"V(VOUT)\"\>", "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 0.00001`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{"\<\"I(VIN)\"\>", "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 0.00001`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{"\<\"I(VDD)\"\>", "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 0.00001`}}, "<>"]\),
              False,
              Editable->False]}]}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\({VOUT, IIN, IVDD} = {"\<V(VOUT)\>", "\<I(VIN)\>", "\<I(VDD)\>"} /. 
        First@BufferDatTran; \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(TransientPlot[VOUT[t], {t, 0. , 1.*^-5}]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .41901 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 1 r
MFill
% Scaling calculations
0.346651 0.322841 0.209503 0.322841 [
[ 0 0 0 0 ]
[ 1 .41901 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.00997634 0.669492 0.40903 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 1 r
MFill
% Scaling calculations
0.0238095 95238.1 -38.0677 12.8135 [
[.21429 .36018 -16.5 -12.5 ]
[.21429 .36018 16.5 0 ]
[.40476 .36018 -16.5 -12.5 ]
[.40476 .36018 16.5 0 ]
[.59524 .36018 -16.5 -12.5 ]
[.59524 .36018 16.5 0 ]
[.78571 .36018 -16.5 -12.5 ]
[.78571 .36018 16.5 0 ]
[.97619 .36018 -21 -9 ]
[.97619 .36018 21 0 ]
[1.025 .37268 0 -6.28125 ]
[1.025 .37268 10 6.28125 ]
[.01131 .11641 -24 -4.5 ]
[.01131 .11641 0 4.5 ]
[.01131 .24454 -24 -4.5 ]
[.01131 .24454 0 4.5 ]
[.01131 .50081 -24 -4.5 ]
[.01131 .50081 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
.21429 .37268 m
.21429 .37893 L
s
gsave
.21429 .36018 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.40476 .37268 m
.40476 .37893 L
s
gsave
.40476 .36018 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.59524 .37268 m
.59524 .37893 L
s
gsave
.59524 .36018 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(6) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.78571 .37268 m
.78571 .37893 L
s
gsave
.78571 .36018 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(8) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .37268 m
.97619 .37893 L
s
[(0.00001)] .97619 .36018 0 1 Mshowa
.125 Mabswid
.07143 .37268 m
.07143 .37643 L
s
.11905 .37268 m
.11905 .37643 L
s
.16667 .37268 m
.16667 .37643 L
s
.2619 .37268 m
.2619 .37643 L
s
.30952 .37268 m
.30952 .37643 L
s
.35714 .37268 m
.35714 .37643 L
s
.45238 .37268 m
.45238 .37643 L
s
.5 .37268 m
.5 .37643 L
s
.54762 .37268 m
.54762 .37643 L
s
.64286 .37268 m
.64286 .37643 L
s
.69048 .37268 m
.69048 .37643 L
s
.7381 .37268 m
.7381 .37643 L
s
.83333 .37268 m
.83333 .37643 L
s
.88095 .37268 m
.88095 .37643 L
s
.92857 .37268 m
.92857 .37643 L
s
.25 Mabswid
0 .37268 m
1 .37268 L
s
gsave
1.025 .37268 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(t) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.02381 .11641 m
.03006 .11641 L
s
[(2.98)] .01131 .11641 1 0 Mshowa
.02381 .24454 m
.03006 .24454 L
s
[(2.99)] .01131 .24454 1 0 Mshowa
.02381 .50081 m
.03006 .50081 L
s
[(3.01)] .01131 .50081 1 0 Mshowa
.125 Mabswid
.02381 .14203 m
.02756 .14203 L
s
.02381 .16766 m
.02756 .16766 L
s
.02381 .19329 m
.02756 .19329 L
s
.02381 .21892 m
.02756 .21892 L
s
.02381 .27017 m
.02756 .27017 L
s
.02381 .2958 m
.02756 .2958 L
s
.02381 .32142 m
.02756 .32142 L
s
.02381 .34705 m
.02756 .34705 L
s
.02381 .3983 m
.02756 .3983 L
s
.02381 .42393 m
.02756 .42393 L
s
.02381 .44956 m
.02756 .44956 L
s
.02381 .47518 m
.02756 .47518 L
s
.02381 .09078 m
.02756 .09078 L
s
.02381 .06515 m
.02756 .06515 L
s
.02381 .03953 m
.02756 .03953 L
s
.02381 .0139 m
.02756 .0139 L
s
.02381 .52644 m
.02756 .52644 L
s
.02381 .55207 m
.02756 .55207 L
s
.02381 .57769 m
.02756 .57769 L
s
.02381 .60332 m
.02756 .60332 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
1 Mabswid
.02381 .37268 m
.03124 .23316 L
.03343 .1523 L
.0345 .11398 L
.0355 .08378 L
.0364 .0595 L
.03736 .04537 L
.03832 .03569 L
.03937 .02502 L
.0404 .01472 L
.04097 .0192 L
.04149 .02485 L
.04348 .0543 L
.04787 .11337 L
.05578 .21984 L
.06433 .3219 L
.07366 .4099 L
.07825 .44695 L
.08257 .48185 L
.08645 .50479 L
.09065 .52738 L
.09475 .54942 L
.09675 .56018 L
.09762 .56488 L
.09857 .56743 L
.09956 .57009 L
.1005 .57261 L
.10256 .57816 L
.10694 .58994 L
.10921 .59606 L
.11046 .59942 L
.11107 .60107 L
.11163 .60257 L
.11262 .60332 L
.1137 .60332 L
.11488 .60332 L
.11545 .60332 L
.11597 .60332 L
.11691 .60267 L
.11791 .59998 L
.12003 .59429 L
.12108 .59146 L
.12167 .59051 L
.12222 .59051 L
.12328 .59051 L
.12429 .59051 L
.12526 .59051 L
.12631 .59019 L
.12727 .58761 L
.12816 .58522 L
Mistroke
.13231 .57039 L
.13982 .54103 L
.14809 .49829 L
.1569 .44515 L
.17346 .33613 L
.18217 .28927 L
.18692 .26369 L
.18924 .25121 L
.19136 .23984 L
.19234 .23455 L
.19341 .23027 L
.19441 .22756 L
.19534 .22506 L
.19961 .21357 L
.20392 .20199 L
.20866 .18923 L
.21058 .18407 L
.21165 .18117 L
.21264 .18047 L
.21351 .18047 L
.21446 .18047 L
.21545 .18047 L
.21637 .18047 L
.21745 .18256 L
.21843 .18519 L
.21957 .18826 L
.22062 .19108 L
.22154 .19329 L
.22251 .19329 L
.22456 .19329 L
.22556 .19329 L
.22613 .19329 L
.22666 .19453 L
.22865 .19989 L
.23239 .20994 L
.23638 .22068 L
.2385 .22639 L
.23962 .22939 L
.24022 .23103 L
.24079 .23337 L
.24173 .23845 L
.24277 .24401 L
.24372 .24912 L
.24458 .25377 L
.24547 .25794 L
.2463 .26019 L
.24814 .26514 L
.24909 .26769 L
.25009 .27061 L
.25095 .27521 L
Mistroke
.25189 .28029 L
.25596 .29898 L
.27338 .37149 L
.28165 .40655 L
.28567 .42363 L
.28742 .43305 L
.28841 .43755 L
.28931 .43999 L
.29128 .44528 L
.29313 .45025 L
.29719 .46118 L
.30128 .4722 L
.30345 .47804 L
.30465 .48125 L
.30578 .48429 L
.30676 .48694 L
.30784 .488 L
.30881 .488 L
.30971 .488 L
.31063 .488 L
.31149 .488 L
.31239 .48928 L
.31338 .49195 L
.31527 .49702 L
.3163 .49978 L
.31725 .50081 L
.31829 .50081 L
.31943 .50081 L
.32142 .50081 L
.3256 .50081 L
.3278 .50081 L
.32901 .50081 L
.3296 .50081 L
.33014 .50081 L
.33112 .5004 L
.33217 .49756 L
.33442 .49153 L
.33646 .48602 L
.33836 .48091 L
.3393 .47837 L
.34019 .47599 L
.34121 .47518 L
.34214 .47518 L
.34412 .47518 L
.34466 .47518 L
.34523 .47518 L
.34626 .47248 L
.35375 .45232 L
.38523 .34198 L
.39355 .31959 L
Mistroke
.40142 .29842 L
.40353 .29274 L
.40577 .28672 L
.40633 .28521 L
.40694 .28358 L
.4076 .28298 L
.40823 .28298 L
.40931 .28298 L
.41049 .28298 L
.41105 .28298 L
.41164 .28298 L
.4127 .28088 L
.4148 .27523 L
.41587 .27237 L
.41687 .27017 L
.41777 .27017 L
.41875 .27017 L
.42254 .27017 L
.42661 .27017 L
.42781 .27017 L
.42894 .27017 L
.42996 .27017 L
.43054 .27017 L
.43107 .27044 L
.43203 .27303 L
.43309 .27588 L
.43412 .27864 L
.4347 .2802 L
.43524 .28166 L
.43577 .28298 L
.43634 .28298 L
.4375 .28298 L
.43957 .28298 L
.44196 .28298 L
.44314 .28298 L
.44423 .28298 L
.44526 .28299 L
.44635 .28593 L
.44865 .29212 L
.45267 .30293 L
.48402 .37446 L
.50145 .41112 L
.50972 .42393 L
.51072 .42393 L
.51179 .42393 L
.51281 .42631 L
.51374 .42882 L
.51548 .4335 L
.51647 .43616 L
.51739 .43674 L
Mistroke
.51829 .43674 L
.51925 .43674 L
.52121 .43674 L
.52527 .43674 L
.53386 .43674 L
.53807 .43674 L
.54014 .43674 L
.54205 .43674 L
.54379 .43674 L
.54466 .43674 L
.54563 .43576 L
.54659 .43317 L
.54763 .43037 L
.5486 .42777 L
.54951 .42531 L
.55055 .42393 L
.5515 .42393 L
.55261 .42393 L
.55362 .42393 L
.55452 .42393 L
.55546 .42212 L
.55745 .41677 L
.55848 .414 L
.55904 .41247 L
.55958 .41112 L
.56063 .41112 L
.56158 .41112 L
.56263 .41112 L
.56321 .41112 L
.56375 .41112 L
.56434 .41105 L
.56498 .40931 L
.56612 .40625 L
.58359 .37205 L
.59097 .35986 L
.59885 .3438 L
.59997 .34079 L
.60118 .33753 L
.60174 .33603 L
.60233 .33445 L
.60339 .33424 L
.6044 .33424 L
.60535 .33424 L
.60751 .33424 L
.6095 .33424 L
.61048 .33424 L
.61139 .33424 L
.61244 .33288 L
.61299 .3314 L
.61357 .32981 L
Mistroke
.61557 .32445 L
.61611 .32298 L
.61669 .32143 L
.61772 .32142 L
.61829 .32142 L
.61883 .32142 L
.62004 .32142 L
.62425 .32142 L
.63213 .32142 L
.64109 .32142 L
.6455 .32142 L
.64958 .32142 L
.6516 .32142 L
.65349 .32142 L
.65444 .32142 L
.65547 .32325 L
.65602 .32474 L
.65661 .32631 L
.65765 .32912 L
.6587 .33194 L
.65928 .3335 L
.65982 .33424 L
.66088 .33424 L
.66184 .33424 L
.66291 .33424 L
.6635 .33424 L
.66404 .33424 L
.66463 .3351 L
.66528 .33684 L
.66643 .33992 L
.66738 .34248 L
.66841 .34526 L
.66939 .34705 L
.6703 .34705 L
.67212 .34705 L
.67301 .34705 L
.67383 .34705 L
.6748 .34965 L
.67585 .35247 L
.67769 .3574 L
.67864 .35986 L
.67968 .35986 L
.68078 .35986 L
.68179 .35986 L
.6828 .35986 L
.68387 .36124 L
.68495 .36414 L
.68614 .36733 L
.68716 .37009 L
.68773 .37161 L
Mistroke
.68826 .37268 L
.6893 .37268 L
.69026 .37268 L
.69118 .37268 L
.69217 .37268 L
.6931 .37325 L
.69394 .37552 L
.6959 .38078 L
.69697 .38366 L
.69797 .38549 L
.69903 .38549 L
.7002 .38549 L
.70225 .38549 L
.70467 .38549 L
.70573 .38549 L
.70629 .38549 L
.70689 .38549 L
.70797 .38762 L
.70897 .39032 L
.71094 .39563 L
.71201 .3983 L
.71301 .3983 L
.71529 .3983 L
.71917 .3983 L
.72023 .3983 L
.72082 .3983 L
.72137 .3983 L
.72244 .40094 L
.72342 .40357 L
.72445 .40636 L
.72555 .40932 L
.72649 .41112 L
.72752 .41112 L
.73198 .41112 L
.73983 .41112 L
.7437 .41112 L
.74729 .41112 L
.74829 .41112 L
.74923 .41112 L
.75032 .41035 L
.7513 .40769 L
.75242 .40471 L
.75359 .40155 L
.75459 .39886 L
.75516 .3983 L
.75569 .3983 L
.75938 .3983 L
.76337 .3983 L
.76561 .3983 L
.76671 .3983 L
Mistroke
.76773 .3983 L
.76866 .3983 L
.76964 .3968 L
.77062 .39415 L
.77171 .39123 L
.77279 .38831 L
.77338 .38673 L
.77393 .38549 L
.77453 .38549 L
.77518 .38549 L
.77632 .38549 L
.7774 .38549 L
.77842 .38549 L
.77898 .38448 L
.77959 .38285 L
.78065 .37999 L
.78165 .37729 L
.78261 .37473 L
.78313 .37331 L
.7837 .37268 L
.78471 .37268 L
.7885 .37268 L
.79066 .37268 L
.79129 .37268 L
.79187 .37268 L
.7924 .37268 L
.79297 .37246 L
.79402 .36963 L
.79513 .36665 L
.79615 .3639 L
.79712 .36131 L
.79821 .35986 L
.7992 .35986 L
.80142 .35986 L
.80337 .35986 L
.80543 .35986 L
.80651 .35986 L
.80713 .35986 L
.8077 .35846 L
.8098 .35282 L
.81097 .34967 L
.81155 .34811 L
.81208 .34705 L
.81269 .34705 L
.81336 .34705 L
.81454 .34705 L
.84692 .34705 L
.85543 .34705 L
.86463 .34705 L
.86886 .34705 L
Mistroke
.87117 .34705 L
.8723 .34705 L
.87333 .34705 L
.87427 .34819 L
.87517 .3506 L
.87714 .35591 L
.87811 .35852 L
.87915 .35986 L
.87968 .35986 L
.88028 .35986 L
.88133 .35986 L
.88539 .35986 L
.88638 .35986 L
.88744 .35986 L
.88805 .35986 L
.8886 .36111 L
.88968 .36401 L
.89157 .3691 L
.89263 .37197 L
.89362 .37268 L
.89448 .37268 L
.89542 .37268 L
.89733 .37268 L
.90163 .37268 L
.904 .37268 L
.90517 .37268 L
.90625 .37268 L
.90726 .37289 L
.90834 .37578 L
.90951 .37893 L
.91061 .3819 L
.91162 .3846 L
.9127 .38549 L
.91369 .38549 L
.91459 .38549 L
.94731 .38549 L
.97619 .38549 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
0 g
.71792 .14493 m
.71792 .26727 L
.97619 .26727 L
.97619 .14493 L
F
.96 g
.70178 .16108 m
.70178 .28342 L
.96005 .28342 L
.96005 .16108 L
F
0 g
.001 w
.70178 .16108 m
.96005 .16108 L
.96005 .28342 L
.70178 .28342 L
.70178 .16108 L
s
% Start of sub-graphic
p
0.701776 0.161077 0.960048 0.283417 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0263158 0.263158 0.0263158 0.263158 [
[ 0 0 0 0 ]
[ 1 .47368 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47368 L
0 .47368 L
closepath
clip
newpath
% Start of sub-graphic
p
0.105263 0.105263 0.368421 0.368421 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
1 Mabswid
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.46053 .23684 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(VOUT) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
87.000000 12.812500 moveto
(@) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
99.000000 12.812500 moveto
(D) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .41901 L
0 .41901 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{494, 206.813},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ParametricPlot3D[
      \[IndentingNewLine]{IIN[t], VOUT[t], IVDD[t], Hue[t/\((1.*^-5)\)]}, 
      \[IndentingNewLine]{t, 1.*^-6, 1.*^-5}\ , 
      \[IndentingNewLine]AxesLabel\  \[Rule] 
        \ {\ \*"\"\<\!\(I\_IN\)\>\"", \*"\"\<\!\(V\_OUT\)\>\"", 
          \*"\"\<\!\(I\_VDD\)\>\""}, 
      TextStyle\  \[Rule] 
        \ {FontSize \[Rule] 15, FontWeight\  \[Rule] \ Bold}
          \[IndentingNewLine]]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.02603 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 1 r
MFill
% Scaling calculations
-0.0596519 1.1193 3.77476e-015 1.1193 [
[.18103 .10504 -26.625 -14.4849 ]
[.18103 .10504 0 4.70259 ]
[.81897 .10504 0 -14.4849 ]
[.81897 .10504 33.5 4.70259 ]
[-0.05587 .53016 -33.5 -13.1936 ]
[-0.05587 .53016 0 5.99386 ]
[ 0 0 0 0 ]
[ 1 1.02603 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
.04348 .26766 m
.5 0 L
s
gsave
.18103 .10504 -87.625 -18.4849 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.1875 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 23.187500 moveto
 460.000000 23.187500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 23.187500 lineto
closepath
clip newpath
63.000000 17.625000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 15.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 17.625000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 15.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(I) show
72.000000 20.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.625000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(IN) show
85.625000 17.625000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 15.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.5 0 m
.95652 .26766 L
s
gsave
.81897 .10504 -61 -18.4849 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.1875 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 23.187500 moveto
 460.000000 23.187500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 23.187500 lineto
closepath
clip newpath
63.000000 17.625000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 15.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.312500 17.625000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 15.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(V) show
72.312500 20.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.625000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(OUT) show
92.500000 17.625000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 15.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.04348 .26766 m
0 .87945 L
s
gsave
-0.05587 .53016 -94.5 -17.1936 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.1875 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 23.187500 moveto
 460.000000 23.187500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 23.187500 lineto
closepath
clip newpath
63.000000 17.625000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 15.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 17.625000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 15.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(I) show
72.312500 20.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.625000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(VDD) show
92.500000 17.625000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 15.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.04348 .26766 m
0 .87945 L
s
0 .87945 m
.5 1.02603 L
s
.5 1.02603 m
.5 .47355 L
s
.5 .47355 m
.04348 .26766 L
s
.5 0 m
.95652 .26766 L
s
.95652 .26766 m
1 .87945 L
s
1 .87945 m
.5 .68402 L
s
.5 .68402 m
.5 0 L
s
.04348 .26766 m
0 .87945 L
s
0 .87945 m
.5 .68402 L
s
.5 .68402 m
.5 0 L
s
.5 0 m
.04348 .26766 L
s
.5 .47355 m
.95652 .26766 L
s
.95652 .26766 m
1 .87945 L
s
1 .87945 m
.5 1.02603 L
s
.5 1.02603 m
.5 .47355 L
s
0 0 m
1 0 L
1 1.02603 L
0 1.02603 L
closepath
clip
newpath
1 .746 0 r
.5 Mabswid
.65293 .71269 m
.51595 .84314 L
s
1 .673 0 r
.77233 .55219 m
.65293 .71269 L
s
1 .819 0 r
.51595 .84314 m
.38851 .92569 L
s
1 .892 0 r
.38851 .92569 m
.27817 .93926 L
s
.014 1 0 r
.66754 .52653 m
.59253 .60498 L
s
.086 1 0 r
.71911 .4358 m
.66754 .52653 L
s
0 1 .059 r
.59253 .60498 m
.52866 .67292 L
s
0 1 .132 r
.52866 .67292 m
.45725 .70786 L
s
.159 1 0 r
.74897 .34365 m
.71911 .4358 L
s
1 .965 0 r
.27817 .93926 m
.21279 .88341 L
s
0 1 .205 r
.45725 .70786 m
.40514 .71161 L
s
.232 1 0 r
.7564 .25961 m
.74897 .34365 L
s
0 .627 1 r
.56602 .5415 m
.52316 .57266 L
s
0 .7 1 r
.60108 .49464 m
.56602 .5415 L
s
0 .773 1 r
.63125 .44544 m
.60108 .49464 L
s
0 1 .278 r
.40514 .71161 m
.36516 .67644 L
s
0 .554 1 r
.52316 .57266 m
.48848 .59013 L
s
0 .846 1 r
.64893 .39178 m
.63125 .44544 L
s
0 .481 1 r
.48848 .59013 m
.46341 .59101 L
s
.614 0 1 r
.57489 .4837 m
.54589 .50093 L
s
.541 0 1 r
.5916 .45525 m
.57489 .4837 L
s
0 .919 1 r
.65627 .34251 m
.64893 .39178 L
s
.305 1 0 r
.73731 .19254 m
.7564 .25961 L
s
.759 0 1 r
.53394 .5242 m
.51071 .52665 L
s
.686 0 1 r
.54589 .50093 m
.53394 .5242 L
s
.468 0 1 r
.59416 .42042 m
.5916 .45525 L
s
0 .408 1 r
.46341 .59101 m
.44854 .57039 L
s
.962 1 0 r
.21279 .88341 m
.19413 .76202 L
s
.832 0 1 r
.51071 .52665 m
.49681 .52593 L
s
1 0 0 r
.5406 .48002 m
.53439 .49123 L
s
.395 0 1 r
.60168 .39442 m
.59416 .42042 L
s
1 0 .073 r
.54877 .4658 m
.5406 .48002 L
s
0 .992 1 r
.64981 .3052 m
.65627 .34251 L
s
1 0 .146 r
.55795 .45111 m
.54877 .4658 L
s
.905 0 1 r
.49681 .52593 m
.48604 .51385 L
s
1 0 .219 r
.56704 .43643 m
.55795 .45111 L
s
0 1 .351 r
.36516 .67644 m
.35644 .61735 L
s
1 0 .292 r
.57493 .42228 m
.56704 .43643 L
s
.322 0 1 r
.60387 .37334 m
.60168 .39442 L
s
0 .335 1 r
.44854 .57039 m
.43756 .53522 L
s
1 0 .365 r
.5668 .40681 m
.57493 .42228 L
s
.978 0 1 r
.48604 .51385 m
.47998 .49326 L
s
.249 0 1 r
.58986 .35753 m
.60387 .37334 L
s
1 0 .438 r
.56944 .40169 m
.5668 .40681 L
s
1 0 .511 r
.55466 .39535 m
.56944 .40169 L
s
0 1 .935 r
.62332 .27432 m
.64981 .3052 L
s
.378 1 0 r
.70329 .14667 m
.73731 .19254 L
s
1 0 .949 r
.47998 .49326 m
.49129 .47368 L
s
1 0 .876 r
.49129 .47368 m
.50415 .45222 L
s
0 .262 1 r
.43756 .53522 m
.444 .49331 L
s
.176 0 1 r
.56784 .35182 m
.58986 .35753 L
s
1 0 .584 r
.5359 .39688 m
.55466 .39535 L
s
1 0 .803 r
.50415 .45222 m
.51682 .43138 L
s
1 0 .73 r
.51682 .43138 m
.5278 .41129 L
s
0 1 .424 r
.35644 .61735 m
.36498 .53313 L
s
1 0 .657 r
.5278 .41129 m
.5359 .39688 L
s
.103 0 1 r
.54145 .35789 m
.56784 .35182 L
s
0 .189 1 r
.444 .49331 m
.46805 .45016 L
s
0 1 .862 r
.59279 .269 m
.62332 .27432 L
s
0 .116 1 r
.46805 .45016 m
.49168 .41146 L
s
.03 0 1 r
.512 .37591 m
.54145 .35789 L
s
0 .043 1 r
.49168 .41146 m
.512 .37591 L
s
.889 1 0 r
.19413 .76202 m
.22461 .59691 L
s
.451 1 0 r
.63749 .11622 m
.70329 .14667 L
s
0 1 .789 r
.54967 .28129 m
.59279 .269 L
s
0 1 .497 r
.36498 .53313 m
.39598 .448 L
s
0 1 .716 r
.49282 .31357 m
.54967 .28129 L
s
0 1 .57 r
.39598 .448 m
.44313 .37269 L
s
0 1 .643 r
.44313 .37269 m
.49282 .31357 L
s
.524 1 0 r
.56573 .12794 m
.63749 .11622 L
s
.816 1 0 r
.22461 .59691 m
.2778 .41845 L
s
.597 1 0 r
.47105 .17671 m
.56573 .12794 L
s
.743 1 0 r
.2778 .41845 m
.37699 .27666 L
s
.67 1 0 r
.37699 .27666 m
.47105 .17671 L
s
0 0 0 r
.25 Mabswid
.5 0 m
.95652 .26766 L
s
.95652 .26766 m
1 .87945 L
s
1 .87945 m
.5 .68402 L
s
.5 .68402 m
.5 0 L
s
.04348 .26766 m
0 .87945 L
s
0 .87945 m
.5 .68402 L
s
.5 .68402 m
.5 0 L
s
.5 0 m
.04348 .26766 L
s
.04348 .26766 m
.5 0 L
s
gsave
.18103 .10504 -87.625 -18.4849 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.1875 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 23.187500 moveto
 460.000000 23.187500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 23.187500 lineto
closepath
clip newpath
63.000000 17.625000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 15.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 17.625000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 15.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(I) show
72.000000 20.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.625000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(IN) show
85.625000 17.625000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 15.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400.688, 411.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Initialization Cells", "ExampleSection",
  InitializationCell->True],

Cell[TextData[{
  "Read ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " package Analog Insydes:"
}], "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(Off[General::spell, \ General::spell1]; \)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \($NotebookDirectory = 
      ToFileName@
        First["\<FileName\>" /. NotebookInformation[EvaluationNotebook[]]]; \n
    PrependTo[$Path, $NotebookDirectory]; \)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(<< AnalogInsydes`; \)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Off[ReadNetlist::mod]; \)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SetDirectory[ToFileName[{$NotebookDirectory, "\<PSpice\>"}]]; \)\)], 
  "Input",
  InitializationCell->True],

Cell[BoxData[
    \(SetOptions[{DXFGraphics, TransientPlot, ParametricPlot3D}, 
      Background \[Rule] RGBColor[1, 1, 1]]; \n
    SetOptions[ParametricPlot3D, BoxRatios\  \[Rule] \ {1.0, \ 1.0, \ 1.0}, 
      Ticks \[Rule] None, ViewPoint \[Rule] {3, \(-3\), 2. }]; \)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["", "ExampleSection",
  Editable->False,
  ShowGroupOpenCloseIcon->False],

Cell[TextData[StyleBox["Copyright \[Copyright] 1998-2000 by ITWM e.V.",
  FontWeight->"Bold"]], "Text",
  Editable->False,
  CellFrame->{{0, 0}, {0, 1}},
  CellMargins->{{0, 0}, {0, 7}},
  FontFamily->"Helvetica",
  FontSize->16,
  FontWeight->"Bold",
  Background->RGBColor[0.8, 0.8, 0.900008],
  CellTags->"$Id: DemoInterface.nb,v 1.3 2000/11/03 16:19:49 halfmann Exp $"],\


Cell[TextData[{
  ButtonBox["Analog Insydes",
    ButtonData:>{
      URL[ "http://www.itwm.uni-kl.de/as/products/ai"], None},
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["ITWM",
    ButtonData:>{
      URL[ "http://www.itwm.uni-kl.de/"], None},
    ButtonStyle->"Hyperlink"],
  " - Institut f\[UDoubleDot]r Techno- und Wirtschaftsmathematik e.V.\n\
Gottlieb-Daimler-Str.\nD-67663 Kaiserslautern, Germany\n\nAnalog Insydes is a \
trademark of ITWM.\n",
  StyleBox["Mathematica", "TI"],
  " is a registered trademark of Wolfram Research, Inc.\nAll other product \
names are trademarks of their respective owners."
}], "Text",
  Editable->False,
  CellMargins->{{0, 12}, {0, 0}},
  Background->RGBColor[0.8, 0.8, 0.900008]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1152}, {0, 836}},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
InitializationCellWarning->False,
CellGrouping->Manual,
WindowSize->{556, 564},
WindowMargins->{{121, Automatic}, {Automatic, 21}},
ButtonBoxOptions->{Active->True,
ButtonStyle->None},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
$Id: DemoStyleSheet.nb,v 1.5 1999/02/10 08:00:23 wichmann Exp $\
\>", "Text"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9,
    FontSize->12],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->18],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->10],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->11,
    PrivateFontOptions->{"FontType"->"Outline"}],
  
  Cell[StyleData[All, "Book"],
    PageWidth->PaperWidth,
    ShowCellTags->False,
    ScriptMinSize->5,
    FontSize->13.75,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "Header"]}, {Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{None, Cell[ 
            TextData[ {"\[Copyright]1999 ITWM e.V. All rights reserved."}], 
            "Footer"], None}, {None, Cell[ 
            TextData[ {"\[Copyright]1999 ITWM e.V. All rights reserved."}], 
            "Footer"], None}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"PrintingMargins"->{{54, 54}, {108, 72}},
    "PaperSize"->{597.563, 842.375},
    "PaperOrientation"->"Portrait",
    "PrintCellBrackets"->False,
    "PrintRegistrationMarks"->False,
    "PrintMultipleHorizontalPages"->False,
    "FirstPageHeader"->False,
    "FirstPageFooter"->False,
    "FacingPages"->True,
    "FirstPageFace"->Right},
    ShowCellBracket->False,
    CellLabelAutoDelete->True,
    DefaultNewCellStyle->"Input",
    DefaultDuplicateCellStyle->"Text",
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.900008, 0.940002]],
  
  Cell[StyleData["Notebook", "Book"],
    PrintingCopies->1,
    PrintingPageRange->{Automatic, Automatic},
    PageFooters->{{None, None, None}, {None, None, None}},
    PageFooterLines->{False, False}],
  
  Cell[StyleData["Notebook", "Printout"],
    PrintingCopies->1,
    PrintingPageRange->{Automatic, Automatic},
    PageFooters->{{None, None, None}, {None, None, None}},
    PageFooterLines->{False, False},
    Background->GrayLevel[1]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->28,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    TextAlignment->Left,
    LineSpacing->{1, 0},
    FontSize->42],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->26],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {12, 30}},
    FontSize->28],
  
  Cell[StyleData["Title", "Book"],
    CellMargins->{{2.5, 12.5}, {15, 37.5}},
    FontSize->35]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellFrame->2,
    CellMargins->{{12, 12}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    Background->RGBColor[0.8, 0.8, 0.900008]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->18],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Book"],
    CellMargins->{{2.5, 12.5}, {15, 10}},
    FontSize->30]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->30],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 8}},
    FontSize->18],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->20],
  
  Cell[StyleData["Subsubtitle", "Book"],
    CellMargins->{{2.5, 12.5}, {15, 10}},
    FontSize->25]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[GraySquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->14],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->16],
  
  Cell[StyleData["Section", "Book"],
    CellMargins->{{16.25, 0}, {8.75, 27.5}},
    FontSize->20]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSection"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ExampleSection", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["ExampleSection", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->14],
  
  Cell[StyleData["ExampleSection", "Printout"],
    CellDingbat->"\[FilledSquare]",
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->16],
  
  Cell[StyleData["ExampleSection", "Book"],
    CellDingbat->"\[FilledSquare]",
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{16.25, 0}, {8.75, 27.5}},
    FontSize->20]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->21],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->14],
  
  Cell[StyleData["Subsection", "Book"],
    CellMargins->{{11.25, 0}, {8.75, 27.5}},
    FontSize->17.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->8},
    CellGroupingRules->{"SectionGrouping", 50},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionIcon", "Printout"],
    CellDingbat->"\[FilledSquare]",
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14],
  
  Cell[StyleData["SubsectionIcon", "Book"],
    CellDingbat->"\[FilledSquare]",
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{20, 0}, {0, 22.5}},
    PageBreakBelow->False,
    FontSize->17.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellGroupingRules->{"SectionGrouping", 60},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionIcon", "Printout"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->11],
  
  Cell[StyleData["SubsubsectionIcon", "Book"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{2.5, 0}, {0, 22.5}},
    PageBreakBelow->False,
    FontSize->13.75]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{12, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{24, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{8, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 0}, {7, 22}},
    FontSize->12],
  
  Cell[StyleData["Subsubsection", "Book"],
    CellMargins->{{2.5, 0}, {8.75, 27.5}},
    FontSize->15]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    FontFamily->"Times"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1],
  
  Cell[StyleData["Text", "Book"],
    CellMargins->{{2.5, 2.5}, {7.5, 7.5}},
    TextJustification->1]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CommentInput"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"CommentInput",
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["CommentInput", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["CommentInput", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2}],
  
  Cell[StyleData["CommentInput", "Printout"],
    CellMargins->{{2, 2}, {5, 5}}],
  
  Cell[StyleData["CommentInput", "Book"],
    CellMargins->{{2.5, 2.5}, {6.25, 6.25}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Comment"],
    CellMargins->{{12, 10}, {6, 6}},
    TextJustification->1,
    LineSpacing->{1, 3},
    CounterIncrements->"Comment",
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Comment", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Comment", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2}],
  
  Cell[StyleData["Comment", "Printout"],
    CellMargins->{{2, 2}, {5, 5}}],
  
  Cell[StyleData["Comment", "Book"],
    CellMargins->{{2.5, 2.5}, {6.25, 6.25}}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names. \
Some attributes for these styles are actually set in FormatType Styles (in \
the last section of this stylesheet). \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    ShowCellBracket->True,
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    TextAlignment->Left,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    Background->RGBColor[0.829999, 0.829999, 0.900008],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    TextAlignment->Left,
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}},
    TextAlignment->Left],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    TextAlignment->Left],
  
  Cell[StyleData["Input", "Book"],
    CellMargins->{{48.75, 0}, {5, 7.5}},
    TextAlignment->Left]
  }, Open  ]],
  
  Cell[StyleData["InputOnly"],
    ShowCellBracket->True,
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    DefaultFormatType->DefaultInputFormatType,
    TextAlignment->Left,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    ShowCellBracket->True,
    CellMargins->{{45, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    TextAlignment->Left,
    TextJustification->0.25,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    Background->RGBColor[0.949996, 0.949996, 0.979995],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}}],
  
  Cell[StyleData["Output", "Book"],
    CellMargins->{{48.75, 0}, {7.5, 5}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{47, 10}, {7, 5}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    TextAlignment->Left,
    TextJustification->0.25,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Program",
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{39, 0}, {6, 4}}],
  
  Cell[StyleData["Program", "Book"],
    CellMargins->{{48.75, 0}, {7.5, 5}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    ShowCellBracket->True,
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Message", "Book"],
    CellMargins->{{48.75, Inherited}, {Inherited, Inherited}},
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Book"],
    CellMargins->{{48.75, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    ShowCellBracket->False,
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    TextAlignment->Left,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica"],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageMargins->{{38, Inherited}, {Inherited, 0}},
    Magnification->0.6],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    Magnification->0.8],
  
  Cell[StyleData["Graphics", "Book"],
    ImageMargins->{{37.5, Inherited}, {Inherited, 0}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["CellLabel", "Book"],
    FontFamily->"Courier",
    FontSize->10,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}],
  
  Cell[StyleData["InlineFormula", "Book"],
    CellMargins->{{2.5, 0}, {7.5, 7.5}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->7],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Book"],
    CellMargins->{{2.5, 2.5}, {6.25, 6.25}},
    FontSize->11.25]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard ButtonFunctions, for use \
in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSlant->"Italic",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Hyperlink", "Book"],
    FontSlant->"Italic",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionHyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontSize->14,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["SubsectionHyperlink", "Presentation"],
    FontSize->21],
  
  Cell[StyleData["SubsectionHyperlink", "Condensed"],
    FontSize->12],
  
  Cell[StyleData["SubsectionHyperlink", "Printout"],
    FontSize->14,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["SubsectionHyperlink", "Book"],
    FontSize->14,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["MainBookLink", "Book"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["AddOnsLink", "Book"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["RefGuideLink", "Book"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["GettingStartedLink", "Book"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AITopicLink"],
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AITopicLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["AITopicLink", "Book"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["OtherInformationLink", "Book"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["M4"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Math4",
    CharacterEncoding->"Math4"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Book"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8.75,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1", "Printout"],
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["C1", "Book"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1MR", "Printout"],
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["C1MR", "Book"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Emphasis Boxes and Pictures", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Box"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["Box", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Box", "Book"],
    CellMargins->{{2.5, 0}, {0, 10}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DoubleBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->2,
    RowAlignments->Top}],
  
  Cell[StyleData["DoubleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["DoubleBox", "Book"],
    CellMargins->{{2.5, 0}, {0, 10}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["1ColumnBox", "Book"],
    CellMargins->{{2.5, 0}, {0, 10}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.31, 0.62}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["2ColumnBox", "Book"],
    CellMargins->{{2.5, 5}, {0, 10}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.46}],
  
  Cell[StyleData["2ColumnEvenBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["2ColumnEvenBox", "Book"],
    CellMargins->{{2.5, 0}, {0, 10}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["2ColumnSmallBox", "Book"],
    CellMargins->{{2.5, 0}, {0, 10}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{RowSpacings->2,
    ColumnWidths->{0.2, 0.15, 0.58}}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["3ColumnBox", "Book"],
    CellMargins->{{2.5, 5}, {0, 10}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.24,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["3ColumnSmallBox", "Book"],
    CellMargins->{{2.5, 0}, {0, 10}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.33, 0.13, 0.33}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["4ColumnBox", "Book"],
    CellMargins->{{2.5, 0}, {0, 10}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.194}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["5ColumnBox", "Book"],
    CellMargins->{{2.5, 0}, {0, 10}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.12, 0.22, 0.12, 0.12, 0.22, 0.12}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["6ColumnBox", "Book"],
    CellMargins->{{2.5, 0}, {0, 10}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedNoteBox"],
    CellFrame->0.5,
    CellMargins->{{37, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["ItemizedNoteBox", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["ItemizedNoteBox", "Book"],
    FontSize->12.5,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineSpacing->{1.2, 1},
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{RowSpacings->2,
    ColumnSpacings->1,
    ColumnWidths->{0.3, 0.7},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["DefinitionBox", "Book"],
    CellMargins->{{2.5, 5}, {0, 10}},
    FontSize->12.5,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox3Col"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineSpacing->{1.2, 1},
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{RowSpacings->2,
    ColumnSpacings->1,
    ColumnWidths->{0.2, 0.15, 0.65},
    ColumnAlignments->{Left},
    RowLines->{True, False}}],
  
  Cell[StyleData["DefinitionBox3Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["DefinitionBox3Col", "Book"],
    CellMargins->{{2.5, 5}, {0, 10}},
    FontSize->12.5,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox4Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.15, 0.35, 0.15, 0.35},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox4Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["DefinitionBox4Col", "Book"],
    CellMargins->{{2.5, 5}, {0, 10}},
    FontSize->12.5,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox5Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->0.2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox5Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["DefinitionBox5Col", "Book"],
    CellMargins->{{2.5, 5}, {0, 10}},
    FontSize->12.5,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox6Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox6Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["DefinitionBox6Col", "Book"],
    CellMargins->{{2.5, 5}, {0, 10}},
    FontSize->12.5,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    LineSpacing->{1.2, 1},
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->2,
    ColumnSpacings->1,
    ColumnWidths->{0.3, 0.7},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopBox", "Printout"],
    CellMargins->{{2, 4}, {0, 0}},
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["TopBox", "Book"],
    CellMargins->{{2.5, 5}, {0, 0}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleBox", "Printout"],
    CellMargins->{{2, 4}, {0, 0}},
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["MiddleBox", "Book"],
    CellMargins->{{2.5, 5}, {0, 0}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    LineSpacing->{1.2, 1},
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->2,
    ColumnSpacings->1,
    ColumnWidths->{0.3, 0.7},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BottomBox", "Printout"],
    CellMargins->{{2, 4}, {0, -5}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["BottomBox", "Book"],
    CellMargins->{{2.5, 5}, {0, -6.25}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopSpanBox", "Printout"],
    CellMargins->{{2, 4}, {0, 10}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["TopSpanBox", "Book"],
    CellMargins->{{2.5, 5}, {0, 10}},
    FontSize->12.5,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, 0}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpanBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["MiddleSpanBox", "Book"],
    CellMargins->{{2.5, 5}, {0, 10}},
    FontSize->12.5,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{60, Inherited}, {0, 8}},
    CellHorizontalScrolling->True,
    ShowCellLabel->False,
    CounterIncrements->"Figure",
    StyleMenuListing->None],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{30, 0}, {0, 8}}],
  
  Cell[StyleData["Picture", "Book"],
    CellMargins->{{30, 0}, {0, 10}}]
  }, Open  ]],
  
  Cell[StyleData["PictureHeading"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{60, 10}, {5, 7}},
    Evaluatable->False,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    TextAlignment->Left,
    AutoItalicWords->{},
    ShowStringCharacters->True,
    NumberMarks->True,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["PictureOutput"],
    CellMargins->{{60, Inherited}, {0, 8}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    ShowCellLabel->False,
    CounterIncrements->"Figure",
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedPicture"],
    CellMargins->{{35, 4}, {0, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedPicture", "Printout"],
    CellMargins->{{27, 0}, {0, 4}}],
  
  Cell[StyleData["ItemizedPicture", "Book"],
    CellMargins->{{33.75, 0}, {0, 5}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["PictureGroup", "Book"],
    CellMargins->{{2.5, 0}, {0, 10}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sound"],
    CellMargins->{{10, Inherited}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Sound", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["Sound", "Book"],
    CellMargins->{{2.5, 0}, {0, 10}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{60, 4}, {10, 3}},
    PageBreakAbove->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{30, 0}, {10, 3}},
    FontSize->7],
  
  Cell[StyleData["Caption", "Book"],
    CellMargins->{{30, 0}, {12.5, 3.75}},
    FontSize->8.75]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BoxCaption"],
    CellMargins->{{10, 4}, {0, 8}},
    PageBreakAbove->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["BoxCaption", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->7],
  
  Cell[StyleData["BoxCaption", "Book"],
    CellMargins->{{2.5, 5}, {0, 10}},
    FontSize->8.75]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.34, 0.64},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["2ColumnTable", "Book"],
    CellMargins->{{2.5, 0}, {0, 10}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.49,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnEvenTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["2ColumnEvenTable", "Book"],
    CellMargins->{{2.5, 0}, {0, 10}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["3ColumnTable", "Book"],
    CellMargins->{{2.5, 0}, {0, 10}}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Misc AI Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ModelBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    TextAlignment->Left,
    LineSpacing->{1.2, 1},
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LineIndent->0,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    Background->GrayLevel[0.8],
    FontVariations->{"Underline"->False},
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}}],
  
  Cell[StyleData["ModelBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.949996]],
  
  Cell[StyleData["ModelBox", "Book"],
    CellMargins->{{2.5, 5}, {0, 10}},
    FontSize->12.5,
    Background->GrayLevel[0.949996]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AICopyright"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  
  Cell[StyleData["AICopyright", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    TextAlignment->Left,
    LineSpacing->{1, 0}],
  
  Cell[StyleData["AICopyright", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}}],
  
  Cell[StyleData["AICopyright", "Printout"],
    CellMargins->{{2, 10}, {12, 30}}],
  
  Cell[StyleData["AICopyright", "Book"],
    CellMargins->{{0, 0}, {0, 0}},
    PageBreakAbove->True,
    FontSize->1,
    FontColor->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AIAddress"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    FontFamily->"Times"],
  
  Cell[StyleData["AIAddress", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["AIAddress", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["AIAddress", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1],
  
  Cell[StyleData["AIAddress", "Book"],
    CellMargins->{{0, 0}, {0, 0}},
    TextJustification->1,
    FontSize->1,
    FontColor->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AIHyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["AIHyperlink", "Presentation"]],
  
  Cell[StyleData["AIHyperlink", "Condensed"]],
  
  Cell[StyleData["AIHyperlink", "Printout"],
    FontSlant->"Italic",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["AIHyperlink", "Book"],
    FontSize->1,
    FontColor->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PermissionText"],
    CellMargins->{{12, 10}, {7, 7}},
    Evaluatable->False,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 0.501961]],
  
  Cell[StyleData["PermissionText", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 0},
    FontSize->15],
  
  Cell[StyleData["PermissionText", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    FontSize->8],
  
  Cell[StyleData["PermissionText", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    FontSize->8],
  
  Cell[StyleData["PermissionText", "Book"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->1,
    FontColor->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Task"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Task", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->21],
  
  Cell[StyleData["Task", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->12],
  
  Cell[StyleData["Task", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    FontSize->12],
  
  Cell[StyleData["Task", "Book"],
    CellMargins->{{2.5, 2.5}, {7.5, 7.5}},
    FontSize->15]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder objects in \
palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles of most \
cells.  If a cell's FormatType matches the name of one of the styles defined \
below, then that style is applied between the cell's style and its own \
options. This is particularly true of Input and Output.\
\>", "Text",
    FontSize->12],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{0.6, 1},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an inline cell \
within another.\
\>", "Text",
    FontSize->12],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }]
]


(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

